@@ -21,8 +21,8 @@ var hierarchy =
       [ "viennacl::tools::detail::auximpl< U, Deleter >", "structviennacl_1_1tools_1_1detail_1_1auximpl.html", null ]
     ] ],
     [ "viennacl::ocl::backend< dummy >", "classviennacl_1_1ocl_1_1backend.html", null ],
-    [ "viennacl::basic_range< SizeType, DistanceType >", "classviennacl_1_1basic__range.html", null ],
-    [ "viennacl::basic_slice< SizeType, DistanceType >", "classviennacl_1_1basic__slice.html", null ],
+    [ "viennacl::basic_range< SizeT, DistanceT >", "classviennacl_1_1basic__range.html", null ],
+    [ "viennacl::basic_slice< SizeT, DistanceT >", "classviennacl_1_1basic__slice.html", null ],
     [ "viennacl::linalg::bicgstab_tag", "classviennacl_1_1linalg_1_1bicgstab__tag.html", null ],
     [ "viennacl::device_specific::binary_leaf", "classviennacl_1_1device__specific_1_1binary__leaf.html", [
       [ "viennacl::device_specific::mapped_matrix_column", "classviennacl_1_1device__specific_1_1mapped__matrix__column.html", null ],
@@ -61,15 +61,14 @@ var hierarchy =
     [ "viennacl::compressed_matrix< NumericT >", "classviennacl_1_1compressed__matrix.html", null ],
     [ "viennacl::compressed_matrix< NumericType >", "classviennacl_1_1compressed__matrix.html", null ],
     [ "viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT >", "classviennacl_1_1compressed__matrix.html", null ],
-    [ "viennacl::const_entry_proxy< SCALARTYPE >", "classviennacl_1_1const__entry__proxy.html", null ],
+    [ "viennacl::const_entry_proxy< NumericT >", "classviennacl_1_1const__entry__proxy.html", null ],
     [ "viennacl::tools::CONST_REMOVER< T >", "structviennacl_1_1tools_1_1_c_o_n_s_t___r_e_m_o_v_e_r.html", null ],
     [ "viennacl::tools::const_sparse_matrix_adapted_iterator< NumericT, SizeT, is_iterator1, is_forward >", "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html", null ],
     [ "viennacl::tools::const_sparse_matrix_adapter< NumericT, SizeT >", "classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html", [
       [ "viennacl::tools::sparse_matrix_adapter< NumericT, SizeT >", "classviennacl_1_1tools_1_1sparse__matrix__adapter.html", null ]
     ] ],
-    [ "viennacl::const_vector_iterator< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1const__vector__iterator.html", null ],
     [ "viennacl::const_vector_iterator< NumericT, AlignmentV >", "classviennacl_1_1const__vector__iterator.html", [
-      [ "viennacl::vector_iterator< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vector__iterator.html", null ]
+      [ "viennacl::vector_iterator< NumericT, AlignmentV >", "classviennacl_1_1vector__iterator.html", null ]
     ] ],
     [ "viennacl::context", "classviennacl_1_1context.html", null ],
     [ "viennacl::ocl::context", "classviennacl_1_1ocl_1_1context.html", null ],
@@ -98,7 +97,7 @@ var hierarchy =
     [ "viennacl::ell_matrix< double >", "classviennacl_1_1ell__matrix.html", null ],
     [ "viennacl::ell_matrix< float >", "classviennacl_1_1ell__matrix.html", null ],
     [ "viennacl::enable_if< b, T >", "structviennacl_1_1enable__if.html", null ],
-    [ "viennacl::entry_proxy< SCALARTYPE >", "classviennacl_1_1entry__proxy.html", null ],
+    [ "viennacl::entry_proxy< NumericT >", "classviennacl_1_1entry__proxy.html", null ],
     [ "viennacl::ocl::error_checker< T >", "structviennacl_1_1ocl_1_1error__checker.html", null ],
     [ "exception", null, [
       [ "viennacl::cuda_not_available_exception", "classviennacl_1_1cuda__not__available__exception.html", null ],
@@ -185,9 +184,9 @@ var hierarchy =
     [ "viennacl::ocl::handle< cl_program >", "classviennacl_1_1ocl_1_1handle.html", null ],
     [ "viennacl::device_specific::utils::handle_fun", "structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html", null ],
     [ "viennacl::ocl::handle_inc_dec_helper< OCL_TYPE >", "classviennacl_1_1ocl_1_1handle__inc__dec__helper.html", null ],
-    [ "viennacl::hankel_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1hankel__matrix.html", null ],
+    [ "viennacl::hankel_matrix< NumericT, AlignmentV >", "classviennacl_1_1hankel__matrix.html", null ],
     [ "viennacl::linalg::opencl::kernels::hyb_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1hyb__matrix.html", null ],
-    [ "viennacl::hyb_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1hyb__matrix.html", null ],
+    [ "viennacl::hyb_matrix< NumericT, AlignmentV >", "classviennacl_1_1hyb__matrix.html", null ],
     [ "viennacl::hyb_matrix< double >", "classviennacl_1_1hyb__matrix.html", null ],
     [ "viennacl::hyb_matrix< float >", "classviennacl_1_1hyb__matrix.html", null ],
     [ "viennacl::linalg::ichol0_precond< MatrixT >", "classviennacl_1_1linalg_1_1ichol0__precond.html", null ],
@@ -315,7 +314,7 @@ var hierarchy =
       [ "viennacl::matrix_slice< matrix_range< MatrixType > >", "classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html", null ]
     ] ],
     [ "viennacl::matrix_base< NumericT >", "classviennacl_1_1matrix__base.html", [
-      [ "viennacl::matrix< SCALARTYPE, F, ALIGNMENT >", "classviennacl_1_1matrix.html", null ]
+      [ "viennacl::matrix< NumericT, F, AlignmentV >", "classviennacl_1_1matrix.html", null ]
     ] ],
     [ "viennacl::matrix_base< short >", "classviennacl_1_1matrix__base.html", null ],
     [ "viennacl::matrix_base< unsigned char >", "classviennacl_1_1matrix__base.html", null ],
@@ -324,7 +323,7 @@ var hierarchy =
     [ "viennacl::matrix_base< unsigned short >", "classviennacl_1_1matrix__base.html", null ],
     [ "viennacl::linalg::opencl::kernels::matrix_element< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html", null ],
     [ "viennacl::matrix_expression< LHS, RHS, OP >", "classviennacl_1_1matrix__expression.html", null ],
-    [ "viennacl::matrix_iterator< ROWCOL, MATRIXTYPE >", "classviennacl_1_1matrix__iterator.html", null ],
+    [ "viennacl::matrix_iterator< ROWCOL, MatrixT >", "classviennacl_1_1matrix__iterator.html", null ],
     [ "viennacl::tools::MATRIX_ITERATOR_INCREMENTER< ROWCOL, MATRIXTYPE >", "structviennacl_1_1tools_1_1_m_a_t_r_i_x___i_t_e_r_a_t_o_r___i_n_c_r_e_m_e_n_t_e_r.html", null ],
     [ "viennacl::linalg::opencl::kernels::matrix_legacy< NumericT, LayoutT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html", null ],
     [ "matrix_maker< UBlasType, F >", "structmatrix__maker.html", null ],
@@ -361,6 +360,7 @@ var hierarchy =
     [ "viennacl::op_argmax", "structviennacl_1_1op__argmax.html", null ],
     [ "viennacl::op_argmin", "structviennacl_1_1op__argmin.html", null ],
     [ "viennacl::op_asin", "structviennacl_1_1op__asin.html", null ],
+    [ "op_assign", "structop__assign.html", null ],
     [ "viennacl::op_assign", "structviennacl_1_1op__assign.html", null ],
     [ "viennacl::op_atan", "structviennacl_1_1op__atan.html", null ],
     [ "viennacl::op_atan2", "structviennacl_1_1op__atan2.html", null ],
@@ -396,12 +396,14 @@ var hierarchy =
     [ "viennacl::op_matrix_diag", "structviennacl_1_1op__matrix__diag.html", null ],
     [ "viennacl::op_max", "structviennacl_1_1op__max.html", null ],
     [ "viennacl::op_min", "structviennacl_1_1op__min.html", null ],
+    [ "op_minus_assign", "structop__minus__assign.html", null ],
     [ "viennacl::op_mult", "structviennacl_1_1op__mult.html", null ],
     [ "viennacl::op_neq", "structviennacl_1_1op__neq.html", null ],
     [ "viennacl::op_norm_1", "structviennacl_1_1op__norm__1.html", null ],
     [ "viennacl::op_norm_2", "structviennacl_1_1op__norm__2.html", null ],
     [ "viennacl::op_norm_frobenius", "structviennacl_1_1op__norm__frobenius.html", null ],
     [ "viennacl::op_norm_inf", "structviennacl_1_1op__norm__inf.html", null ],
+    [ "op_plus_assign", "structop__plus__assign.html", null ],
     [ "viennacl::op_pow", "structviennacl_1_1op__pow.html", null ],
     [ "viennacl::op_prod", "structviennacl_1_1op__prod.html", null ],
     [ "viennacl::op_reduce_columns< T >", "structviennacl_1_1op__reduce__columns.html", null ],
@@ -505,7 +507,7 @@ var hierarchy =
     [ "viennacl::linalg::row_scaling< MatrixType, true >", "classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html", null ],
     [ "viennacl::linalg::row_scaling_tag", "classviennacl_1_1linalg_1_1row__scaling__tag.html", null ],
     [ "viennacl::linalg::opencl::kernels::row_wise_reduction< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html", null ],
-    [ "viennacl::scalar< TYPE >", "classviennacl_1_1scalar.html", null ],
+    [ "viennacl::scalar< NumericT >", "classviennacl_1_1scalar.html", null ],
     [ "viennacl::linalg::opencl::kernels::scalar< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html", null ],
     [ "viennacl::scalar< char >", "classviennacl_1_1scalar.html", null ],
     [ "viennacl::scalar< double >", "classviennacl_1_1scalar.html", null ],
@@ -581,9 +583,8 @@ var hierarchy =
       [ "viennacl::device_specific::template_base_impl< TemplateType, ParametersType >", "classviennacl_1_1device__specific_1_1template__base__impl.html", null ]
     ] ],
     [ "testData", "structtest_data.html", null ],
-    [ "Timer", "class_timer.html", null ],
     [ "viennacl::tools::timer", "classviennacl_1_1tools_1_1timer.html", null ],
-    [ "viennacl::toeplitz_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1toeplitz__matrix.html", null ],
+    [ "Timer", "class_timer.html", null ],
     [ "viennacl::toeplitz_matrix< NumericT, AlignmentV >", "classviennacl_1_1toeplitz__matrix.html", null ],
     [ "viennacl::device_specific::tree_parsing::traversal_functor", "classviennacl_1_1device__specific_1_1tree__parsing_1_1traversal__functor.html", [
       [ "viennacl::device_specific::tree_parsing::evaluate_expression_traversal", "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html", null ],
@@ -614,7 +615,7 @@ var hierarchy =
     [ "viennacl::linalg::unit_upper_tag", "structviennacl_1_1linalg_1_1unit__upper__tag.html", null ],
     [ "viennacl::linalg::upper_tag", "structviennacl_1_1linalg_1_1upper__tag.html", null ],
     [ "viennacl::result_of::value_type< T >", "structviennacl_1_1result__of_1_1value__type.html", null ],
-    [ "viennacl::vandermonde_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vandermonde__matrix.html", null ],
+    [ "viennacl::vandermonde_matrix< NumericT, AlignmentV >", "classviennacl_1_1vandermonde__matrix.html", null ],
     [ "viennacl::linalg::opencl::kernels::vector< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
     [ "viennacl::linalg::host_based::detail::vector_array_wrapper< NumericT >", "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html", null ],
     [ "viennacl::vector_base< NumericT, SizeT, DistanceT >", "classviennacl_1_1vector__base.html", null ],
@@ -625,15 +626,19 @@ var hierarchy =
     [ "viennacl::vector_base< long >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< NumericT >", "classviennacl_1_1vector__base.html", [
       [ "viennacl::vector< NumericT >", "classviennacl_1_1vector.html", null ],
-      [ "viennacl::vector< NumericT, AlignmentV >", "classviennacl_1_1vector.html", null ],
-      [ "viennacl::vector< NumericType >", "classviennacl_1_1vector.html", null ],
-      [ "viennacl::vector< ScalarType >", "classviennacl_1_1vector.html", null ],
-      [ "viennacl::vector< unsigned int >", "classviennacl_1_1vector.html", null ],
-      [ "viennacl::vector< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vector.html", null ]
+      [ "viennacl::vector< NumericT, AlignmentV >", "classviennacl_1_1vector.html", null ]
+    ] ],
+    [ "viennacl::vector_base< NumericType >", "classviennacl_1_1vector__base.html", [
+      [ "viennacl::vector< NumericType >", "classviennacl_1_1vector.html", null ]
+    ] ],
+    [ "viennacl::vector_base< ScalarType >", "classviennacl_1_1vector__base.html", [
+      [ "viennacl::vector< ScalarType >", "classviennacl_1_1vector.html", null ]
     ] ],
     [ "viennacl::vector_base< short >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< unsigned char >", "classviennacl_1_1vector__base.html", null ],
-    [ "viennacl::vector_base< unsigned int >", "classviennacl_1_1vector__base.html", null ],
+    [ "viennacl::vector_base< unsigned int >", "classviennacl_1_1vector__base.html", [
+      [ "viennacl::vector< unsigned int >", "classviennacl_1_1vector.html", null ]
+    ] ],
     [ "viennacl::vector_base< unsigned long >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< unsigned short >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< VectorType::cpu_value_type >", "classviennacl_1_1vector__base.html", [
@@ -645,6 +650,7 @@ var hierarchy =
     [ "viennacl::linalg::opencl::kernels::vector_element< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html", null ],
     [ "viennacl::vector_expression< LHS, RHS, OP >", "classviennacl_1_1vector__expression.html", null ],
     [ "viennacl::linalg::opencl::kernels::vector_multi_inner_prod< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ],
+    [ "vector_proxy< NumericT >", "classvector__proxy.html", null ],
     [ "viennacl::vector_tuple< ScalarT >", "classviennacl_1_1vector__tuple.html", null ],
     [ "ViennaCLBackend_impl", "struct_vienna_c_l_backend__impl.html", null ],
     [ "ViennaCLCUDABackend_impl", "struct_vienna_c_l_c_u_d_a_backend__impl.html", null ],
