@@ -3,26 +3,27 @@ var NAVTREEINDEX =
 "index.html":[],
 "index.html":[0],
 "pages.html":[1],
-"usermanual.html":[1,0],
-"manual-page-introduction.html":[1,0,0],
-"manual-page-installation.html":[1,0,1],
-"manual-page-types.html":[1,0,2],
-"manual-page-operations.html":[1,0,3],
-"manual-page-algorithms.html":[1,0,4],
-"manual-page-interfacing.html":[1,0,5],
-"manual-page-memory.html":[1,0,6],
-"manual-page-shared-library.html":[1,0,7],
-"manual-page-additional-algorithms.html":[1,0,8],
-"manual-page-custom-contexts.html":[1,0,9],
-"manual-page-multi-device.html":[1,0,10],
-"manual-page-custom-kernels.html":[1,0,11],
-"manual-page-structured-matrix.html":[1,0,12],
-"manual-page-design.html":[1,0,13],
-"manual-page-authors.html":[1,0,14],
-"manual-page-versioning.html":[1,0,15],
-"manual-page-license.html":[1,0,16],
-"test.html":[1,1],
-"citelist.html":[1,2],
+"faq.html":[1,0],
+"usermanual.html":[1,1],
+"manual-page-introduction.html":[1,1,0],
+"manual-page-installation.html":[1,1,1],
+"manual-page-types.html":[1,1,2],
+"manual-page-operations.html":[1,1,3],
+"manual-page-algorithms.html":[1,1,4],
+"manual-page-interfacing.html":[1,1,5],
+"manual-page-memory.html":[1,1,6],
+"manual-page-shared-library.html":[1,1,7],
+"manual-page-additional-algorithms.html":[1,1,8],
+"manual-page-custom-contexts.html":[1,1,9],
+"manual-page-multi-device.html":[1,1,10],
+"manual-page-custom-kernels.html":[1,1,11],
+"manual-page-structured-matrix.html":[1,1,12],
+"manual-page-design.html":[1,1,13],
+"manual-page-authors.html":[1,1,14],
+"manual-page-versioning.html":[1,1,15],
+"manual-page-license.html":[1,1,16],
+"test.html":[1,2],
+"citelist.html":[1,3],
 "namespaces.html":[2,0],
 "namespacedetail.html":[2,0,0],
 "namespaceviennacl.html":[2,0,1],
@@ -49,48 +50,53 @@ var NAVTREEINDEX =
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[2,0,22],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[2,0,23],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen_1_1cypress.html":[2,0,24],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1unknown.html":[2,0,25],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1unknown_1_1devastator.html":[2,0,26],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[2,0,27],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands_1_1hawaii.html":[2,0,28],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1fallback.html":[2,0,29],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[2,0,30],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[2,0,31],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gt__540m.html":[2,0,32],
-"namespaceviennacl_1_1device__specific_1_1detail.html":[2,0,33],
-"namespaceviennacl_1_1device__specific_1_1profiles.html":[2,0,34],
-"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[2,0,35],
-"namespaceviennacl_1_1device__specific_1_1utils.html":[2,0,36],
-"namespaceviennacl_1_1io.html":[2,0,37],
-"namespaceviennacl_1_1io_1_1detail.html":[2,0,38],
-"namespaceviennacl_1_1io_1_1tag.html":[2,0,39],
-"namespaceviennacl_1_1io_1_1val.html":[2,0,40],
-"namespaceviennacl_1_1linalg.html":[2,0,41],
-"namespaceviennacl_1_1linalg_1_1cuda.html":[2,0,42],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[2,0,43],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[2,0,44],
-"namespaceviennacl_1_1linalg_1_1detail.html":[2,0,45],
-"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[2,0,46],
-"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[2,0,47],
-"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[2,0,48],
-"namespaceviennacl_1_1linalg_1_1host__based.html":[2,0,49],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[2,0,50],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[2,0,51],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[2,0,52],
-"namespaceviennacl_1_1linalg_1_1kernels.html":[2,0,53],
-"namespaceviennacl_1_1linalg_1_1opencl.html":[2,0,54],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[2,0,55],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[2,0,56],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[2,0,57],
-"namespaceviennacl_1_1ocl.html":[2,0,58],
-"namespaceviennacl_1_1result__of.html":[2,0,59],
-"namespaceviennacl_1_1scheduler.html":[2,0,60],
-"namespaceviennacl_1_1scheduler_1_1detail.html":[2,0,61],
-"namespaceviennacl_1_1scheduler_1_1preset.html":[2,0,62],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[2,0,63],
-"namespaceviennacl_1_1tools.html":[2,0,64],
-"namespaceviennacl_1_1tools_1_1detail.html":[2,0,65],
-"namespaceviennacl_1_1traits.html":[2,0,66],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands.html":[2,0,25],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands_1_1devastator.html":[2,0,26],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[2,0,27],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands_1_1tahiti.html":[2,0,28],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[2,0,29],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands_1_1hawaii.html":[2,0,30],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1fallback.html":[2,0,31],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[2,0,32],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[2,0,33],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gt__540m.html":[2,0,34],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__580.html":[2,0,35],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[2,0,36],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler_1_1tesla__k20m.html":[2,0,37],
+"namespaceviennacl_1_1device__specific_1_1detail.html":[2,0,38],
+"namespaceviennacl_1_1device__specific_1_1profiles.html":[2,0,39],
+"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[2,0,40],
+"namespaceviennacl_1_1device__specific_1_1utils.html":[2,0,41],
+"namespaceviennacl_1_1io.html":[2,0,42],
+"namespaceviennacl_1_1io_1_1detail.html":[2,0,43],
+"namespaceviennacl_1_1io_1_1tag.html":[2,0,44],
+"namespaceviennacl_1_1io_1_1val.html":[2,0,45],
+"namespaceviennacl_1_1linalg.html":[2,0,46],
+"namespaceviennacl_1_1linalg_1_1cuda.html":[2,0,47],
+"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[2,0,48],
+"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[2,0,49],
+"namespaceviennacl_1_1linalg_1_1detail.html":[2,0,50],
+"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[2,0,51],
+"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[2,0,52],
+"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[2,0,53],
+"namespaceviennacl_1_1linalg_1_1host__based.html":[2,0,54],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[2,0,55],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[2,0,56],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[2,0,57],
+"namespaceviennacl_1_1linalg_1_1kernels.html":[2,0,58],
+"namespaceviennacl_1_1linalg_1_1opencl.html":[2,0,59],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[2,0,60],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[2,0,61],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[2,0,62],
+"namespaceviennacl_1_1ocl.html":[2,0,63],
+"namespaceviennacl_1_1result__of.html":[2,0,64],
+"namespaceviennacl_1_1scheduler.html":[2,0,65],
+"namespaceviennacl_1_1scheduler_1_1detail.html":[2,0,66],
+"namespaceviennacl_1_1scheduler_1_1preset.html":[2,0,67],
+"namespaceviennacl_1_1scheduler_1_1result__of.html":[2,0,68],
+"namespaceviennacl_1_1tools.html":[2,0,69],
+"namespaceviennacl_1_1tools_1_1detail.html":[2,0,70],
+"namespaceviennacl_1_1traits.html":[2,0,71],
 "namespacemembers.html":[2,1,0],
 "namespacemembers.html":[2,1,0,0],
 "namespacemembers.html":[2,1,0,1],
@@ -797,316 +803,320 @@ var NAVTREEINDEX =
 "examples_2tutorial_2qr__method_8cpp.html":[4,0,34],
 "examples_2tutorial_2_random_8hpp.html":[4,0,35],
 "tutorial_2scheduler_8cpp.html":[4,0,36],
-"spai_8cpp.html":[4,0,37],
-"examples_2tutorial_2sparse_8cpp.html":[4,0,38],
-"examples_2tutorial_2structured-matrices_8cpp.html":[4,0,39],
-"tql2_8cpp.html":[4,0,40],
-"vector-io_8hpp.html":[4,0,41],
-"vector-range_8cpp.html":[4,0,42],
-"viennacl-info_8cpp.html":[4,0,43],
-"wrap-host-buffer_8cpp.html":[4,0,44],
-"viennacl_8hpp.html":[4,0,45],
-"backend_8cpp.html":[4,0,46],
-"libviennacl_2src_2blas1_8cpp.html":[4,0,47],
-"blas1__host_8cpp.html":[4,0,48],
-"blas1__opencl_8cpp.html":[4,0,49],
-"libviennacl_2src_2blas2_8cpp.html":[4,0,50],
-"blas2__host_8cpp.html":[4,0,51],
-"blas2__opencl_8cpp.html":[4,0,52],
-"libviennacl_2src_2blas3_8cpp.html":[4,0,53],
-"blas3_8hpp.html":[4,0,54],
-"blas3__host_8cpp.html":[4,0,55],
-"blas3__opencl_8cpp.html":[4,0,56],
-"init__matrix_8hpp.html":[4,0,57],
-"init__vector_8hpp.html":[4,0,58],
-"viennacl__private_8hpp.html":[4,0,59],
-"tests_2src_2bisect_8cpp.html":[4,0,60],
-"blas3__solve_8cpp.html":[4,0,61],
-"external__1_8cpp.html":[4,0,62],
-"external__2_8cpp.html":[4,0,63],
-"fft__1d_8cpp.html":[4,0,64],
-"fft__2d_8cpp.html":[4,0,65],
-"generator__blas1_8cpp.html":[4,0,66],
-"generator__blas2_8cpp.html":[4,0,67],
-"generator__blas3_8cpp.html":[4,0,68],
-"global__variables_8cpp.html":[4,0,69],
-"iterators_8cpp.html":[4,0,70],
-"libviennacl__blas1_8cpp.html":[4,0,71],
-"libviennacl__blas2_8cpp.html":[4,0,72],
-"libviennacl__blas3_8cpp.html":[4,0,73],
-"matrix__col__double_8cpp.html":[4,0,74],
-"matrix__col__float_8cpp.html":[4,0,75],
-"matrix__col__int_8cpp.html":[4,0,76],
-"matrix__float__double_8hpp.html":[4,0,77],
-"matrix__int_8hpp.html":[4,0,78],
-"matrix__product__double_8cpp.html":[4,0,79],
-"matrix__product__float_8cpp.html":[4,0,80],
-"matrix__product__float__double_8hpp.html":[4,0,81],
-"matrix__row__double_8cpp.html":[4,0,82],
-"matrix__row__float_8cpp.html":[4,0,83],
-"matrix__row__int_8cpp.html":[4,0,84],
-"matrix__vector_8cpp.html":[4,0,85],
-"matrix__vector__int_8cpp.html":[4,0,86],
-"tests_2src_2nmf_8cpp.html":[4,0,87],
-"tests_2src_2qr__method_8cpp.html":[4,0,88],
-"qr__method__func_8cpp.html":[4,0,89],
-"tests_2src_2_random_8hpp.html":[4,0,90],
-"scalar_8cpp.html":[4,0,91],
-"scan_8cpp.html":[4,0,92],
-"scheduler__matrix_8cpp.html":[4,0,93],
-"scheduler__matrix__matrix_8cpp.html":[4,0,94],
-"scheduler__matrix__vector_8cpp.html":[4,0,95],
-"scheduler__sparse_8cpp.html":[4,0,96],
-"scheduler__vector_8cpp.html":[4,0,97],
-"tests_2src_2sparse_8cpp.html":[4,0,98],
-"spmdm_8cpp.html":[4,0,99],
-"tests_2src_2structured-matrices_8cpp.html":[4,0,100],
-"svd_8cpp.html":[4,0,101],
-"tql_8cpp.html":[4,0,102],
-"vector__float__double_8cpp.html":[4,0,103],
-"vector__int_8cpp.html":[4,0,104],
-"vector__multi__inner__prod_8cpp.html":[4,0,105],
-"vector__uint_8cpp.html":[4,0,106],
-"circulant__matrix_8hpp.html":[4,0,107],
-"compressed__compressed__matrix_8hpp.html":[4,0,108],
-"compressed__matrix_8hpp.html":[4,0,109],
-"context_8hpp.html":[4,0,110],
-"coordinate__matrix_8hpp.html":[4,0,111],
-"ell__matrix_8hpp.html":[4,0,112],
-"fft_8hpp.html":[4,0,113],
-"forwards_8h.html":[4,0,114],
-"hankel__matrix_8hpp.html":[4,0,115],
-"hyb__matrix_8hpp.html":[4,0,116],
-"matrix_8hpp.html":[4,0,117],
-"matrix__def_8hpp.html":[4,0,118],
-"matrix__proxy_8hpp.html":[4,0,119],
-"range_8hpp.html":[4,0,120],
-"scalar_8hpp.html":[4,0,121],
-"slice_8hpp.html":[4,0,122],
-"sliced__ell__matrix_8hpp.html":[4,0,123],
-"toeplitz__matrix_8hpp.html":[4,0,124],
-"vandermonde__matrix_8hpp.html":[4,0,125],
-"vector_8hpp.html":[4,0,126],
-"vector__def_8hpp.html":[4,0,127],
-"vector__proxy_8hpp.html":[4,0,128],
-"version_8hpp.html":[4,0,129],
-"cpu__ram_8hpp.html":[4,0,130],
-"cuda_8hpp.html":[4,0,131],
-"mem__handle_8hpp.html":[4,0,132],
-"memory_8hpp.html":[4,0,133],
-"opencl_8hpp.html":[4,0,134],
-"backend_2util_8hpp.html":[4,0,135],
-"device__specific_2execute_8hpp.html":[4,0,136],
-"execution__handler_8hpp.html":[4,0,137],
-"device__specific_2forwards_8h.html":[4,0,138],
-"lazy__program__compiler_8hpp.html":[4,0,139],
-"mapped__objects_8hpp.html":[4,0,140],
-"tree__parsing_8hpp.html":[4,0,141],
-"device__specific_2utils_8hpp.html":[4,0,142],
-"device__specific_2builtin__database_2common_8hpp.html":[4,0,143],
-"matrix__axpy_8hpp.html":[4,0,144],
-"matrix__product_8hpp.html":[4,0,145],
-"reduction_8hpp.html":[4,0,146],
-"row__wise__reduction_8hpp.html":[4,0,147],
-"vector__axpy_8hpp.html":[4,0,148],
-"accelerator_2fallback_8hpp.html":[4,0,149],
-"cpu_2fallback_8hpp.html":[4,0,150],
-"gpu_2fallback_8hpp.html":[4,0,151],
-"cypress_8hpp.html":[4,0,152],
-"devastator_8hpp.html":[4,0,153],
-"hawaii_8hpp.html":[4,0,154],
-"geforce__gt__540m_8hpp.html":[4,0,155],
-"matrix__axpy__template_8hpp.html":[4,0,156],
-"matrix__product__template_8hpp.html":[4,0,157],
-"reduction__template_8hpp.html":[4,0,158],
-"row__wise__reduction__template_8hpp.html":[4,0,159],
-"template__base_8hpp.html":[4,0,160],
-"device__specific_2templates_2utils_8hpp.html":[4,0,161],
-"vector__axpy__template_8hpp.html":[4,0,162],
-"matrix__market_8hpp.html":[4,0,163],
-"amg_8hpp.html":[4,0,164],
-"bicgstab_8hpp.html":[4,0,165],
-"bisect_8hpp.html":[4,0,166],
-"bisect__gpu_8hpp.html":[4,0,167],
-"cg_8hpp.html":[4,0,168],
-"circulant__matrix__operations_8hpp.html":[4,0,169],
-"direct__solve_8hpp.html":[4,0,170],
-"eig_8hpp.html":[4,0,171],
-"fft__operations_8hpp.html":[4,0,172],
-"gmres_8hpp.html":[4,0,173],
-"hankel__matrix__operations_8hpp.html":[4,0,174],
-"ichol_8hpp.html":[4,0,175],
-"ilu_8hpp.html":[4,0,176],
-"inner__prod_8hpp.html":[4,0,177],
-"iterative__operations_8hpp.html":[4,0,178],
-"jacobi__precond_8hpp.html":[4,0,179],
-"lanczos_8hpp.html":[4,0,180],
-"lu_8hpp.html":[4,0,181],
-"matrix__operations_8hpp.html":[4,0,182],
-"misc__operations_8hpp.html":[4,0,183],
-"mixed__precision__cg_8hpp.html":[4,0,184],
-"nmf__operations_8hpp.html":[4,0,185],
-"norm__1_8hpp.html":[4,0,186],
-"norm__2_8hpp.html":[4,0,187],
-"norm__frobenius_8hpp.html":[4,0,188],
-"norm__inf_8hpp.html":[4,0,189],
-"power__iter_8hpp.html":[4,0,190],
-"prod_8hpp.html":[4,0,191],
-"qr-method-common_8hpp.html":[4,0,192],
-"qr-method_8hpp.html":[4,0,193],
-"qr_8hpp.html":[4,0,194],
-"reduce_8hpp.html":[4,0,195],
-"row__scaling_8hpp.html":[4,0,196],
-"scalar__operations_8hpp.html":[4,0,197],
-"spai_8hpp.html":[4,0,198],
-"sparse__matrix__operations_8hpp.html":[4,0,199],
-"svd_8hpp.html":[4,0,200],
-"toeplitz__matrix__operations_8hpp.html":[4,0,201],
-"tql2_8hpp.html":[4,0,202],
-"tred2_8hpp.html":[4,0,203],
-"vandermonde__matrix__operations_8hpp.html":[4,0,204],
-"vector__operations_8hpp.html":[4,0,205],
-"cuda_2bisect__kernel__calls_8hpp.html":[4,0,206],
-"bisect__kernel__large_8hpp.html":[4,0,207],
-"bisect__kernel__large__multi_8hpp.html":[4,0,208],
-"bisect__kernel__large__onei_8hpp.html":[4,0,209],
-"bisect__kernel__small_8hpp.html":[4,0,210],
-"bisect__util_8hpp.html":[4,0,211],
-"linalg_2cuda_2common_8hpp.html":[4,0,212],
-"cuda_2direct__solve_8hpp.html":[4,0,213],
-"cuda_2fft__operations_8hpp.html":[4,0,214],
-"cuda_2iterative__operations_8hpp.html":[4,0,215],
-"cuda_2matrix__operations_8hpp.html":[4,0,216],
-"matrix__operations__col_8hpp.html":[4,0,217],
-"matrix__operations__prod_8hpp.html":[4,0,218],
-"matrix__operations__row_8hpp.html":[4,0,219],
-"cuda_2misc__operations_8hpp.html":[4,0,220],
-"cuda_2nmf__operations_8hpp.html":[4,0,221],
-"cuda_2scalar__operations_8hpp.html":[4,0,222],
-"cuda_2sparse__matrix__operations_8hpp.html":[4,0,223],
-"sparse__matrix__operations__solve_8hpp.html":[4,0,224],
-"cuda_2vector__operations_8hpp.html":[4,0,225],
-"op__applier_8hpp.html":[4,0,226],
-"op__executor_8hpp.html":[4,0,227],
-"amg__base_8hpp.html":[4,0,228],
-"amg__coarse_8hpp.html":[4,0,229],
-"amg__debug_8hpp.html":[4,0,230],
-"amg__interpol_8hpp.html":[4,0,231],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html":[4,0,232],
-"bisect__large_8hpp.html":[4,0,233],
-"bisect__small_8hpp.html":[4,0,234],
-"config_8hpp.html":[4,0,235],
-"gerschgorin_8hpp.html":[4,0,236],
-"structs_8hpp.html":[4,0,237],
-"linalg_2detail_2bisect_2util_8hpp.html":[4,0,238],
-"block__ilu_8hpp.html":[4,0,239],
-"linalg_2detail_2ilu_2common_8hpp.html":[4,0,240],
-"ilu0_8hpp.html":[4,0,241],
-"ilut_8hpp.html":[4,0,242],
-"block__matrix_8hpp.html":[4,0,243],
-"block__vector_8hpp.html":[4,0,244],
-"fspai_8hpp.html":[4,0,245],
-"detail_2spai_2qr_8hpp.html":[4,0,246],
-"small__matrix_8hpp.html":[4,0,247],
-"spai-dynamic_8hpp.html":[4,0,248],
-"spai-static_8hpp.html":[4,0,249],
-"detail_2spai_2spai_8hpp.html":[4,0,250],
-"spai__tag_8hpp.html":[4,0,251],
-"sparse__vector_8hpp.html":[4,0,252],
-"linalg_2host__based_2common_8hpp.html":[4,0,253],
-"host__based_2direct__solve_8hpp.html":[4,0,254],
-"host__based_2fft__operations_8hpp.html":[4,0,255],
-"host__based_2iterative__operations_8hpp.html":[4,0,256],
-"host__based_2matrix__operations_8hpp.html":[4,0,257],
-"host__based_2misc__operations_8hpp.html":[4,0,258],
-"host__based_2nmf__operations_8hpp.html":[4,0,259],
-"host__based_2scalar__operations_8hpp.html":[4,0,260],
-"host__based_2sparse__matrix__operations_8hpp.html":[4,0,261],
-"sse__blas_8hpp.html":[4,0,262],
-"sse__kernels_8hpp.html":[4,0,263],
-"host__based_2vector__operations_8hpp.html":[4,0,264],
-"opencl_2bisect__kernel__calls_8hpp.html":[4,0,265],
-"linalg_2opencl_2common_8hpp.html":[4,0,266],
-"opencl_2direct__solve_8hpp.html":[4,0,267],
-"opencl_2fft__operations_8hpp.html":[4,0,268],
-"opencl_2iterative__operations_8hpp.html":[4,0,269],
-"opencl_2matrix__operations_8hpp.html":[4,0,270],
-"opencl_2misc__operations_8hpp.html":[4,0,271],
-"opencl_2nmf__operations_8hpp.html":[4,0,272],
-"opencl_2scalar__operations_8hpp.html":[4,0,273],
-"opencl_2sparse__matrix__operations_8hpp.html":[4,0,274],
-"opencl_2vandermonde__matrix__operations_8hpp.html":[4,0,275],
-"opencl_2vector__operations_8hpp.html":[4,0,276],
-"opencl_2kernels_2bisect_8hpp.html":[4,0,277],
-"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html":[4,0,278],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html":[4,0,279],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[4,0,280],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[4,0,281],
-"linalg_2opencl_2kernels_2fft_8hpp.html":[4,0,282],
-"linalg_2opencl_2kernels_2hyb__matrix_8hpp.html":[4,0,283],
-"opencl_2kernels_2ilu_8hpp.html":[4,0,284],
-"iterative_8hpp.html":[4,0,285],
-"linalg_2opencl_2kernels_2matrix_8hpp.html":[4,0,286],
-"matrix__solve_8hpp.html":[4,0,287],
-"nmf_8hpp.html":[4,0,288],
-"linalg_2opencl_2kernels_2scalar_8hpp.html":[4,0,289],
-"linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp.html":[4,0,290],
-"opencl_2kernels_2spai_8hpp.html":[4,0,291],
-"opencl_2kernels_2svd_8hpp.html":[4,0,292],
-"linalg_2opencl_2kernels_2vector_8hpp.html":[4,0,293],
-"enable__if_8hpp.html":[4,0,294],
-"predicate_8hpp.html":[4,0,295],
-"result__of_8hpp.html":[4,0,296],
-"tag__of_8hpp.html":[4,0,297],
-"bandwidth__reduction_8hpp.html":[4,0,298],
-"cuthill__mckee_8hpp.html":[4,0,299],
-"gibbs__poole__stockmeyer_8hpp.html":[4,0,300],
-"backend_8hpp.html":[4,0,301],
-"command__queue_8hpp.html":[4,0,302],
-"ocl_2context_8hpp.html":[4,0,303],
-"device_8hpp.html":[4,0,304],
-"device__utils_8hpp.html":[4,0,305],
-"enqueue_8hpp.html":[4,0,306],
-"error_8hpp.html":[4,0,307],
-"ocl_2forwards_8h.html":[4,0,308],
-"ocl_2handle_8hpp.html":[4,0,309],
-"kernel_8hpp.html":[4,0,310],
-"local__mem_8hpp.html":[4,0,311],
-"platform_8hpp.html":[4,0,312],
-"program_8hpp.html":[4,0,313],
-"ocl_2utils_8hpp.html":[4,0,314],
-"gaussian_8hpp.html":[4,0,315],
-"uniform_8hpp.html":[4,0,316],
-"rand_2utils_8hpp.html":[4,0,317],
-"scheduler_2execute_8hpp.html":[4,0,318],
-"execute__axbx_8hpp.html":[4,0,319],
-"execute__elementwise_8hpp.html":[4,0,320],
-"execute__generic__dispatcher_8hpp.html":[4,0,321],
-"execute__matrix__dispatcher_8hpp.html":[4,0,322],
-"execute__matrix__prod_8hpp.html":[4,0,323],
-"execute__scalar__assign_8hpp.html":[4,0,324],
-"execute__scalar__dispatcher_8hpp.html":[4,0,325],
-"execute__util_8hpp.html":[4,0,326],
-"execute__vector__dispatcher_8hpp.html":[4,0,327],
-"scheduler_2forwards_8h.html":[4,0,328],
-"io_8hpp.html":[4,0,329],
-"preset_8hpp.html":[4,0,330],
-"adapter_8hpp.html":[4,0,331],
-"entry__proxy_8hpp.html":[4,0,332],
-"matrix__generation_8hpp.html":[4,0,333],
-"matrix__size__deducer_8hpp.html":[4,0,334],
-"sha1_8hpp.html":[4,0,335],
-"shared__ptr_8hpp.html":[4,0,336],
-"timer_8hpp.html":[4,0,337],
-"tools_8hpp.html":[4,0,338],
-"clear_8hpp.html":[4,0,339],
-"traits_2context_8hpp.html":[4,0,340],
-"fill_8hpp.html":[4,0,341],
-"traits_2handle_8hpp.html":[4,0,342],
-"row__major_8hpp.html":[4,0,343],
-"size_8hpp.html":[4,0,344],
-"start_8hpp.html":[4,0,345],
-"stride_8hpp.html":[4,0,346],
+"examples_2tutorial_2scheduler__matrix_8cpp.html":[4,0,37],
+"spai_8cpp.html":[4,0,38],
+"examples_2tutorial_2sparse_8cpp.html":[4,0,39],
+"examples_2tutorial_2structured-matrices_8cpp.html":[4,0,40],
+"tql2_8cpp.html":[4,0,41],
+"vector-io_8hpp.html":[4,0,42],
+"vector-range_8cpp.html":[4,0,43],
+"viennacl-info_8cpp.html":[4,0,44],
+"wrap-host-buffer_8cpp.html":[4,0,45],
+"viennacl_8hpp.html":[4,0,46],
+"backend_8cpp.html":[4,0,47],
+"libviennacl_2src_2blas1_8cpp.html":[4,0,48],
+"blas1__host_8cpp.html":[4,0,49],
+"blas1__opencl_8cpp.html":[4,0,50],
+"libviennacl_2src_2blas2_8cpp.html":[4,0,51],
+"blas2__host_8cpp.html":[4,0,52],
+"blas2__opencl_8cpp.html":[4,0,53],
+"libviennacl_2src_2blas3_8cpp.html":[4,0,54],
+"blas3_8hpp.html":[4,0,55],
+"blas3__host_8cpp.html":[4,0,56],
+"blas3__opencl_8cpp.html":[4,0,57],
+"init__matrix_8hpp.html":[4,0,58],
+"init__vector_8hpp.html":[4,0,59],
+"viennacl__private_8hpp.html":[4,0,60],
+"tests_2src_2bisect_8cpp.html":[4,0,61],
+"blas3__solve_8cpp.html":[4,0,62],
+"external__1_8cpp.html":[4,0,63],
+"external__2_8cpp.html":[4,0,64],
+"fft__1d_8cpp.html":[4,0,65],
+"fft__2d_8cpp.html":[4,0,66],
+"generator__blas1_8cpp.html":[4,0,67],
+"generator__blas2_8cpp.html":[4,0,68],
+"generator__blas3_8cpp.html":[4,0,69],
+"global__variables_8cpp.html":[4,0,70],
+"iterators_8cpp.html":[4,0,71],
+"libviennacl__blas1_8cpp.html":[4,0,72],
+"libviennacl__blas2_8cpp.html":[4,0,73],
+"libviennacl__blas3_8cpp.html":[4,0,74],
+"matrix__col__double_8cpp.html":[4,0,75],
+"matrix__col__float_8cpp.html":[4,0,76],
+"matrix__col__int_8cpp.html":[4,0,77],
+"matrix__float__double_8hpp.html":[4,0,78],
+"matrix__int_8hpp.html":[4,0,79],
+"matrix__product__double_8cpp.html":[4,0,80],
+"matrix__product__float_8cpp.html":[4,0,81],
+"matrix__product__float__double_8hpp.html":[4,0,82],
+"matrix__row__double_8cpp.html":[4,0,83],
+"matrix__row__float_8cpp.html":[4,0,84],
+"matrix__row__int_8cpp.html":[4,0,85],
+"matrix__vector_8cpp.html":[4,0,86],
+"matrix__vector__int_8cpp.html":[4,0,87],
+"tests_2src_2nmf_8cpp.html":[4,0,88],
+"tests_2src_2qr__method_8cpp.html":[4,0,89],
+"qr__method__func_8cpp.html":[4,0,90],
+"tests_2src_2_random_8hpp.html":[4,0,91],
+"scalar_8cpp.html":[4,0,92],
+"scan_8cpp.html":[4,0,93],
+"tests_2src_2scheduler__matrix_8cpp.html":[4,0,94],
+"scheduler__matrix__matrix_8cpp.html":[4,0,95],
+"scheduler__matrix__vector_8cpp.html":[4,0,96],
+"scheduler__sparse_8cpp.html":[4,0,97],
+"scheduler__vector_8cpp.html":[4,0,98],
+"tests_2src_2sparse_8cpp.html":[4,0,99],
+"spmdm_8cpp.html":[4,0,100],
+"tests_2src_2structured-matrices_8cpp.html":[4,0,101],
+"svd_8cpp.html":[4,0,102],
+"tql_8cpp.html":[4,0,103],
+"vector__float__double_8cpp.html":[4,0,104],
+"vector__int_8cpp.html":[4,0,105],
+"vector__multi__inner__prod_8cpp.html":[4,0,106],
+"vector__uint_8cpp.html":[4,0,107],
+"circulant__matrix_8hpp.html":[4,0,108],
+"compressed__compressed__matrix_8hpp.html":[4,0,109],
+"compressed__matrix_8hpp.html":[4,0,110],
+"context_8hpp.html":[4,0,111],
+"coordinate__matrix_8hpp.html":[4,0,112],
+"ell__matrix_8hpp.html":[4,0,113],
+"fft_8hpp.html":[4,0,114],
+"forwards_8h.html":[4,0,115],
+"hankel__matrix_8hpp.html":[4,0,116],
+"hyb__matrix_8hpp.html":[4,0,117],
+"matrix_8hpp.html":[4,0,118],
+"matrix__def_8hpp.html":[4,0,119],
+"matrix__proxy_8hpp.html":[4,0,120],
+"range_8hpp.html":[4,0,121],
+"scalar_8hpp.html":[4,0,122],
+"slice_8hpp.html":[4,0,123],
+"sliced__ell__matrix_8hpp.html":[4,0,124],
+"toeplitz__matrix_8hpp.html":[4,0,125],
+"vandermonde__matrix_8hpp.html":[4,0,126],
+"vector_8hpp.html":[4,0,127],
+"vector__def_8hpp.html":[4,0,128],
+"vector__proxy_8hpp.html":[4,0,129],
+"version_8hpp.html":[4,0,130],
+"cpu__ram_8hpp.html":[4,0,131],
+"cuda_8hpp.html":[4,0,132],
+"mem__handle_8hpp.html":[4,0,133],
+"memory_8hpp.html":[4,0,134],
+"opencl_8hpp.html":[4,0,135],
+"backend_2util_8hpp.html":[4,0,136],
+"device__specific_2execute_8hpp.html":[4,0,137],
+"execution__handler_8hpp.html":[4,0,138],
+"device__specific_2forwards_8h.html":[4,0,139],
+"lazy__program__compiler_8hpp.html":[4,0,140],
+"mapped__objects_8hpp.html":[4,0,141],
+"tree__parsing_8hpp.html":[4,0,142],
+"device__specific_2utils_8hpp.html":[4,0,143],
+"device__specific_2builtin__database_2common_8hpp.html":[4,0,144],
+"matrix__axpy_8hpp.html":[4,0,145],
+"matrix__product_8hpp.html":[4,0,146],
+"reduction_8hpp.html":[4,0,147],
+"row__wise__reduction_8hpp.html":[4,0,148],
+"vector__axpy_8hpp.html":[4,0,149],
+"accelerator_2fallback_8hpp.html":[4,0,150],
+"cpu_2fallback_8hpp.html":[4,0,151],
+"gpu_2fallback_8hpp.html":[4,0,152],
+"cypress_8hpp.html":[4,0,153],
+"devastator_8hpp.html":[4,0,154],
+"tahiti_8hpp.html":[4,0,155],
+"hawaii_8hpp.html":[4,0,156],
+"geforce__gt__540m_8hpp.html":[4,0,157],
+"geforce__gtx__580_8hpp.html":[4,0,158],
+"tesla__k20m_8hpp.html":[4,0,159],
+"matrix__axpy__template_8hpp.html":[4,0,160],
+"matrix__product__template_8hpp.html":[4,0,161],
+"reduction__template_8hpp.html":[4,0,162],
+"row__wise__reduction__template_8hpp.html":[4,0,163],
+"template__base_8hpp.html":[4,0,164],
+"device__specific_2templates_2utils_8hpp.html":[4,0,165],
+"vector__axpy__template_8hpp.html":[4,0,166],
+"matrix__market_8hpp.html":[4,0,167],
+"amg_8hpp.html":[4,0,168],
+"bicgstab_8hpp.html":[4,0,169],
+"bisect_8hpp.html":[4,0,170],
+"bisect__gpu_8hpp.html":[4,0,171],
+"cg_8hpp.html":[4,0,172],
+"circulant__matrix__operations_8hpp.html":[4,0,173],
+"direct__solve_8hpp.html":[4,0,174],
+"eig_8hpp.html":[4,0,175],
+"fft__operations_8hpp.html":[4,0,176],
+"gmres_8hpp.html":[4,0,177],
+"hankel__matrix__operations_8hpp.html":[4,0,178],
+"ichol_8hpp.html":[4,0,179],
+"ilu_8hpp.html":[4,0,180],
+"inner__prod_8hpp.html":[4,0,181],
+"iterative__operations_8hpp.html":[4,0,182],
+"jacobi__precond_8hpp.html":[4,0,183],
+"lanczos_8hpp.html":[4,0,184],
+"lu_8hpp.html":[4,0,185],
+"matrix__operations_8hpp.html":[4,0,186],
+"misc__operations_8hpp.html":[4,0,187],
+"mixed__precision__cg_8hpp.html":[4,0,188],
+"nmf__operations_8hpp.html":[4,0,189],
+"norm__1_8hpp.html":[4,0,190],
+"norm__2_8hpp.html":[4,0,191],
+"norm__frobenius_8hpp.html":[4,0,192],
+"norm__inf_8hpp.html":[4,0,193],
+"power__iter_8hpp.html":[4,0,194],
+"prod_8hpp.html":[4,0,195],
+"qr-method-common_8hpp.html":[4,0,196],
+"qr-method_8hpp.html":[4,0,197],
+"qr_8hpp.html":[4,0,198],
+"reduce_8hpp.html":[4,0,199],
+"row__scaling_8hpp.html":[4,0,200],
+"scalar__operations_8hpp.html":[4,0,201],
+"spai_8hpp.html":[4,0,202],
+"sparse__matrix__operations_8hpp.html":[4,0,203],
+"svd_8hpp.html":[4,0,204],
+"toeplitz__matrix__operations_8hpp.html":[4,0,205],
+"tql2_8hpp.html":[4,0,206],
+"tred2_8hpp.html":[4,0,207],
+"vandermonde__matrix__operations_8hpp.html":[4,0,208],
+"vector__operations_8hpp.html":[4,0,209],
+"cuda_2bisect__kernel__calls_8hpp.html":[4,0,210],
+"bisect__kernel__large_8hpp.html":[4,0,211],
+"bisect__kernel__large__multi_8hpp.html":[4,0,212],
+"bisect__kernel__large__onei_8hpp.html":[4,0,213],
+"bisect__kernel__small_8hpp.html":[4,0,214],
+"bisect__util_8hpp.html":[4,0,215],
+"linalg_2cuda_2common_8hpp.html":[4,0,216],
+"cuda_2direct__solve_8hpp.html":[4,0,217],
+"cuda_2fft__operations_8hpp.html":[4,0,218],
+"cuda_2iterative__operations_8hpp.html":[4,0,219],
+"cuda_2matrix__operations_8hpp.html":[4,0,220],
+"matrix__operations__col_8hpp.html":[4,0,221],
+"matrix__operations__prod_8hpp.html":[4,0,222],
+"matrix__operations__row_8hpp.html":[4,0,223],
+"cuda_2misc__operations_8hpp.html":[4,0,224],
+"cuda_2nmf__operations_8hpp.html":[4,0,225],
+"cuda_2scalar__operations_8hpp.html":[4,0,226],
+"cuda_2sparse__matrix__operations_8hpp.html":[4,0,227],
+"sparse__matrix__operations__solve_8hpp.html":[4,0,228],
+"cuda_2vector__operations_8hpp.html":[4,0,229],
+"op__applier_8hpp.html":[4,0,230],
+"op__executor_8hpp.html":[4,0,231],
+"amg__base_8hpp.html":[4,0,232],
+"amg__coarse_8hpp.html":[4,0,233],
+"amg__debug_8hpp.html":[4,0,234],
+"amg__interpol_8hpp.html":[4,0,235],
+"detail_2bisect_2bisect__kernel__calls_8hpp.html":[4,0,236],
+"bisect__large_8hpp.html":[4,0,237],
+"bisect__small_8hpp.html":[4,0,238],
+"config_8hpp.html":[4,0,239],
+"gerschgorin_8hpp.html":[4,0,240],
+"structs_8hpp.html":[4,0,241],
+"linalg_2detail_2bisect_2util_8hpp.html":[4,0,242],
+"block__ilu_8hpp.html":[4,0,243],
+"linalg_2detail_2ilu_2common_8hpp.html":[4,0,244],
+"ilu0_8hpp.html":[4,0,245],
+"ilut_8hpp.html":[4,0,246],
+"block__matrix_8hpp.html":[4,0,247],
+"block__vector_8hpp.html":[4,0,248],
+"fspai_8hpp.html":[4,0,249],
+"detail_2spai_2qr_8hpp.html":[4,0,250],
+"small__matrix_8hpp.html":[4,0,251],
+"spai-dynamic_8hpp.html":[4,0,252],
+"spai-static_8hpp.html":[4,0,253],
+"detail_2spai_2spai_8hpp.html":[4,0,254],
+"spai__tag_8hpp.html":[4,0,255],
+"sparse__vector_8hpp.html":[4,0,256],
+"linalg_2host__based_2common_8hpp.html":[4,0,257],
+"host__based_2direct__solve_8hpp.html":[4,0,258],
+"host__based_2fft__operations_8hpp.html":[4,0,259],
+"host__based_2iterative__operations_8hpp.html":[4,0,260],
+"host__based_2matrix__operations_8hpp.html":[4,0,261],
+"host__based_2misc__operations_8hpp.html":[4,0,262],
+"host__based_2nmf__operations_8hpp.html":[4,0,263],
+"host__based_2scalar__operations_8hpp.html":[4,0,264],
+"host__based_2sparse__matrix__operations_8hpp.html":[4,0,265],
+"sse__blas_8hpp.html":[4,0,266],
+"sse__kernels_8hpp.html":[4,0,267],
+"host__based_2vector__operations_8hpp.html":[4,0,268],
+"opencl_2bisect__kernel__calls_8hpp.html":[4,0,269],
+"linalg_2opencl_2common_8hpp.html":[4,0,270],
+"opencl_2direct__solve_8hpp.html":[4,0,271],
+"opencl_2fft__operations_8hpp.html":[4,0,272],
+"opencl_2iterative__operations_8hpp.html":[4,0,273],
+"opencl_2matrix__operations_8hpp.html":[4,0,274],
+"opencl_2misc__operations_8hpp.html":[4,0,275],
+"opencl_2nmf__operations_8hpp.html":[4,0,276],
+"opencl_2scalar__operations_8hpp.html":[4,0,277],
+"opencl_2sparse__matrix__operations_8hpp.html":[4,0,278],
+"opencl_2vandermonde__matrix__operations_8hpp.html":[4,0,279],
+"opencl_2vector__operations_8hpp.html":[4,0,280],
+"opencl_2kernels_2bisect_8hpp.html":[4,0,281],
+"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html":[4,0,282],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html":[4,0,283],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[4,0,284],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[4,0,285],
+"linalg_2opencl_2kernels_2fft_8hpp.html":[4,0,286],
+"linalg_2opencl_2kernels_2hyb__matrix_8hpp.html":[4,0,287],
+"opencl_2kernels_2ilu_8hpp.html":[4,0,288],
+"iterative_8hpp.html":[4,0,289],
+"linalg_2opencl_2kernels_2matrix_8hpp.html":[4,0,290],
+"matrix__solve_8hpp.html":[4,0,291],
+"nmf_8hpp.html":[4,0,292],
+"linalg_2opencl_2kernels_2scalar_8hpp.html":[4,0,293],
+"linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp.html":[4,0,294],
+"opencl_2kernels_2spai_8hpp.html":[4,0,295],
+"opencl_2kernels_2svd_8hpp.html":[4,0,296],
+"linalg_2opencl_2kernels_2vector_8hpp.html":[4,0,297],
+"enable__if_8hpp.html":[4,0,298],
+"predicate_8hpp.html":[4,0,299],
+"result__of_8hpp.html":[4,0,300],
+"tag__of_8hpp.html":[4,0,301],
+"bandwidth__reduction_8hpp.html":[4,0,302],
+"cuthill__mckee_8hpp.html":[4,0,303],
+"gibbs__poole__stockmeyer_8hpp.html":[4,0,304],
+"backend_8hpp.html":[4,0,305],
+"command__queue_8hpp.html":[4,0,306],
+"ocl_2context_8hpp.html":[4,0,307],
+"device_8hpp.html":[4,0,308],
+"device__utils_8hpp.html":[4,0,309],
+"enqueue_8hpp.html":[4,0,310],
+"error_8hpp.html":[4,0,311],
+"ocl_2forwards_8h.html":[4,0,312],
+"ocl_2handle_8hpp.html":[4,0,313],
+"kernel_8hpp.html":[4,0,314],
+"local__mem_8hpp.html":[4,0,315],
+"platform_8hpp.html":[4,0,316],
+"program_8hpp.html":[4,0,317],
+"ocl_2utils_8hpp.html":[4,0,318],
+"gaussian_8hpp.html":[4,0,319],
+"uniform_8hpp.html":[4,0,320],
+"rand_2utils_8hpp.html":[4,0,321],
+"scheduler_2execute_8hpp.html":[4,0,322],
+"execute__axbx_8hpp.html":[4,0,323],
+"execute__elementwise_8hpp.html":[4,0,324],
+"execute__generic__dispatcher_8hpp.html":[4,0,325],
+"execute__matrix__dispatcher_8hpp.html":[4,0,326],
+"execute__matrix__prod_8hpp.html":[4,0,327],
+"execute__scalar__assign_8hpp.html":[4,0,328],
+"execute__scalar__dispatcher_8hpp.html":[4,0,329],
+"execute__util_8hpp.html":[4,0,330],
+"execute__vector__dispatcher_8hpp.html":[4,0,331],
+"scheduler_2forwards_8h.html":[4,0,332],
+"io_8hpp.html":[4,0,333],
+"preset_8hpp.html":[4,0,334],
+"adapter_8hpp.html":[4,0,335],
+"entry__proxy_8hpp.html":[4,0,336],
+"matrix__generation_8hpp.html":[4,0,337],
+"matrix__size__deducer_8hpp.html":[4,0,338],
+"sha1_8hpp.html":[4,0,339],
+"shared__ptr_8hpp.html":[4,0,340],
+"timer_8hpp.html":[4,0,341],
+"tools_8hpp.html":[4,0,342],
+"clear_8hpp.html":[4,0,343],
+"traits_2context_8hpp.html":[4,0,344],
+"fill_8hpp.html":[4,0,345],
+"traits_2handle_8hpp.html":[4,0,346],
+"row__major_8hpp.html":[4,0,347],
+"size_8hpp.html":[4,0,348],
+"start_8hpp.html":[4,0,349],
+"stride_8hpp.html":[4,0,350],
 "globals.html":[4,1,0],
 "globals.html":[4,1,0,0],
 "globals_0x62.html":[4,1,0,1],
