@@ -1,25 +1,5 @@
 var NAVTREEINDEX13 =
 {
-"globals_vars.html":[7,1,2],
-"gmres_8hpp.html":[7,0,3,4,13],
-"gmres_8hpp.html#a29d6b53b3a99961196a859fa7ef46537":[7,0,3,4,13,4],
-"gmres_8hpp.html#a7714c5d2a59986f4c2cd9fdb47817ba0":[7,0,3,4,13,5],
-"gmres_8hpp.html#a9dace8e3f8cafdc7c5b56282860e5a97":[7,0,3,4,13,1],
-"gmres_8hpp.html#ac34f2a4be7c82ecf4fd10e05ecc24273":[7,0,3,4,13,7],
-"gmres_8hpp.html#ad2b2c8a343124143d1ddc2fee8b2ce73":[7,0,3,4,13,3],
-"gmres_8hpp.html#af6c0a087d090d74573763d9dd48c9074":[7,0,3,4,13,6],
-"gmres_8hpp.html#afb24b0bd7c338eff5ecf6b8b35f2757a":[7,0,3,4,13,2],
-"gmres_8hpp_source.html":[7,0,3,4,13],
-"gpu_2fallback_8hpp.html":[7,0,3,2,0,0,2,2],
-"gpu_2fallback_8hpp.html#a165e05191585908e619174cc89662cd1":[7,0,3,2,0,0,2,2,1],
-"gpu_2fallback_8hpp.html#a1c59b69f8e3bd9a3ac749254166e5631":[7,0,3,2,0,0,2,2,16],
-"gpu_2fallback_8hpp.html#a24f3d26d0f7d3f109909cc5c748e0a55":[7,0,3,2,0,0,2,2,9],
-"gpu_2fallback_8hpp.html#a33a37096f9f0ea65e8798e844f645f1b":[7,0,3,2,0,0,2,2,13],
-"gpu_2fallback_8hpp.html#a33b18acc254b1857b13e7e4889410e5d":[7,0,3,2,0,0,2,2,11],
-"gpu_2fallback_8hpp.html#a3476b3346a369ec706b48c711e184883":[7,0,3,2,0,0,2,2,12],
-"gpu_2fallback_8hpp.html#a4d19637e7dcb5012d9c60fffa561d959":[7,0,3,2,0,0,2,2,3],
-"gpu_2fallback_8hpp.html#a575cb62848f2516a12eb405d29a91d92":[7,0,3,2,0,0,2,2,2],
-"gpu_2fallback_8hpp.html#a5764b80284de678fd73c0675cd28e41a":[7,0,3,2,0,0,2,2,8],
 "gpu_2fallback_8hpp.html#a5976cb702fa7ae70988337ea3f87d18a":[7,0,3,2,0,0,2,2,15],
 "gpu_2fallback_8hpp.html#a658d72b419715ea281694759c006f2ee":[7,0,3,2,0,0,2,2,17],
 "gpu_2fallback_8hpp.html#a6cde4bbd0b6de4556e43668c0451a65b":[7,0,3,2,0,0,2,2,10],
@@ -62,23 +42,20 @@ var NAVTREEINDEX13 =
 "hawaii_8hpp_source.html":[7,0,3,2,0,0,2,0,3,0],
 "hierarchy.html":[6,2],
 "host__based_2direct__solve_8hpp.html":[7,0,3,4,2,1],
-"host__based_2direct__solve_8hpp.html#a10c37c9c6eefea85aaae14a1b6872d85":[7,0,3,4,2,1,7],
-"host__based_2direct__solve_8hpp.html#a3055f9817cac10e4a8c0dbb58b283d0b":[7,0,3,4,2,1,10],
-"host__based_2direct__solve_8hpp.html#a38989d09acd0c0763276fd94123e9d51":[7,0,3,4,2,1,15],
-"host__based_2direct__solve_8hpp.html#a3c508843dc43b682cfc869aaeff8c40d":[7,0,3,4,2,1,9],
-"host__based_2direct__solve_8hpp.html#a403fe72a464f4740ef24f503021c3250":[7,0,3,4,2,1,6],
-"host__based_2direct__solve_8hpp.html#a7960189e297c0b1912eedc6444f04c80":[7,0,3,4,2,1,11],
-"host__based_2direct__solve_8hpp.html#a96090fa88ab45b1c22ffc5038ce17b2d":[7,0,3,4,2,1,16],
-"host__based_2direct__solve_8hpp.html#aa072bcdeba22f9f70efdb3daa92cdc3c":[7,0,3,4,2,1,2],
-"host__based_2direct__solve_8hpp.html#aa32680534256aabf4851c1e6ab429966":[7,0,3,4,2,1,8],
-"host__based_2direct__solve_8hpp.html#aab6a9010a6db51e4611423ae57637050":[7,0,3,4,2,1,0],
-"host__based_2direct__solve_8hpp.html#abbb3c1e4a509f6e151e4bc54ad183333":[7,0,3,4,2,1,4],
-"host__based_2direct__solve_8hpp.html#abfc23de72edd1a0de0fa6484f3e2520a":[7,0,3,4,2,1,14],
-"host__based_2direct__solve_8hpp.html#ac8d849341066e2adcf63a64827dea1c8":[7,0,3,4,2,1,13],
-"host__based_2direct__solve_8hpp.html#ac8f313c98e01be6f1b3d663aa726a1d5":[7,0,3,4,2,1,3],
-"host__based_2direct__solve_8hpp.html#ac98eccc8d07dcf787097c5d3f1da526a":[7,0,3,4,2,1,12],
-"host__based_2direct__solve_8hpp.html#ac9d51c78fe96e462287ec111bf6bfbac":[7,0,3,4,2,1,5],
-"host__based_2direct__solve_8hpp.html#af1f292e350561f288283a499e483c6be":[7,0,3,4,2,1,1],
+"host__based_2direct__solve_8hpp.html#a10c37c9c6eefea85aaae14a1b6872d85":[7,0,3,4,2,1,4],
+"host__based_2direct__solve_8hpp.html#a3055f9817cac10e4a8c0dbb58b283d0b":[7,0,3,4,2,1,7],
+"host__based_2direct__solve_8hpp.html#a38989d09acd0c0763276fd94123e9d51":[7,0,3,4,2,1,12],
+"host__based_2direct__solve_8hpp.html#a3c508843dc43b682cfc869aaeff8c40d":[7,0,3,4,2,1,6],
+"host__based_2direct__solve_8hpp.html#a403fe72a464f4740ef24f503021c3250":[7,0,3,4,2,1,3],
+"host__based_2direct__solve_8hpp.html#a694a9feaf70ec0f8a096ed91cd354208":[7,0,3,4,2,1,1],
+"host__based_2direct__solve_8hpp.html#a7960189e297c0b1912eedc6444f04c80":[7,0,3,4,2,1,8],
+"host__based_2direct__solve_8hpp.html#a96090fa88ab45b1c22ffc5038ce17b2d":[7,0,3,4,2,1,13],
+"host__based_2direct__solve_8hpp.html#aa32680534256aabf4851c1e6ab429966":[7,0,3,4,2,1,5],
+"host__based_2direct__solve_8hpp.html#abfc23de72edd1a0de0fa6484f3e2520a":[7,0,3,4,2,1,11],
+"host__based_2direct__solve_8hpp.html#ac8d849341066e2adcf63a64827dea1c8":[7,0,3,4,2,1,10],
+"host__based_2direct__solve_8hpp.html#ac98eccc8d07dcf787097c5d3f1da526a":[7,0,3,4,2,1,9],
+"host__based_2direct__solve_8hpp.html#ac9d51c78fe96e462287ec111bf6bfbac":[7,0,3,4,2,1,2],
+"host__based_2direct__solve_8hpp.html#af83ff307c97a945a568c30253c1a7c61":[7,0,3,4,2,1,0],
 "host__based_2direct__solve_8hpp_source.html":[7,0,3,4,2,1],
 "host__based_2fft__operations_8hpp.html":[7,0,3,4,2,2],
 "host__based_2fft__operations_8hpp.html#a02ce2b0b08798d0a794c19a8d3ee3108":[7,0,3,4,2,2,22],
@@ -243,11 +220,34 @@ var NAVTREEINDEX13 =
 "host__based_2vector__operations_8hpp_source.html":[7,0,3,4,2,11],
 "hyb__matrix_8hpp.html":[7,0,3,20],
 "hyb__matrix_8hpp.html#a3eccd807b53d2713366addeaf1137bae":[7,0,3,20,1],
-"hyb__matrix_8hpp.html#aee077076d127c528b236cc78ff6b8bbe":[7,0,3,20,2],
+"hyb__matrix_8hpp.html#ad947ef8abf3c3cd4f69649b01ffb6d7e":[7,0,3,20,4],
+"hyb__matrix_8hpp.html#aee077076d127c528b236cc78ff6b8bbe":[7,0,3,20,3],
+"hyb__matrix_8hpp.html#aef3fd50d62ce69e229ebdc92f9ddb6a6":[7,0,3,20,2],
 "hyb__matrix_8hpp_source.html":[7,0,3,20],
 "ichol_8hpp.html":[7,0,3,4,15],
 "ichol_8hpp.html#a674c204660f61ec3c8b881fe86ef1dfd":[7,0,3,4,15,3],
 "ichol_8hpp_source.html":[7,0,3,4,15],
 "ilu0_8hpp.html":[7,0,3,4,1,2,2],
-"ilu0_8hpp.html#ae92ae6061c4ac82fdea8230c9877badc":[7,0,3,4,1,2,2,3]
+"ilu0_8hpp.html#ae92ae6061c4ac82fdea8230c9877badc":[7,0,3,4,1,2,2,3],
+"ilu0_8hpp_source.html":[7,0,3,4,1,2,2],
+"ilu_8hpp.html":[7,0,3,4,16],
+"ilu_8hpp_source.html":[7,0,3,4,16],
+"ilut_8hpp.html":[7,0,3,4,1,2,3],
+"ilut_8hpp.html#a18218af41096d0913c54322e022d780d":[7,0,3,4,1,2,3,5],
+"ilut_8hpp.html#a39ed99a266c4ca46f851316297ce9bf6":[7,0,3,4,1,2,3,3],
+"ilut_8hpp.html#a79537640cb9e9f4dd0be0024143860b1":[7,0,3,4,1,2,3,4],
+"ilut_8hpp_source.html":[7,0,3,4,1,2,3],
+"index.html":[],
+"index.html":[0],
+"init__matrix_8hpp.html":[7,0,1,1,11],
+"init__matrix_8hpp_source.html":[7,0,1,1,11],
+"init__vector_8hpp.html":[7,0,1,1,12],
+"init__vector_8hpp_source.html":[7,0,1,1,12],
+"inner__prod_8hpp.html":[7,0,3,4,17],
+"inner__prod_8hpp.html#a3d9ef35327424393d599467538882522":[7,0,3,4,17,5],
+"inner__prod_8hpp.html#aac998ca060d47ba7c4b8bc1a994060ac":[7,0,3,4,17,4],
+"inner__prod_8hpp.html#ab35950c4374eb3be08a03d852508c01a":[7,0,3,4,17,0],
+"inner__prod_8hpp.html#ac71bae6daf6dc8a5803071f79565582a":[7,0,3,4,17,3],
+"inner__prod_8hpp.html#ad273e72f4a44fcd9802e3609d06af5e6":[7,0,3,4,17,1],
+"inner__prod_8hpp.html#ae4c12bee75a1dff46f0bd4b48abca2a5":[7,0,3,4,17,2]
 };
