@@ -1,26 +1,5 @@
 var NAVTREEINDEX14 =
 {
-"ilu0_8hpp_source.html":[7,0,3,4,1,2,2],
-"ilu_8hpp.html":[7,0,3,4,16],
-"ilu_8hpp_source.html":[7,0,3,4,16],
-"ilut_8hpp.html":[7,0,3,4,1,2,3],
-"ilut_8hpp.html#a18218af41096d0913c54322e022d780d":[7,0,3,4,1,2,3,5],
-"ilut_8hpp.html#a39ed99a266c4ca46f851316297ce9bf6":[7,0,3,4,1,2,3,3],
-"ilut_8hpp.html#a79537640cb9e9f4dd0be0024143860b1":[7,0,3,4,1,2,3,4],
-"ilut_8hpp_source.html":[7,0,3,4,1,2,3],
-"index.html":[],
-"index.html":[0],
-"init__matrix_8hpp.html":[7,0,1,1,11],
-"init__matrix_8hpp_source.html":[7,0,1,1,11],
-"init__vector_8hpp.html":[7,0,1,1,12],
-"init__vector_8hpp_source.html":[7,0,1,1,12],
-"inner__prod_8hpp.html":[7,0,3,4,17],
-"inner__prod_8hpp.html#a3d9ef35327424393d599467538882522":[7,0,3,4,17,5],
-"inner__prod_8hpp.html#aac998ca060d47ba7c4b8bc1a994060ac":[7,0,3,4,17,4],
-"inner__prod_8hpp.html#ab35950c4374eb3be08a03d852508c01a":[7,0,3,4,17,0],
-"inner__prod_8hpp.html#ac71bae6daf6dc8a5803071f79565582a":[7,0,3,4,17,3],
-"inner__prod_8hpp.html#ad273e72f4a44fcd9802e3609d06af5e6":[7,0,3,4,17,1],
-"inner__prod_8hpp.html#ae4c12bee75a1dff46f0bd4b48abca2a5":[7,0,3,4,17,2],
 "inner__prod_8hpp_source.html":[7,0,3,4,17],
 "io_8hpp.html":[7,0,3,8,11],
 "io_8hpp.html#a2642d47c8e7a49835d0512734863e664":[7,0,3,8,11,3],
@@ -79,10 +58,10 @@ var NAVTREEINDEX14 =
 "iterative__operations_8hpp.html#ab66c2c1f1a8eb05b116d9b1274243b38":[7,0,3,4,18,0],
 "iterative__operations_8hpp.html#ad5aba6fa27cb6e14b04f527c64a10196":[7,0,3,4,18,4],
 "iterative__operations_8hpp_source.html":[7,0,3,4,18],
-"iterators_8cpp.html":[7,0,2,0,10],
-"iterators_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,10,1],
-"iterators_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,10,0],
-"iterators_8cpp_source.html":[7,0,2,0,10],
+"iterators_8cpp.html":[7,0,2,0,7],
+"iterators_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,7,1],
+"iterators_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,7,0],
+"iterators_8cpp_source.html":[7,0,2,0,7],
 "jacobi__precond_8hpp.html":[7,0,3,4,19],
 "jacobi__precond_8hpp_source.html":[7,0,3,4,19],
 "kernel_8hpp.html":[7,0,3,7,9],
@@ -129,28 +108,28 @@ var NAVTREEINDEX14 =
 "libviennacl_2src_2blas3_8cpp_source.html":[7,0,1,1,7],
 "libviennacl_8cpp.html":[7,0,0,1,17],
 "libviennacl_8cpp_source.html":[7,0,0,1,17],
-"libviennacl__blas1_8cpp.html":[7,0,2,0,11],
-"libviennacl__blas1_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,11,1],
-"libviennacl__blas1_8cpp.html#a6bf7fe4754c57bc8bc55f4a2647f8a49":[7,0,2,0,11,2],
-"libviennacl__blas1_8cpp.html#ade615bbf93f6f668af70fb8e6b427d17":[7,0,2,0,11,0],
-"libviennacl__blas1_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,11,3],
-"libviennacl__blas1_8cpp_source.html":[7,0,2,0,11],
-"libviennacl__blas2_8cpp.html":[7,0,2,0,12],
-"libviennacl__blas2_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,12,1],
-"libviennacl__blas2_8cpp.html#a6bf7fe4754c57bc8bc55f4a2647f8a49":[7,0,2,0,12,2],
-"libviennacl__blas2_8cpp.html#ade615bbf93f6f668af70fb8e6b427d17":[7,0,2,0,12,0],
-"libviennacl__blas2_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,12,3],
-"libviennacl__blas2_8cpp_source.html":[7,0,2,0,12],
-"libviennacl__blas3_8cpp.html":[7,0,2,0,13],
-"libviennacl__blas3_8cpp.html#a0aa40911e4364bee4ee61d65ed25da30":[7,0,2,0,13,7],
-"libviennacl__blas3_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,13,1],
-"libviennacl__blas3_8cpp.html#a6bf7fe4754c57bc8bc55f4a2647f8a49":[7,0,2,0,13,2],
-"libviennacl__blas3_8cpp.html#a6e10b4809597e1ee89055ad971e3da6b":[7,0,2,0,13,5],
-"libviennacl__blas3_8cpp.html#a7af13aac94a977123ecc5f486ca97a16":[7,0,2,0,13,6],
-"libviennacl__blas3_8cpp.html#a92f64d4fde59ac6cf59aa0e74b92e732":[7,0,2,0,13,3],
-"libviennacl__blas3_8cpp.html#ade615bbf93f6f668af70fb8e6b427d17":[7,0,2,0,13,0],
-"libviennacl__blas3_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,13,4],
-"libviennacl__blas3_8cpp_source.html":[7,0,2,0,13],
+"libviennacl__blas1_8cpp.html":[7,0,2,0,8],
+"libviennacl__blas1_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,8,1],
+"libviennacl__blas1_8cpp.html#a6bf7fe4754c57bc8bc55f4a2647f8a49":[7,0,2,0,8,2],
+"libviennacl__blas1_8cpp.html#ade615bbf93f6f668af70fb8e6b427d17":[7,0,2,0,8,0],
+"libviennacl__blas1_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,8,3],
+"libviennacl__blas1_8cpp_source.html":[7,0,2,0,8],
+"libviennacl__blas2_8cpp.html":[7,0,2,0,9],
+"libviennacl__blas2_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,9,1],
+"libviennacl__blas2_8cpp.html#a6bf7fe4754c57bc8bc55f4a2647f8a49":[7,0,2,0,9,2],
+"libviennacl__blas2_8cpp.html#ade615bbf93f6f668af70fb8e6b427d17":[7,0,2,0,9,0],
+"libviennacl__blas2_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,9,3],
+"libviennacl__blas2_8cpp_source.html":[7,0,2,0,9],
+"libviennacl__blas3_8cpp.html":[7,0,2,0,10],
+"libviennacl__blas3_8cpp.html#a0aa40911e4364bee4ee61d65ed25da30":[7,0,2,0,10,7],
+"libviennacl__blas3_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,10,1],
+"libviennacl__blas3_8cpp.html#a6bf7fe4754c57bc8bc55f4a2647f8a49":[7,0,2,0,10,2],
+"libviennacl__blas3_8cpp.html#a6e10b4809597e1ee89055ad971e3da6b":[7,0,2,0,10,5],
+"libviennacl__blas3_8cpp.html#a7af13aac94a977123ecc5f486ca97a16":[7,0,2,0,10,6],
+"libviennacl__blas3_8cpp.html#a92f64d4fde59ac6cf59aa0e74b92e732":[7,0,2,0,10,3],
+"libviennacl__blas3_8cpp.html#ade615bbf93f6f668af70fb8e6b427d17":[7,0,2,0,10,0],
+"libviennacl__blas3_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,10,4],
+"libviennacl__blas3_8cpp_source.html":[7,0,2,0,10],
 "linalg_2cuda_2common_8hpp.html":[7,0,3,4,0,6],
 "linalg_2cuda_2common_8hpp.html#a125a7aa551d23d929ecb528342a7e20b":[7,0,3,4,0,6,19],
 "linalg_2cuda_2common_8hpp.html#a126ca9ddbc9e3103e8d1c108d719f52a":[7,0,3,4,0,6,15],
@@ -249,5 +228,26 @@ var NAVTREEINDEX14 =
 "linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#adae8b4e52dfd836b1ca21ec19f9514a7":[7,0,3,4,3,0,2,5],
 "linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#ae2bf04c2598b9482f3b9bd5f3e2865fb":[7,0,3,4,3,0,2,4],
 "linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#af37f85ae0d4cee5a2ab550de681da27b":[7,0,3,4,3,0,2,1],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp_source.html":[7,0,3,4,3,0,2]
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp_source.html":[7,0,3,4,3,0,2],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[7,0,3,4,3,0,3],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a23ff7b816118c0d1bef3965ae3ef941b":[7,0,3,4,3,0,3,1],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a4a3dd26085bc1f2f42717d6cd25371b0":[7,0,3,4,3,0,3,3],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a64f3806d00d953c07d3c31e4514b17eb":[7,0,3,4,3,0,3,2],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#afd2bb5a0a4802b32b6ffe26036395755":[7,0,3,4,3,0,3,4],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp_source.html":[7,0,3,4,3,0,3],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[7,0,3,4,3,0,4],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#a7868cd7436d34ded05a200226df77b75":[7,0,3,4,3,0,4,3],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aaab30445458756f2a6b9e4afd54feafc":[7,0,3,4,3,0,4,1],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aff4ab5e5474e310e09eb03a10aaa6844":[7,0,3,4,3,0,4,2],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp_source.html":[7,0,3,4,3,0,4],
+"linalg_2opencl_2kernels_2fft_8hpp.html":[7,0,3,4,3,0,5],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a03d946ea93037f1a394325d1c524383b":[7,0,3,4,3,0,5,8],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a056ee100af7f100796c7e6893617c1cb":[7,0,3,4,3,0,5,5],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a08dcb168fcfe7292634e1d15e0ecb577":[7,0,3,4,3,0,5,2],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a1953cd9bfa9ae539106f7d5364488f20":[7,0,3,4,3,0,5,3],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a5bc438da1adb4fe04d869bbe9318d2db":[7,0,3,4,3,0,5,9],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a72c23e31b4c043ac2a373988576f7aa8":[7,0,3,4,3,0,5,7],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a829073b7bfc3c121a1baba87a595462a":[7,0,3,4,3,0,5,4],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a909a503c6a235fdff7b7d95900513dc3":[7,0,3,4,3,0,5,6],
+"linalg_2opencl_2kernels_2fft_8hpp.html#acbcd37b7373b647d9eb2d93e77902ba2":[7,0,3,4,3,0,5,10]
 };
