@@ -1,26 +1,5 @@
 var NAVTREEINDEX15 =
 {
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[7,0,3,4,3,0,3],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a23ff7b816118c0d1bef3965ae3ef941b":[7,0,3,4,3,0,3,1],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a4a3dd26085bc1f2f42717d6cd25371b0":[7,0,3,4,3,0,3,3],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a64f3806d00d953c07d3c31e4514b17eb":[7,0,3,4,3,0,3,2],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#afd2bb5a0a4802b32b6ffe26036395755":[7,0,3,4,3,0,3,4],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp_source.html":[7,0,3,4,3,0,3],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[7,0,3,4,3,0,4],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#a7868cd7436d34ded05a200226df77b75":[7,0,3,4,3,0,4,3],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aaab30445458756f2a6b9e4afd54feafc":[7,0,3,4,3,0,4,1],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aff4ab5e5474e310e09eb03a10aaa6844":[7,0,3,4,3,0,4,2],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp_source.html":[7,0,3,4,3,0,4],
-"linalg_2opencl_2kernels_2fft_8hpp.html":[7,0,3,4,3,0,5],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a03d946ea93037f1a394325d1c524383b":[7,0,3,4,3,0,5,8],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a056ee100af7f100796c7e6893617c1cb":[7,0,3,4,3,0,5,5],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a08dcb168fcfe7292634e1d15e0ecb577":[7,0,3,4,3,0,5,2],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a1953cd9bfa9ae539106f7d5364488f20":[7,0,3,4,3,0,5,3],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a5bc438da1adb4fe04d869bbe9318d2db":[7,0,3,4,3,0,5,9],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a72c23e31b4c043ac2a373988576f7aa8":[7,0,3,4,3,0,5,7],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a829073b7bfc3c121a1baba87a595462a":[7,0,3,4,3,0,5,4],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a909a503c6a235fdff7b7d95900513dc3":[7,0,3,4,3,0,5,6],
-"linalg_2opencl_2kernels_2fft_8hpp.html#acbcd37b7373b647d9eb2d93e77902ba2":[7,0,3,4,3,0,5,10],
 "linalg_2opencl_2kernels_2fft_8hpp.html#ae143c2d7887d9060ef8d1319a1022769":[7,0,3,4,3,0,5,1],
 "linalg_2opencl_2kernels_2fft_8hpp.html#ae93743370d109b9e5e468651c8ccec49":[7,0,3,4,3,0,5,11],
 "linalg_2opencl_2kernels_2fft_8hpp_source.html":[7,0,3,4,3,0,5],
@@ -245,9 +224,30 @@ var NAVTREEINDEX15 =
 "matrix__axpy_8hpp_source.html":[7,0,3,2,0,2],
 "matrix__axpy__template_8hpp.html":[7,0,3,2,1,0],
 "matrix__axpy__template_8hpp_source.html":[7,0,3,2,1,0],
-"matrix__col__double_8cpp.html":[7,0,2,0,14],
-"matrix__col__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,14,0],
-"matrix__col__double_8cpp_source.html":[7,0,2,0,14],
-"matrix__col__float_8cpp.html":[7,0,2,0,15],
-"matrix__col__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,15,0]
+"matrix__col__double_8cpp.html":[7,0,2,0,11],
+"matrix__col__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,11,0],
+"matrix__col__double_8cpp_source.html":[7,0,2,0,11],
+"matrix__col__float_8cpp.html":[7,0,2,0,12],
+"matrix__col__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,12,0],
+"matrix__col__float_8cpp_source.html":[7,0,2,0,12],
+"matrix__col__int_8cpp.html":[7,0,2,0,13],
+"matrix__col__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,13,0],
+"matrix__col__int_8cpp_source.html":[7,0,2,0,13],
+"matrix__def_8hpp.html":[7,0,3,1,0],
+"matrix__def_8hpp_source.html":[7,0,3,1,0],
+"matrix__float__double_8hpp.html":[7,0,2,0,14],
+"matrix__float__double_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,14,1],
+"matrix__float__double_8hpp.html#a3eeb8dff5404f0ba9ff74f4ee5b9095d":[7,0,2,0,14,5],
+"matrix__float__double_8hpp.html#a931ce6a0abe4400075e9db9f45456a6d":[7,0,2,0,14,3],
+"matrix__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,14,0],
+"matrix__float__double_8hpp.html#ab3fef5684e0d6531328592e7028143d9":[7,0,2,0,14,4],
+"matrix__float__double_8hpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,14,2],
+"matrix__float__double_8hpp_source.html":[7,0,2,0,14],
+"matrix__generation_8hpp.html":[7,0,3,9,2],
+"matrix__generation_8hpp.html#a2702f36c2589c4c7149933392df2d2c5":[7,0,3,9,2,1],
+"matrix__generation_8hpp.html#a2f78fcdf605a26a07bc8a74abf43cebd":[7,0,3,9,2,2],
+"matrix__generation_8hpp.html#ad234a38b10b156c750260065c3d3883c":[7,0,3,9,2,0],
+"matrix__generation_8hpp.html#ad8bbea154a3967f21dd72eb90c32e8b6":[7,0,3,9,2,5],
+"matrix__generation_8hpp.html#add4bc9eb3478008256fb745ea682cf0e":[7,0,3,9,2,4],
+"matrix__generation_8hpp.html#af9cd8936be17b4cf089bf18fec7861fb":[7,0,3,9,2,3]
 };
