@@ -1,34 +1,13 @@
 var NAVTREEINDEX16 =
 {
-"matrix__col__float_8cpp_source.html":[7,0,2,0,15],
-"matrix__col__int_8cpp.html":[7,0,2,0,16],
-"matrix__col__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,16,0],
-"matrix__col__int_8cpp_source.html":[7,0,2,0,16],
-"matrix__def_8hpp.html":[7,0,3,1,0],
-"matrix__def_8hpp_source.html":[7,0,3,1,0],
-"matrix__float__double_8hpp.html":[7,0,2,0,17],
-"matrix__float__double_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,17,1],
-"matrix__float__double_8hpp.html#a3eeb8dff5404f0ba9ff74f4ee5b9095d":[7,0,2,0,17,5],
-"matrix__float__double_8hpp.html#a931ce6a0abe4400075e9db9f45456a6d":[7,0,2,0,17,3],
-"matrix__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,17,0],
-"matrix__float__double_8hpp.html#ab3fef5684e0d6531328592e7028143d9":[7,0,2,0,17,4],
-"matrix__float__double_8hpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,17,2],
-"matrix__float__double_8hpp_source.html":[7,0,2,0,17],
-"matrix__generation_8hpp.html":[7,0,3,9,2],
-"matrix__generation_8hpp.html#a2702f36c2589c4c7149933392df2d2c5":[7,0,3,9,2,1],
-"matrix__generation_8hpp.html#a2f78fcdf605a26a07bc8a74abf43cebd":[7,0,3,9,2,2],
-"matrix__generation_8hpp.html#ad234a38b10b156c750260065c3d3883c":[7,0,3,9,2,0],
-"matrix__generation_8hpp.html#ad8bbea154a3967f21dd72eb90c32e8b6":[7,0,3,9,2,5],
-"matrix__generation_8hpp.html#add4bc9eb3478008256fb745ea682cf0e":[7,0,3,9,2,4],
-"matrix__generation_8hpp.html#af9cd8936be17b4cf089bf18fec7861fb":[7,0,3,9,2,3],
 "matrix__generation_8hpp_source.html":[7,0,3,9,2],
-"matrix__int_8hpp.html":[7,0,2,0,18],
-"matrix__int_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,18,0],
-"matrix__int_8hpp.html#a2b140ddbbb3e8a84a1e7b00a7d2fece3":[7,0,2,0,18,4],
-"matrix__int_8hpp.html#a2dc3f334bcfe9273604284f5fde2e2a9":[7,0,2,0,18,3],
-"matrix__int_8hpp.html#accb6d386a66b1ad26b6fa5c3f8cf9988":[7,0,2,0,18,2],
-"matrix__int_8hpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,18,1],
-"matrix__int_8hpp_source.html":[7,0,2,0,18],
+"matrix__int_8hpp.html":[7,0,2,0,15],
+"matrix__int_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,15,0],
+"matrix__int_8hpp.html#a2b140ddbbb3e8a84a1e7b00a7d2fece3":[7,0,2,0,15,4],
+"matrix__int_8hpp.html#a2dc3f334bcfe9273604284f5fde2e2a9":[7,0,2,0,15,3],
+"matrix__int_8hpp.html#accb6d386a66b1ad26b6fa5c3f8cf9988":[7,0,2,0,15,2],
+"matrix__int_8hpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,15,1],
+"matrix__int_8hpp_source.html":[7,0,2,0,15],
 "matrix__market_8hpp.html":[7,0,3,3,0],
 "matrix__market_8hpp.html#a1ca9d47b6dbd62ff5b21190e5d604a51":[7,0,3,3,0,1],
 "matrix__market_8hpp.html#a2154ce66dd922c41a0399b08595f5cef":[7,0,3,3,0,3],
@@ -177,43 +156,41 @@ var NAVTREEINDEX16 =
 "matrix__operations__prod_8hpp_source.html":[7,0,3,4,0,12],
 "matrix__operations__row_8hpp.html":[7,0,3,4,0,13],
 "matrix__operations__row_8hpp.html#a051bf582e945c53446052448f5700342":[7,0,3,4,0,13,0],
-"matrix__operations__row_8hpp.html#a140760584560dacbb0856e0c5cae773b":[7,0,3,4,0,13,15],
-"matrix__operations__row_8hpp.html#a1a9ab804ef1ba7fe326c51183836026f":[7,0,3,4,0,13,10],
-"matrix__operations__row_8hpp.html#a209ab62b7c396b9cdbe83b31b0459ef4":[7,0,3,4,0,13,16],
-"matrix__operations__row_8hpp.html#a3d2afe289db90c26b9b136eb71815163":[7,0,3,4,0,13,26],
+"matrix__operations__row_8hpp.html#a140760584560dacbb0856e0c5cae773b":[7,0,3,4,0,13,14],
+"matrix__operations__row_8hpp.html#a209ab62b7c396b9cdbe83b31b0459ef4":[7,0,3,4,0,13,15],
+"matrix__operations__row_8hpp.html#a3d2afe289db90c26b9b136eb71815163":[7,0,3,4,0,13,25],
 "matrix__operations__row_8hpp.html#a40ace4f9dd96e5bc19b7cadf584b6e24":[7,0,3,4,0,13,1],
-"matrix__operations__row_8hpp.html#a442a5fe3461438e1b63f9adb990ecf3f":[7,0,3,4,0,13,21],
-"matrix__operations__row_8hpp.html#a46116ec48d8d8817e052048d7a508535":[7,0,3,4,0,13,20],
-"matrix__operations__row_8hpp.html#a4c2cf5f7166de2bec1ebdf2b34d88068":[7,0,3,4,0,13,17],
+"matrix__operations__row_8hpp.html#a442a5fe3461438e1b63f9adb990ecf3f":[7,0,3,4,0,13,20],
+"matrix__operations__row_8hpp.html#a46116ec48d8d8817e052048d7a508535":[7,0,3,4,0,13,19],
+"matrix__operations__row_8hpp.html#a4c2cf5f7166de2bec1ebdf2b34d88068":[7,0,3,4,0,13,16],
 "matrix__operations__row_8hpp.html#a554183987e3e0bc46f8363737f0eea2e":[7,0,3,4,0,13,6],
-"matrix__operations__row_8hpp.html#a5740a977590561b47fc935c7f28798c9":[7,0,3,4,0,13,29],
-"matrix__operations__row_8hpp.html#a594c065f0451d324d6d1df2cf68375c8":[7,0,3,4,0,13,36],
-"matrix__operations__row_8hpp.html#a5c8c9eb9cad541d0df71091cb6d48b0a":[7,0,3,4,0,13,19],
+"matrix__operations__row_8hpp.html#a5740a977590561b47fc935c7f28798c9":[7,0,3,4,0,13,28],
+"matrix__operations__row_8hpp.html#a594c065f0451d324d6d1df2cf68375c8":[7,0,3,4,0,13,34],
+"matrix__operations__row_8hpp.html#a5c8c9eb9cad541d0df71091cb6d48b0a":[7,0,3,4,0,13,18],
 "matrix__operations__row_8hpp.html#a5e11149460839d0ac88663a8f83cff9e":[7,0,3,4,0,13,2],
-"matrix__operations__row_8hpp.html#a6a6d4242c36c438c0ca4331a844de631":[7,0,3,4,0,13,12],
-"matrix__operations__row_8hpp.html#a6cb1df783999e816cbbca4d62da0c41f":[7,0,3,4,0,13,14],
+"matrix__operations__row_8hpp.html#a6a6d4242c36c438c0ca4331a844de631":[7,0,3,4,0,13,11],
+"matrix__operations__row_8hpp.html#a6cb1df783999e816cbbca4d62da0c41f":[7,0,3,4,0,13,13],
 "matrix__operations__row_8hpp.html#a70676b804388fbd340bd06470124e50a":[7,0,3,4,0,13,9],
 "matrix__operations__row_8hpp.html#a7603380e189cdde868c8d1a8ce55a483":[7,0,3,4,0,13,8],
-"matrix__operations__row_8hpp.html#a76ef0b275275ca8ce6522c0fe9c96fe9":[7,0,3,4,0,13,35],
-"matrix__operations__row_8hpp.html#a7f04c29e7fb19c267eea21691185309a":[7,0,3,4,0,13,24],
-"matrix__operations__row_8hpp.html#a9072fb1bbafdb15446b9aa0338da4f1c":[7,0,3,4,0,13,27],
-"matrix__operations__row_8hpp.html#a929030285bc21f3191df5cbe23d8554d":[7,0,3,4,0,13,32],
-"matrix__operations__row_8hpp.html#a941643e5428eb9c2ca160271877d3244":[7,0,3,4,0,13,11],
+"matrix__operations__row_8hpp.html#a76ef0b275275ca8ce6522c0fe9c96fe9":[7,0,3,4,0,13,33],
+"matrix__operations__row_8hpp.html#a7f04c29e7fb19c267eea21691185309a":[7,0,3,4,0,13,23],
+"matrix__operations__row_8hpp.html#a9072fb1bbafdb15446b9aa0338da4f1c":[7,0,3,4,0,13,26],
+"matrix__operations__row_8hpp.html#a941643e5428eb9c2ca160271877d3244":[7,0,3,4,0,13,10],
 "matrix__operations__row_8hpp.html#a945e116c04670bda5225f54d78c7f18e":[7,0,3,4,0,13,7],
-"matrix__operations__row_8hpp.html#a949f33a650dad04cd29d61f2307d61cb":[7,0,3,4,0,13,31],
-"matrix__operations__row_8hpp.html#a9b3f355b36d76a0f60240f63546284a4":[7,0,3,4,0,13,30],
-"matrix__operations__row_8hpp.html#aa74525399d7f4b752ce092ec6558058b":[7,0,3,4,0,13,34],
+"matrix__operations__row_8hpp.html#a949f33a650dad04cd29d61f2307d61cb":[7,0,3,4,0,13,30],
+"matrix__operations__row_8hpp.html#a9b3f355b36d76a0f60240f63546284a4":[7,0,3,4,0,13,29],
+"matrix__operations__row_8hpp.html#aa74525399d7f4b752ce092ec6558058b":[7,0,3,4,0,13,32],
 "matrix__operations__row_8hpp.html#abb62dce8a842fddefb5727a6073494fa":[7,0,3,4,0,13,3],
 "matrix__operations__row_8hpp.html#ac4c81e2abc7e7d421181a819b0f46160":[7,0,3,4,0,13,5],
-"matrix__operations__row_8hpp.html#ac6063385a9c46838e6fa747609b09670":[7,0,3,4,0,13,33],
-"matrix__operations__row_8hpp.html#ac82836adfb1c47e5d963189057ab1baf":[7,0,3,4,0,13,22],
-"matrix__operations__row_8hpp.html#ad65686b36a328aad60394c616809b489":[7,0,3,4,0,13,13],
-"matrix__operations__row_8hpp.html#ad73ed63f68b5922248a9cc51ae878e60":[7,0,3,4,0,13,25],
-"matrix__operations__row_8hpp.html#adac9b13a79cd0c009dff3f6c41f2b570":[7,0,3,4,0,13,18],
+"matrix__operations__row_8hpp.html#ac6063385a9c46838e6fa747609b09670":[7,0,3,4,0,13,31],
+"matrix__operations__row_8hpp.html#ac82836adfb1c47e5d963189057ab1baf":[7,0,3,4,0,13,21],
+"matrix__operations__row_8hpp.html#ad65686b36a328aad60394c616809b489":[7,0,3,4,0,13,12],
+"matrix__operations__row_8hpp.html#ad73ed63f68b5922248a9cc51ae878e60":[7,0,3,4,0,13,24],
+"matrix__operations__row_8hpp.html#adac9b13a79cd0c009dff3f6c41f2b570":[7,0,3,4,0,13,17],
 "matrix__operations__row_8hpp.html#ae0c1ab49bf9e4cd4cf694e3639d442dc":[7,0,3,4,0,13,4],
-"matrix__operations__row_8hpp.html#aef28890380b6a246d556390c13e26a61":[7,0,3,4,0,13,23],
-"matrix__operations__row_8hpp.html#af2b44cf9690bfb3f9e5dff5b26b607e9":[7,0,3,4,0,13,37],
-"matrix__operations__row_8hpp.html#af7f5b871860c650a17d06404fe61f9ac":[7,0,3,4,0,13,28],
+"matrix__operations__row_8hpp.html#aef28890380b6a246d556390c13e26a61":[7,0,3,4,0,13,22],
+"matrix__operations__row_8hpp.html#af2b44cf9690bfb3f9e5dff5b26b607e9":[7,0,3,4,0,13,35],
+"matrix__operations__row_8hpp.html#af7f5b871860c650a17d06404fe61f9ac":[7,0,3,4,0,13,27],
 "matrix__operations__row_8hpp_source.html":[7,0,3,4,0,13],
 "matrix__product_8hpp.html":[7,0,3,2,0,3],
 "matrix__product_8hpp.html#a07786a0a76651ba3c30d60b7ae5ad6d0":[7,0,3,2,0,3,3],
@@ -222,23 +199,23 @@ var NAVTREEINDEX16 =
 "matrix__product_8hpp.html#a92cf5f3655b5e3bcb1ddcb9b31123067":[7,0,3,2,0,3,4],
 "matrix__product_8hpp.html#ad45fa18ffaecd758a25649b327a1895b":[7,0,3,2,0,3,0],
 "matrix__product_8hpp_source.html":[7,0,3,2,0,3],
-"matrix__product__double_8cpp.html":[7,0,2,0,19],
-"matrix__product__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,19,0],
-"matrix__product__double_8cpp_source.html":[7,0,2,0,19],
-"matrix__product__float_8cpp.html":[7,0,2,0,20],
-"matrix__product__float_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,20,0],
-"matrix__product__float_8cpp_source.html":[7,0,2,0,20],
-"matrix__product__float__double_8hpp.html":[7,0,2,0,21],
-"matrix__product__float__double_8hpp.html#a0168edce7007501cb7b66ea44ae6647b":[7,0,2,0,21,6],
-"matrix__product__float__double_8hpp.html#a0aece9314ad7b81303e5b15af37b6171":[7,0,2,0,21,12],
-"matrix__product__float__double_8hpp.html#a0d2a70fee25ea6dacda8b68b9385da3e":[7,0,2,0,21,10],
-"matrix__product__float__double_8hpp.html#a2d34222888cada9267456dd2c202a36b":[7,0,2,0,21,5],
-"matrix__product__float__double_8hpp.html#a40c835130ac9aa8aa9e48d9459b316ea":[7,0,2,0,21,7],
-"matrix__product__float__double_8hpp.html#a55e79356a78c9ef935cc4d11077b905d":[7,0,2,0,21,9],
-"matrix__product__float__double_8hpp.html#a9c961c45d9f8c1be8dce9678f9a6a128":[7,0,2,0,21,11],
-"matrix__product__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,21,4],
-"matrix__product__float__double_8hpp.html#af855327279fd1faab2e6126cbe3d9497":[7,0,2,0,21,8],
-"matrix__product__float__double_8hpp_source.html":[7,0,2,0,21],
+"matrix__product__double_8cpp.html":[7,0,2,0,16],
+"matrix__product__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,16,0],
+"matrix__product__double_8cpp_source.html":[7,0,2,0,16],
+"matrix__product__float_8cpp.html":[7,0,2,0,17],
+"matrix__product__float_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,17,0],
+"matrix__product__float_8cpp_source.html":[7,0,2,0,17],
+"matrix__product__float__double_8hpp.html":[7,0,2,0,18],
+"matrix__product__float__double_8hpp.html#a0168edce7007501cb7b66ea44ae6647b":[7,0,2,0,18,6],
+"matrix__product__float__double_8hpp.html#a0aece9314ad7b81303e5b15af37b6171":[7,0,2,0,18,12],
+"matrix__product__float__double_8hpp.html#a0d2a70fee25ea6dacda8b68b9385da3e":[7,0,2,0,18,10],
+"matrix__product__float__double_8hpp.html#a2d34222888cada9267456dd2c202a36b":[7,0,2,0,18,5],
+"matrix__product__float__double_8hpp.html#a40c835130ac9aa8aa9e48d9459b316ea":[7,0,2,0,18,7],
+"matrix__product__float__double_8hpp.html#a55e79356a78c9ef935cc4d11077b905d":[7,0,2,0,18,9],
+"matrix__product__float__double_8hpp.html#a9c961c45d9f8c1be8dce9678f9a6a128":[7,0,2,0,18,11],
+"matrix__product__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,18,4],
+"matrix__product__float__double_8hpp.html#af855327279fd1faab2e6126cbe3d9497":[7,0,2,0,18,8],
+"matrix__product__float__double_8hpp_source.html":[7,0,2,0,18],
 "matrix__product__template_8hpp.html":[7,0,3,2,1,1],
 "matrix__product__template_8hpp.html#a2cc2037be613c430d8976673945a2200":[7,0,3,2,1,1,3],
 "matrix__product__template_8hpp.html#a3eee04070ac5528e391f0f7ed0c423c2":[7,0,3,2,1,1,4],
@@ -249,5 +226,28 @@ var NAVTREEINDEX16 =
 "matrix__proxy_8hpp.html#a3d33198f0cc7b3e811381c65dc497632":[7,0,3,22,13],
 "matrix__proxy_8hpp.html#a591856f7f277d0cfe1d88f8157b74b7e":[7,0,3,22,4],
 "matrix__proxy_8hpp.html#a5a8af211ade14d32939de1ab88fbfce3":[7,0,3,22,5],
-"matrix__proxy_8hpp.html#a5d0d5a12b085b5909596f1d754f0c9e3":[7,0,3,22,16]
+"matrix__proxy_8hpp.html#a5d0d5a12b085b5909596f1d754f0c9e3":[7,0,3,22,16],
+"matrix__proxy_8hpp.html#a638aa5c54fe703aac75a9613b6fa992a":[7,0,3,22,6],
+"matrix__proxy_8hpp.html#a784184338e26686e21bdf43d66c875ac":[7,0,3,22,11],
+"matrix__proxy_8hpp.html#a8943b9e05480eb6b7bcd11a0061912e3":[7,0,3,22,9],
+"matrix__proxy_8hpp.html#a99b5ce1b764503f97c07405b6a937fc7":[7,0,3,22,7],
+"matrix__proxy_8hpp.html#adc45a895937fe299100e2b235a442748":[7,0,3,22,12],
+"matrix__proxy_8hpp.html#ae9c089715c733e9e42ac80ee5fc99e29":[7,0,3,22,14],
+"matrix__proxy_8hpp.html#af2902ac57885aecf018516bc72fbab09":[7,0,3,22,10],
+"matrix__proxy_8hpp.html#afa9683f0ed709a227c267e33b3195ec2":[7,0,3,22,15],
+"matrix__proxy_8hpp_source.html":[7,0,3,22],
+"matrix__row__double_8cpp.html":[7,0,2,0,19],
+"matrix__row__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,19,0],
+"matrix__row__double_8cpp_source.html":[7,0,2,0,19],
+"matrix__row__float_8cpp.html":[7,0,2,0,20],
+"matrix__row__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,20,0],
+"matrix__row__float_8cpp_source.html":[7,0,2,0,20],
+"matrix__row__int_8cpp.html":[7,0,2,0,21],
+"matrix__row__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,21,0],
+"matrix__row__int_8cpp_source.html":[7,0,2,0,21],
+"matrix__size__deducer_8hpp.html":[7,0,3,9,3],
+"matrix__size__deducer_8hpp_source.html":[7,0,3,9,3],
+"matrix__solve_8hpp.html":[7,0,3,4,3,0,10],
+"matrix__solve_8hpp.html#a5db626a3b32b204504f4737f96982427":[7,0,3,4,3,0,10,1],
+"matrix__solve_8hpp_source.html":[7,0,3,4,3,0,10]
 };
