@@ -1,47 +1,24 @@
 var NAVTREEINDEX17 =
 {
-"matrix__proxy_8hpp.html#a638aa5c54fe703aac75a9613b6fa992a":[7,0,3,22,6],
-"matrix__proxy_8hpp.html#a784184338e26686e21bdf43d66c875ac":[7,0,3,22,11],
-"matrix__proxy_8hpp.html#a8943b9e05480eb6b7bcd11a0061912e3":[7,0,3,22,9],
-"matrix__proxy_8hpp.html#a99b5ce1b764503f97c07405b6a937fc7":[7,0,3,22,7],
-"matrix__proxy_8hpp.html#adc45a895937fe299100e2b235a442748":[7,0,3,22,12],
-"matrix__proxy_8hpp.html#ae9c089715c733e9e42ac80ee5fc99e29":[7,0,3,22,14],
-"matrix__proxy_8hpp.html#af2902ac57885aecf018516bc72fbab09":[7,0,3,22,10],
-"matrix__proxy_8hpp.html#afa9683f0ed709a227c267e33b3195ec2":[7,0,3,22,15],
-"matrix__proxy_8hpp_source.html":[7,0,3,22],
-"matrix__row__double_8cpp.html":[7,0,2,0,22],
-"matrix__row__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,22,0],
-"matrix__row__double_8cpp_source.html":[7,0,2,0,22],
-"matrix__row__float_8cpp.html":[7,0,2,0,23],
-"matrix__row__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,23,0],
-"matrix__row__float_8cpp_source.html":[7,0,2,0,23],
-"matrix__row__int_8cpp.html":[7,0,2,0,24],
-"matrix__row__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,24,0],
-"matrix__row__int_8cpp_source.html":[7,0,2,0,24],
-"matrix__size__deducer_8hpp.html":[7,0,3,9,3],
-"matrix__size__deducer_8hpp_source.html":[7,0,3,9,3],
-"matrix__solve_8hpp.html":[7,0,3,4,3,0,10],
-"matrix__solve_8hpp.html#a8cd11db4e60f83f0f522108de1cff5b1":[7,0,3,4,3,0,10,1],
-"matrix__solve_8hpp_source.html":[7,0,3,4,3,0,10],
-"matrix__vector_8cpp.html":[7,0,2,0,25],
-"matrix__vector_8cpp.html#a00412d857cf1280ac59bac80061ccf0a":[7,0,2,0,25,7],
-"matrix__vector_8cpp.html#a0fa2d0d0ec97d6cd1192a960d64d92ec":[7,0,2,0,25,6],
-"matrix__vector_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,25,3],
-"matrix__vector_8cpp.html#aacca06eadc801980b85316ba3e9a018b":[7,0,2,0,25,5],
-"matrix__vector_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,25,2],
-"matrix__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,25,4],
-"matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,25,0],
-"matrix__vector_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,25,1],
-"matrix__vector_8cpp_source.html":[7,0,2,0,25],
-"matrix__vector__int_8cpp.html":[7,0,2,0,26],
-"matrix__vector__int_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,26,3],
-"matrix__vector__int_8cpp.html#abb00dc6bc0c69a5f9a07f1e5ea24eb93":[7,0,2,0,26,5],
-"matrix__vector__int_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,26,2],
-"matrix__vector__int_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,26,4],
-"matrix__vector__int_8cpp.html#ae68ad112f7ea64cf94b147ec7625086e":[7,0,2,0,26,6],
-"matrix__vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,26,0],
-"matrix__vector__int_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,26,1],
-"matrix__vector__int_8cpp_source.html":[7,0,2,0,26],
+"matrix__vector_8cpp.html":[7,0,2,0,22],
+"matrix__vector_8cpp.html#a00412d857cf1280ac59bac80061ccf0a":[7,0,2,0,22,7],
+"matrix__vector_8cpp.html#a0fa2d0d0ec97d6cd1192a960d64d92ec":[7,0,2,0,22,6],
+"matrix__vector_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,22,3],
+"matrix__vector_8cpp.html#aacca06eadc801980b85316ba3e9a018b":[7,0,2,0,22,5],
+"matrix__vector_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,22,2],
+"matrix__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,22,4],
+"matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,22,0],
+"matrix__vector_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,22,1],
+"matrix__vector_8cpp_source.html":[7,0,2,0,22],
+"matrix__vector__int_8cpp.html":[7,0,2,0,23],
+"matrix__vector__int_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,23,3],
+"matrix__vector__int_8cpp.html#abb00dc6bc0c69a5f9a07f1e5ea24eb93":[7,0,2,0,23,5],
+"matrix__vector__int_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,23,2],
+"matrix__vector__int_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,23,4],
+"matrix__vector__int_8cpp.html#ae68ad112f7ea64cf94b147ec7625086e":[7,0,2,0,23,6],
+"matrix__vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,23,0],
+"matrix__vector__int_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,23,1],
+"matrix__vector__int_8cpp_source.html":[7,0,2,0,23],
 "maxmin_8hpp.html":[7,0,3,4,23],
 "maxmin_8hpp.html#a3174c1f0846b0f4801e203b2048f12de":[7,0,3,4,23,1],
 "maxmin_8hpp.html#a5057d08504cc799dd77dfd596499bffc":[7,0,3,4,23,5],
@@ -89,35 +66,34 @@ var NAVTREEINDEX17 =
 "multithreaded__cg_8cpp_source.html":[7,0,0,1,21],
 "multithreaded_cg_8cpp-example.html":[8,20],
 "namespacedetail.html":[5,0,0],
-"namespacemembers.html":[5,1,0,14],
+"namespacemembers.html":[5,1,0,9],
+"namespacemembers.html":[5,1,0,20],
 "namespacemembers.html":[5,1,0,13],
-"namespacemembers.html":[5,1,0,7],
-"namespacemembers.html":[5,1,0,10],
-"namespacemembers.html":[5,1,0,12],
-"namespacemembers.html":[5,1,0,4],
+"namespacemembers.html":[5,1,0,11],
+"namespacemembers.html":[5,1,0,8],
 "namespacemembers.html":[5,1,0],
 "namespacemembers.html":[5,1,0,0],
+"namespacemembers.html":[5,1,0,14],
 "namespacemembers.html":[5,1,0,1],
 "namespacemembers.html":[5,1,0,2],
 "namespacemembers.html":[5,1,0,3],
+"namespacemembers.html":[5,1,0,7],
+"namespacemembers.html":[5,1,0,4],
 "namespacemembers.html":[5,1,0,5],
-"namespacemembers.html":[5,1,0,9],
-"namespacemembers.html":[5,1,0,8],
-"namespacemembers.html":[5,1,0,11],
-"namespacemembers.html":[5,1,0,19],
+"namespacemembers.html":[5,1,0,6],
+"namespacemembers.html":[5,1,0,10],
+"namespacemembers.html":[5,1,0,12],
 "namespacemembers.html":[5,1,0,15],
 "namespacemembers.html":[5,1,0,16],
-"namespacemembers.html":[5,1,0,23],
 "namespacemembers.html":[5,1,0,17],
-"namespacemembers.html":[5,1,0,22],
-"namespacemembers.html":[5,1,0,18],
 "namespacemembers.html":[5,1,0,21],
-"namespacemembers.html":[5,1,0,20],
-"namespacemembers.html":[5,1,0,6],
+"namespacemembers.html":[5,1,0,19],
+"namespacemembers.html":[5,1,0,23],
+"namespacemembers.html":[5,1,0,18],
+"namespacemembers.html":[5,1,0,22],
 "namespacemembers_enum.html":[5,1,4],
 "namespacemembers_eval.html":[5,1,5],
 "namespacemembers_func.html":[5,1,1,14],
-"namespacemembers_func.html":[5,1,1,16],
 "namespacemembers_func.html":[5,1,1],
 "namespacemembers_func.html":[5,1,1,0],
 "namespacemembers_func.html":[5,1,1,1],
@@ -134,6 +110,7 @@ var NAVTREEINDEX17 =
 "namespacemembers_func.html":[5,1,1,12],
 "namespacemembers_func.html":[5,1,1,13],
 "namespacemembers_func.html":[5,1,1,15],
+"namespacemembers_func.html":[5,1,1,16],
 "namespacemembers_func.html":[5,1,1,17],
 "namespacemembers_func.html":[5,1,1,18],
 "namespacemembers_func.html":[5,1,1,19],
@@ -143,8 +120,8 @@ var NAVTREEINDEX17 =
 "namespacemembers_type.html":[5,1,3],
 "namespacemembers_vars.html":[5,1,2],
 "namespaces.html":[5,0],
-"namespaceviennacl.html":[6,0,0],
 "namespaceviennacl.html":[5,0,1],
+"namespaceviennacl.html":[6,0,0],
 "namespaceviennacl_1_1backend.html":[5,0,1,0],
 "namespaceviennacl_1_1backend.html":[6,0,0,0],
 "namespaceviennacl_1_1backend_1_1cpu__ram.html":[5,0,1,0,0],
@@ -155,33 +132,33 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1backend_1_1cuda.html":[5,0,1,0,1],
 "namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[5,0,1,0,1,0],
 "namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[6,0,0,0,1,0],
-"namespaceviennacl_1_1backend_1_1detail.html":[5,0,1,0,2],
 "namespaceviennacl_1_1backend_1_1detail.html":[6,0,0,0,2],
+"namespaceviennacl_1_1backend_1_1detail.html":[5,0,1,0,2],
 "namespaceviennacl_1_1backend_1_1opencl.html":[6,0,0,0,3],
 "namespaceviennacl_1_1backend_1_1opencl.html":[5,0,1,0,3],
 "namespaceviennacl_1_1backend_1_1opencl_1_1detail.html":[5,0,1,0,3,0],
 "namespaceviennacl_1_1detail.html":[6,0,0,1],
 "namespaceviennacl_1_1detail.html":[5,0,1,1],
-"namespaceviennacl_1_1detail_1_1fft.html":[6,0,0,1,0],
 "namespaceviennacl_1_1detail_1_1fft.html":[5,0,1,1,0],
+"namespaceviennacl_1_1detail_1_1fft.html":[6,0,0,1,0],
 "namespaceviennacl_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,1,0,0],
-"namespaceviennacl_1_1device__specific.html":[5,0,1,2],
 "namespaceviennacl_1_1device__specific.html":[6,0,0,2],
+"namespaceviennacl_1_1device__specific.html":[5,0,1,2],
 "namespaceviennacl_1_1device__specific_1_1autotune.html":[5,0,1,2,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database.html":[5,0,1,2,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database.html":[6,0,0,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[6,0,0,2,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[5,0,1,2,1,0],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[6,0,0,2,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[6,0,0,2,0,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[5,0,1,2,1,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator_1_1fallback.html":[5,0,1,2,1,0,0,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[6,0,0,2,0,0,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[5,0,1,2,1,0,1],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[6,0,0,2,0,0,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu_1_1fallback.html":[5,0,1,2,1,0,1,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[5,0,1,2,1,0,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[6,0,0,2,0,0,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[6,0,0,2,0,0,2,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[5,0,1,2,1,0,2,0],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[6,0,0,2,0,0,2,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[5,0,1,2,1,0,2,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[6,0,0,2,0,0,2,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen_1_1cedar.html":[5,0,1,2,1,0,2,0,0,0],
@@ -217,8 +194,8 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla_1_1geforce__gtx__260.html":[5,0,1,2,1,0,2,2,3,0],
 "namespaceviennacl_1_1device__specific_1_1detail.html":[5,0,1,2,2],
 "namespaceviennacl_1_1device__specific_1_1profiles.html":[5,0,1,2,3],
-"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
 "namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[5,0,1,2,4],
+"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
 "namespaceviennacl_1_1device__specific_1_1utils.html":[5,0,1,2,5],
 "namespaceviennacl_1_1device__specific_1_1utils.html":[6,0,0,2,2],
 "namespaceviennacl_1_1io.html":[5,0,1,3],
@@ -228,10 +205,10 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1io_1_1val.html":[5,0,1,3,2],
 "namespaceviennacl_1_1linalg.html":[5,0,1,4],
 "namespaceviennacl_1_1linalg.html":[6,0,0,4],
-"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
 "namespaceviennacl_1_1linalg_1_1cuda.html":[5,0,1,4,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
+"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
 "namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[5,0,1,4,0,0],
+"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
 "namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[5,0,1,4,0,0,0],
 "namespaceviennacl_1_1linalg_1_1detail.html":[6,0,0,4,1],
 "namespaceviennacl_1_1linalg_1_1detail.html":[5,0,1,4,1],
@@ -242,12 +219,35 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[6,0,0,4,1,1],
 "namespaceviennacl_1_1linalg_1_1host__based.html":[5,0,1,4,2],
 "namespaceviennacl_1_1linalg_1_1host__based.html":[6,0,0,4,2],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,0],
 "namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[5,0,1,4,2,0],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,0],
 "namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[5,0,1,4,2,0,0],
 "namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[6,0,0,4,2,0,0],
 "namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,4,2,0,0,0],
 "namespaceviennacl_1_1linalg_1_1kernels.html":[5,0,1,4,3],
 "namespaceviennacl_1_1linalg_1_1opencl.html":[5,0,1,4,4],
-"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3]
+"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,0],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,1],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,1,0],
+"namespaceviennacl_1_1ocl.html":[6,0,0,5],
+"namespaceviennacl_1_1ocl.html":[5,0,1,5],
+"namespaceviennacl_1_1result__of.html":[5,0,1,6],
+"namespaceviennacl_1_1result__of.html":[6,0,0,6],
+"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
+"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
+"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
+"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
+"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
+"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
+"namespaceviennacl_1_1tools.html":[5,0,1,8],
+"namespaceviennacl_1_1tools.html":[6,0,0,8],
+"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
+"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
+"namespaceviennacl_1_1traits.html":[5,0,1,9],
+"namespaceviennacl_1_1traits.html":[6,0,0,9],
+"nmf_8cpp-example.html":[8,21],
+"nmf_8hpp.html":[7,0,3,4,26],
+"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,26,0]
 };
