@@ -1,28 +1,5 @@
 var NAVTREEINDEX18 =
 {
-"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,0],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,1],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,1,0],
-"namespaceviennacl_1_1ocl.html":[6,0,0,5],
-"namespaceviennacl_1_1ocl.html":[5,0,1,5],
-"namespaceviennacl_1_1result__of.html":[6,0,0,6],
-"namespaceviennacl_1_1result__of.html":[5,0,1,6],
-"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
-"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
-"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
-"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
-"namespaceviennacl_1_1tools.html":[5,0,1,8],
-"namespaceviennacl_1_1tools.html":[6,0,0,8],
-"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
-"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
-"namespaceviennacl_1_1traits.html":[5,0,1,9],
-"namespaceviennacl_1_1traits.html":[6,0,0,9],
-"nmf_8cpp-example.html":[8,21],
-"nmf_8hpp.html":[7,0,3,4,26],
-"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,26,0],
 "nmf_8hpp_source.html":[7,0,3,4,26],
 "norm__1_8hpp.html":[7,0,3,4,27],
 "norm__1_8hpp.html#a18799037aaa2e6b5e1778cdf203a0274":[7,0,3,4,27,1],
@@ -77,13 +54,13 @@ var NAVTREEINDEX18 =
 "opencl_2bisect__kernel__calls_8hpp.html#ae3bd5c49f889451efee98229ca6d14f3":[7,0,3,4,3,1,3],
 "opencl_2bisect__kernel__calls_8hpp_source.html":[7,0,3,4,3,1],
 "opencl_2direct__solve_8hpp.html":[7,0,3,4,3,3],
-"opencl_2direct__solve_8hpp.html#a090413dd356d105d32c53126b285dcef":[7,0,3,4,3,3,4],
-"opencl_2direct__solve_8hpp.html#a311e24d84e3048a5fdfb0b0d6961bc95":[7,0,3,4,3,3,5],
 "opencl_2direct__solve_8hpp.html#a3b425cc7c38c19cc16f34eb0c349a3e2":[7,0,3,4,3,3,3],
 "opencl_2direct__solve_8hpp.html#a64f1e9f297e72762dd45b29214ae71fd":[7,0,3,4,3,3,0],
 "opencl_2direct__solve_8hpp.html#a78416d62615725d511d7cdbd74e3235b":[7,0,3,4,3,3,2],
 "opencl_2direct__solve_8hpp.html#a9d003d00f2cab87b7bc7ebdd472bf1f2":[7,0,3,4,3,3,1],
 "opencl_2direct__solve_8hpp.html#ac213c5f1e1f1b9d18e7b94acb9e17279":[7,0,3,4,3,3,6],
+"opencl_2direct__solve_8hpp.html#ac90a3dca0595b15ae04662bddb6cf57c":[7,0,3,4,3,3,4],
+"opencl_2direct__solve_8hpp.html#ad6cf7d9d8b5ccaf3088350c4b9168dc5":[7,0,3,4,3,3,5],
 "opencl_2direct__solve_8hpp_source.html":[7,0,3,4,3,3],
 "opencl_2fft__operations_8hpp.html":[7,0,3,4,3,4],
 "opencl_2fft__operations_8hpp.html#a0471ee9c12af0be8cd6c3e231099da17":[7,0,3,4,3,4,10],
@@ -249,5 +226,28 @@ var NAVTREEINDEX18 =
 "opencl_2sparse__matrix__operations_8hpp.html#a1fcccd84db8c1659e268e6d7719df94e":[7,0,3,4,3,10,25],
 "opencl_2sparse__matrix__operations_8hpp.html#a20c8cd535c54bba79b1912abce227d04":[7,0,3,4,3,10,22],
 "opencl_2sparse__matrix__operations_8hpp.html#a246453c807f9114ad40e6ae5c22dabc2":[7,0,3,4,3,10,10],
-"opencl_2sparse__matrix__operations_8hpp.html#a256a599dedd093618c9936e85a75b3d4":[7,0,3,4,3,10,24]
+"opencl_2sparse__matrix__operations_8hpp.html#a256a599dedd093618c9936e85a75b3d4":[7,0,3,4,3,10,24],
+"opencl_2sparse__matrix__operations_8hpp.html#a3a97d7d39ed0063efc0e2a7184c63711":[7,0,3,4,3,10,5],
+"opencl_2sparse__matrix__operations_8hpp.html#a435057e12f3596a3bf78e4267b7f7c00":[7,0,3,4,3,10,21],
+"opencl_2sparse__matrix__operations_8hpp.html#a58540b3dfdf2451f59a8d69b0d503977":[7,0,3,4,3,10,8],
+"opencl_2sparse__matrix__operations_8hpp.html#a66050024d4fd7fe421fdec79b082268e":[7,0,3,4,3,10,3],
+"opencl_2sparse__matrix__operations_8hpp.html#a720d4cb00c0c08602f62608ecaa9a835":[7,0,3,4,3,10,1],
+"opencl_2sparse__matrix__operations_8hpp.html#a72fb925402b34c304e02fb4feafb8bc9":[7,0,3,4,3,10,16],
+"opencl_2sparse__matrix__operations_8hpp.html#a7ecec23db21c19f887742bdecb69b2d3":[7,0,3,4,3,10,13],
+"opencl_2sparse__matrix__operations_8hpp.html#a7f4c33a310f17f3379aac2f88348f85b":[7,0,3,4,3,10,7],
+"opencl_2sparse__matrix__operations_8hpp.html#a82d0e161d210b339dbda37d6ebc6318f":[7,0,3,4,3,10,2],
+"opencl_2sparse__matrix__operations_8hpp.html#a83199d78f9adbf3b16034fc8a093ed38":[7,0,3,4,3,10,15],
+"opencl_2sparse__matrix__operations_8hpp.html#ab533b18fa44834dcb24da21403e151a9":[7,0,3,4,3,10,17],
+"opencl_2sparse__matrix__operations_8hpp.html#ac0ec44510ac05abee01a6b869be68d0c":[7,0,3,4,3,10,20],
+"opencl_2sparse__matrix__operations_8hpp.html#adc9e31f7f23c948acc29e15970acd07f":[7,0,3,4,3,10,9],
+"opencl_2sparse__matrix__operations_8hpp.html#adda9f05f3e9ac885e8603f5eed57db1b":[7,0,3,4,3,10,23],
+"opencl_2sparse__matrix__operations_8hpp.html#ae0b9b74ba21c79a3d9421bc68c74712b":[7,0,3,4,3,10,6],
+"opencl_2sparse__matrix__operations_8hpp.html#ae166d736e11c7a6d102115fcb0dddf03":[7,0,3,4,3,10,19],
+"opencl_2sparse__matrix__operations_8hpp.html#ae83a113e8217c08655530df7d0b846b1":[7,0,3,4,3,10,4],
+"opencl_2sparse__matrix__operations_8hpp.html#af50b89f6d9d21d281be8613a54f7d96e":[7,0,3,4,3,10,12],
+"opencl_2sparse__matrix__operations_8hpp.html#af7d2c1881e671ae1dd573bb49b900c5b":[7,0,3,4,3,10,14],
+"opencl_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,3,10],
+"opencl_2vandermonde__matrix__operations_8hpp.html":[7,0,3,4,3,11],
+"opencl_2vandermonde__matrix__operations_8hpp.html#a4fcce6e27674c9c10dc323440cfbfbb6":[7,0,3,4,3,11,0],
+"opencl_2vandermonde__matrix__operations_8hpp_source.html":[7,0,3,4,3,11]
 };
