@@ -1,5 +1,11 @@
 var NAVTREEINDEX2 =
 {
+"classviennacl_1_1coordinate__matrix.html#a7f83ad82b3bab755d76e7f9d665367f7":[6,0,0,22,8],
+"classviennacl_1_1coordinate__matrix.html#a875b6ccacbf0df8ef48ab7f7c46244f1":[6,0,0,22,10],
+"classviennacl_1_1coordinate__matrix.html#a9cde8a8c5cb1516c5503d011388daed4":[6,0,0,22,4],
+"classviennacl_1_1coordinate__matrix.html#a9fd9168600c330faa69cae2626509602":[6,0,0,22,2],
+"classviennacl_1_1coordinate__matrix.html#ad091412ca52bb131234464ed3f5b103c":[6,0,0,22,14],
+"classviennacl_1_1coordinate__matrix.html#ad4218882f3bd97eeff6d81b575ea1e3c":[6,0,0,22,1],
 "classviennacl_1_1coordinate__matrix.html#ad5b57c8ab8bcc8d839aba53be7cb1463":[6,0,0,22,5],
 "classviennacl_1_1coordinate__matrix.html#aeb74dd2ab673d7912a17f60777e9bf6c":[6,0,0,22,9],
 "classviennacl_1_1cuda__not__available__exception.html":[6,0,0,23],
@@ -160,8 +166,8 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#ace084027c47cb4c20b091e33774dcfbd":[6,0,0,2,1,0,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#adb18331e422fee5141086cad436f265c":[6,0,0,2,1,0,1],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html":[6,0,0,2,1,1],
+"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#a985282bbdfb34ae6777efc4737d45c00":[6,0,0,2,1,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#ad3a7c359b39226b4c63c4efb7e246b35":[6,0,0,2,1,1,1],
-"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#aeafc307c76220bbc238bd7147a884c17":[6,0,0,2,1,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#aef355f4ccd06d80399b9561283c66eb6":[6,0,0,2,1,1,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html":[6,0,0,2,1,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html#a3bd51f61962e2b5ed602d3a19a726cb7":[6,0,0,2,1,2,1],
@@ -217,37 +223,31 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1ell__matrix.html#afeb18c524920cfa52a7d56cd0b31b3c1":[6,0,0,25,18],
 "classviennacl_1_1ell__matrix.html#aff440baf9a08f63a1aa886990aaf406b":[6,0,0,25,5],
 "classviennacl_1_1entry__proxy.html":[6,0,0,27],
-"classviennacl_1_1entry__proxy.html#a20d1e6598ba396eca5441e81866692bb":[6,0,0,27,6],
-"classviennacl_1_1entry__proxy.html#a42a889aa89772a30c2d58d5588a3ac04":[6,0,0,27,1],
-"classviennacl_1_1entry__proxy.html#a4433439fd4233b8bc585d8d8f2cc7619":[6,0,0,27,3],
-"classviennacl_1_1entry__proxy.html#a5aab26f84f0a0f33a16c801826e8b5aa":[6,0,0,27,0],
-"classviennacl_1_1entry__proxy.html#a719287b50d86b5c8a047af7dbe4a5b3a":[6,0,0,27,4],
-"classviennacl_1_1entry__proxy.html#a7219f5d36ca71d3bab8987747cb77d1c":[6,0,0,27,10],
-"classviennacl_1_1entry__proxy.html#a9e5cbe868cfad0720aba407d149c75e1":[6,0,0,27,7],
-"classviennacl_1_1entry__proxy.html#ab12fabdb323eefb4892edde6f7b3bf16":[6,0,0,27,8],
-"classviennacl_1_1entry__proxy.html#acf681a2389ab0b31b5f660205f39ab77":[6,0,0,27,2],
-"classviennacl_1_1entry__proxy.html#adc3fc7c7cb5e7602eedd2d3b4ce35e1c":[6,0,0,27,5],
-"classviennacl_1_1entry__proxy.html#ae0c4cf27e795235d75556894e677e0af":[6,0,0,27,11],
-"classviennacl_1_1entry__proxy.html#aeb73ef2abb2e995991e5ee4d10dfb099":[6,0,0,27,9],
+"classviennacl_1_1entry__proxy.html#a1501c30738b60067172267d936c58dcb":[6,0,0,27,6],
+"classviennacl_1_1entry__proxy.html#a37b3fb6e74d991af47f8d32f1dda6c23":[6,0,0,27,4],
+"classviennacl_1_1entry__proxy.html#a48baf86c6dd5f920bc55b011d832788d":[6,0,0,27,2],
+"classviennacl_1_1entry__proxy.html#a59ddb22fd76964d1e5aae646473f9037":[6,0,0,27,10],
+"classviennacl_1_1entry__proxy.html#a5a5957e985504d3e7cf499407f25c9f2":[6,0,0,27,7],
+"classviennacl_1_1entry__proxy.html#a63ef5534007af719594dc60d0c5781f1":[6,0,0,27,1],
+"classviennacl_1_1entry__proxy.html#a771d0d5e6f898d1680b3f8b6059d31ac":[6,0,0,27,8],
+"classviennacl_1_1entry__proxy.html#a7bf17a30153814b8e7855faf18fdd768":[6,0,0,27,0],
+"classviennacl_1_1entry__proxy.html#a8a00214579b33b0f5d6e022cfd10bedd":[6,0,0,27,5],
+"classviennacl_1_1entry__proxy.html#ac21d5341e24b2aa63ed578f8c15afee0":[6,0,0,27,11],
+"classviennacl_1_1entry__proxy.html#ac4d407afb54158096a97a560ec9b169e":[6,0,0,27,9],
+"classviennacl_1_1entry__proxy.html#adc55b3b64bb7f9e78851d294639a17ba":[6,0,0,27,3],
 "classviennacl_1_1hankel__matrix.html":[6,0,0,29],
-"classviennacl_1_1hankel__matrix.html#a20b24d60a29462b8e683e471a1b9dbbc":[6,0,0,29,4],
-"classviennacl_1_1hankel__matrix.html#a2965b9cc1428525b503791ff404ac2f1":[6,0,0,29,12],
-"classviennacl_1_1hankel__matrix.html#a39d10d5bab1e2564a7d34864a5ea38bf":[6,0,0,29,10],
-"classviennacl_1_1hankel__matrix.html#a44bd0dc3e75be825b2383665d1473dbe":[6,0,0,29,8],
-"classviennacl_1_1hankel__matrix.html#a5f49dd26c680c8c03f576cc02f2724f0":[6,0,0,29,3],
-"classviennacl_1_1hankel__matrix.html#a6b584238a8f38c32facfe9dbf3e2792b":[6,0,0,29,0],
-"classviennacl_1_1hankel__matrix.html#a70394fe33c8d39dc5cf0d892cbc4d33d":[6,0,0,29,7],
-"classviennacl_1_1hankel__matrix.html#a724654e6113cca8296d33d3f080c0481":[6,0,0,29,6],
-"classviennacl_1_1hankel__matrix.html#a9336c061fc3ba521106feabe826ae359":[6,0,0,29,9],
-"classviennacl_1_1hankel__matrix.html#abc7d6eeffe38e08ed8374d351b2fc858":[6,0,0,29,2],
-"classviennacl_1_1hankel__matrix.html#abd607e8fd04765fc5693feee660e268c":[6,0,0,29,1],
-"classviennacl_1_1hankel__matrix.html#ad2f2c36d273f68fabc8f0648eb005916":[6,0,0,29,5],
-"classviennacl_1_1hankel__matrix.html#ae1fe055fd4987e7ccc9585eaa169ebb6":[6,0,0,29,11],
-"classviennacl_1_1hyb__matrix.html":[6,0,0,30],
-"classviennacl_1_1hyb__matrix.html#a0394426fd3b91afe253b64fbbfee97b1":[6,0,0,30,2],
-"classviennacl_1_1hyb__matrix.html#a24b112fc2e22907c32646227831d443a":[6,0,0,30,3],
-"classviennacl_1_1hyb__matrix.html#a321b40813370fc067e3b49afed3da469":[6,0,0,30,18],
-"classviennacl_1_1hyb__matrix.html#a4b3f5963def504d05e7ab97b972067f0":[6,0,0,30,9],
-"classviennacl_1_1hyb__matrix.html#a71a65b6963fe30384f160f4cf6c189c8":[6,0,0,30,15],
-"classviennacl_1_1hyb__matrix.html#a78944df9433891f6654713dbbf34ed93":[6,0,0,30,4]
+"classviennacl_1_1hankel__matrix.html#a1fbac16688ba2b0a19d01fd7a8fab24f":[6,0,0,29,2],
+"classviennacl_1_1hankel__matrix.html#a2ca803773036e3301662f3a4ced06513":[6,0,0,29,5],
+"classviennacl_1_1hankel__matrix.html#a3a303ed0b61a75c3ffd75112bf61b558":[6,0,0,29,12],
+"classviennacl_1_1hankel__matrix.html#a43654fc305980d2a437769d12d5cc84f":[6,0,0,29,4],
+"classviennacl_1_1hankel__matrix.html#a7e7f884fed71f2788b57a130bcfbf4a0":[6,0,0,29,7],
+"classviennacl_1_1hankel__matrix.html#a993abaae40c5fbb82c3317ae34ac66b2":[6,0,0,29,8],
+"classviennacl_1_1hankel__matrix.html#aaa2c575a8c1610216885136d43625749":[6,0,0,29,10],
+"classviennacl_1_1hankel__matrix.html#aaf5e49a335315a70ff47f3ff8cc4242d":[6,0,0,29,6],
+"classviennacl_1_1hankel__matrix.html#abdb174b8cb98f87d0092b25ebf5a3c64":[6,0,0,29,9],
+"classviennacl_1_1hankel__matrix.html#ac34afa167dfc0fb8dc91757bb677eec9":[6,0,0,29,3],
+"classviennacl_1_1hankel__matrix.html#ae413c0e546c764e3fcf919cb0248739a":[6,0,0,29,11],
+"classviennacl_1_1hankel__matrix.html#af0cf795b18e66655356e2e27fa66d4c7":[6,0,0,29,0],
+"classviennacl_1_1hankel__matrix.html#afd888bb3d2508de274684d1cb8fe5d0b":[6,0,0,29,1],
+"classviennacl_1_1hyb__matrix.html":[6,0,0,30]
 };
