@@ -1,28 +1,5 @@
 var NAVTREEINDEX20 =
 {
-"scheduler_2execute_8hpp.html#a7969d99d3180d9e8b3f250f8abe04242":[7,0,3,8,0,2],
-"scheduler_2execute_8hpp.html#a7c54b25dd9b7af74a98800e92035d398":[7,0,3,8,0,0],
-"scheduler_2execute_8hpp_source.html":[7,0,3,8,0],
-"scheduler_2forwards_8h.html":[7,0,3,8,10],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914":[7,0,3,8,10,82],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a0eb2fa398999ffdb62792cc553a25f23":[7,0,3,8,10,82,0],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a45aad1cb2159d71779449d7152217727":[7,0,3,8,10,82,2],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a7353714a084a9f822edc26fe2bca4f8a":[7,0,3,8,10,82,4],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a894ffb1bc4900d3f06ec728e04de4e01":[7,0,3,8,10,82,3],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a8dacc89f3e43c4ca287b23d5d89b75c5":[7,0,3,8,10,82,1],
-"scheduler_2forwards_8h.html#a29f7fd027b643066b775562af636e8d3":[7,0,3,8,10,83],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35":[7,0,3,8,10,78],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a075c87768842f364303bb64127453b2d":[7,0,3,8,10,78,42],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a0c239b137d9dd360a6aedfe5f88dca70":[7,0,3,8,10,78,33],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a0cb4cc0174769a4d12a11a040dba7215":[7,0,3,8,10,78,58],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a136719a66d82a037a875a4b1f8411cf0":[7,0,3,8,10,78,18],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1b7ffa7de0c66231664936fc14b3c4f8":[7,0,3,8,10,78,36],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1f934789dd600ee73f7c22bcd8273d61":[7,0,3,8,10,78,13],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1fa11cb4db8cb099a55fafbe7931a5d4":[7,0,3,8,10,78,45],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a23a42cb76dedaa2d0adf725408da2abd":[7,0,3,8,10,78,51],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a23a62bf8d1c42288dfc0e7a8470c1402":[7,0,3,8,10,78,34],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a247f91a6bec2085f3b31f9ec32b76f1b":[7,0,3,8,10,78,46],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a29c513ff24ce91bb30234dc7f23d151a":[7,0,3,8,10,78,55],
 "scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a2ab4584ae045d23d13a57e2ce3b505bd":[7,0,3,8,10,78,19],
 "scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a2bfc469fbd12756a21b5d8d66578ae2c":[7,0,3,8,10,78,11],
 "scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a398108639e7d778512959c8d0cc7f112":[7,0,3,8,10,78,9],
@@ -114,54 +91,46 @@ var NAVTREEINDEX20 =
 "scheduler_2forwards_8h.html#ae691d1992521cd384c3dad19ac46a6c4acc68622943068fc12d1d3d2d76dcc731":[7,0,3,8,10,81,0],
 "scheduler_2forwards_8h_source.html":[7,0,3,8,10],
 "scheduler_8cpp-example.html":[8,25],
-"scheduler__matrix_8cpp.html":[7,0,2,0,33],
-"scheduler__matrix_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,33,3],
-"scheduler__matrix_8cpp.html#a3eeb8dff5404f0ba9ff74f4ee5b9095d":[7,0,2,0,33,5],
-"scheduler__matrix_8cpp.html#a931ce6a0abe4400075e9db9f45456a6d":[7,0,2,0,33,2],
-"scheduler__matrix_8cpp.html#ab3fef5684e0d6531328592e7028143d9":[7,0,2,0,33,4],
-"scheduler__matrix_8cpp.html#adb1975f54982e94e2bcd2db1577c1e67":[7,0,2,0,33,0],
-"scheduler__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,33,1],
-"scheduler__matrix_8cpp_source.html":[7,0,2,0,33],
-"scheduler__matrix__matrix_8cpp.html":[7,0,2,0,34],
-"scheduler__matrix__matrix_8cpp.html#a23a3d893dfd2dd3b809ce30cee04069a":[7,0,2,0,34,2],
-"scheduler__matrix__matrix_8cpp.html#a2a0fa312c59f09be09409aa4ae5ba438":[7,0,2,0,34,7],
-"scheduler__matrix__matrix_8cpp.html#a6c99af123e391ad3264971ecb6ae22e0":[7,0,2,0,34,6],
-"scheduler__matrix__matrix_8cpp.html#a8cbd379f9259e534655784896a6eac6c":[7,0,2,0,34,3],
-"scheduler__matrix__matrix_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,34,5],
-"scheduler__matrix__matrix_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,34,4],
-"scheduler__matrix__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,34,0],
-"scheduler__matrix__matrix_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,34,1],
-"scheduler__matrix__matrix_8cpp_source.html":[7,0,2,0,34],
-"scheduler__matrix__vector_8cpp.html":[7,0,2,0,35],
-"scheduler__matrix__vector_8cpp.html#a0a0eaa55687e5287a400f0265608aefb":[7,0,2,0,35,6],
-"scheduler__matrix__vector_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,35,3],
-"scheduler__matrix__vector_8cpp.html#aacca06eadc801980b85316ba3e9a018b":[7,0,2,0,35,5],
-"scheduler__matrix__vector_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,35,2],
-"scheduler__matrix__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,35,4],
-"scheduler__matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,35,0],
-"scheduler__matrix__vector_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,35,1],
-"scheduler__matrix__vector_8cpp_source.html":[7,0,2,0,35],
-"scheduler__sparse_8cpp.html":[7,0,2,0,36],
-"scheduler__sparse_8cpp.html#a23a3d893dfd2dd3b809ce30cee04069a":[7,0,2,0,36,3],
-"scheduler__sparse_8cpp.html#a8b9a4f6704d0fa5a6499ca7af211c5cf":[7,0,2,0,36,4],
-"scheduler__sparse_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,36,0],
-"scheduler__sparse_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,36,6],
-"scheduler__sparse_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,36,5],
-"scheduler__sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,36,1],
-"scheduler__sparse_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,36,2],
-"scheduler__sparse_8cpp_source.html":[7,0,2,0,36],
-"scheduler__vector_8cpp.html":[7,0,2,0,37],
-"scheduler__vector_8cpp.html#a244af8a9755388ff60c8f62905537ea4":[7,0,2,0,37,6],
-"scheduler__vector_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,37,3],
-"scheduler__vector_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3":[7,0,2,0,37,2],
-"scheduler__vector_8cpp.html#a9f8ddcb40078b98954fd07f7745789ac":[7,0,2,0,37,8],
-"scheduler__vector_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,37,4],
-"scheduler__vector_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,37,9],
-"scheduler__vector_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,37,5],
-"scheduler__vector_8cpp.html#adb1975f54982e94e2bcd2db1577c1e67":[7,0,2,0,37,0],
-"scheduler__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,37,7],
-"scheduler__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,37,1],
-"scheduler__vector_8cpp_source.html":[7,0,2,0,37],
+"scheduler__matrix__matrix_8cpp.html":[7,0,2,0,31],
+"scheduler__matrix__matrix_8cpp.html#a23a3d893dfd2dd3b809ce30cee04069a":[7,0,2,0,31,2],
+"scheduler__matrix__matrix_8cpp.html#a2a0fa312c59f09be09409aa4ae5ba438":[7,0,2,0,31,7],
+"scheduler__matrix__matrix_8cpp.html#a6c99af123e391ad3264971ecb6ae22e0":[7,0,2,0,31,6],
+"scheduler__matrix__matrix_8cpp.html#a8cbd379f9259e534655784896a6eac6c":[7,0,2,0,31,3],
+"scheduler__matrix__matrix_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,31,5],
+"scheduler__matrix__matrix_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,31,4],
+"scheduler__matrix__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,31,0],
+"scheduler__matrix__matrix_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,31,1],
+"scheduler__matrix__matrix_8cpp_source.html":[7,0,2,0,31],
+"scheduler__matrix__vector_8cpp.html":[7,0,2,0,32],
+"scheduler__matrix__vector_8cpp.html#a0a0eaa55687e5287a400f0265608aefb":[7,0,2,0,32,6],
+"scheduler__matrix__vector_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,32,3],
+"scheduler__matrix__vector_8cpp.html#aacca06eadc801980b85316ba3e9a018b":[7,0,2,0,32,5],
+"scheduler__matrix__vector_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,32,2],
+"scheduler__matrix__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,32,4],
+"scheduler__matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,32,0],
+"scheduler__matrix__vector_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,32,1],
+"scheduler__matrix__vector_8cpp_source.html":[7,0,2,0,32],
+"scheduler__sparse_8cpp.html":[7,0,2,0,33],
+"scheduler__sparse_8cpp.html#a23a3d893dfd2dd3b809ce30cee04069a":[7,0,2,0,33,3],
+"scheduler__sparse_8cpp.html#a8b9a4f6704d0fa5a6499ca7af211c5cf":[7,0,2,0,33,4],
+"scheduler__sparse_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,33,0],
+"scheduler__sparse_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,33,6],
+"scheduler__sparse_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,33,5],
+"scheduler__sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,33,1],
+"scheduler__sparse_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,33,2],
+"scheduler__sparse_8cpp_source.html":[7,0,2,0,33],
+"scheduler__vector_8cpp.html":[7,0,2,0,34],
+"scheduler__vector_8cpp.html#a244af8a9755388ff60c8f62905537ea4":[7,0,2,0,34,6],
+"scheduler__vector_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,34,3],
+"scheduler__vector_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3":[7,0,2,0,34,2],
+"scheduler__vector_8cpp.html#a9f8ddcb40078b98954fd07f7745789ac":[7,0,2,0,34,8],
+"scheduler__vector_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,34,4],
+"scheduler__vector_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,34,9],
+"scheduler__vector_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,34,5],
+"scheduler__vector_8cpp.html#adb1975f54982e94e2bcd2db1577c1e67":[7,0,2,0,34,0],
+"scheduler__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,34,7],
+"scheduler__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,34,1],
+"scheduler__vector_8cpp_source.html":[7,0,2,0,34],
 "scrapper_8hpp.html":[7,0,3,2,0,0,2,0,1,2],
 "scrapper_8hpp.html#a48245f1865ac2987c1f3dde5835b1686":[7,0,3,2,0,0,2,0,1,2,2],
 "scrapper_8hpp.html#a5caffda65322a4a4a49c3af6be152ae8":[7,0,3,2,0,0,2,0,1,2,4],
@@ -173,6 +142,16 @@ var NAVTREEINDEX20 =
 "scrapper_8hpp.html#ad06fdc01da2de61376ef2e6e704b1cd7":[7,0,3,2,0,0,2,0,1,2,0],
 "scrapper_8hpp.html#af12b1086558770ed515e50f4cfa9be5f":[7,0,3,2,0,0,2,0,1,2,8],
 "scrapper_8hpp_source.html":[7,0,3,2,0,0,2,0,1,2],
+"self__assign_8cpp.html":[7,0,2,0,35],
+"self__assign_8cpp.html#a2232c79637835d9d6726e8cd4641682b":[7,0,2,0,35,8],
+"self__assign_8cpp.html#a6a9d7ae541b8aeacf44fcc79023abefa":[7,0,2,0,35,5],
+"self__assign_8cpp.html#acda1ebc89c406ec50668d968f5114cdc":[7,0,2,0,35,9],
+"self__assign_8cpp.html#ae4a791f5676aaa157852201665a91e7a":[7,0,2,0,35,3],
+"self__assign_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,35,7],
+"self__assign_8cpp.html#ae7b8fc99d6fc6d62f94e70dcce176e56":[7,0,2,0,35,6],
+"self__assign_8cpp.html#aef70ba38e56622d10182f9755db2ff86":[7,0,2,0,35,4],
+"self__assign_8cpp.html#af6c53df8e537e259f5450969d1e4111a":[7,0,2,0,35,10],
+"self__assign_8cpp_source.html":[7,0,2,0,35],
 "sha1_8hpp.html":[7,0,3,9,4],
 "sha1_8hpp.html#a9adc7cb5201fba46b10f6dbc70b2bc12":[7,0,3,9,4,1],
 "sha1_8hpp_source.html":[7,0,3,9,4],
@@ -197,6 +176,7 @@ var NAVTREEINDEX20 =
 "slice_8hpp_source.html":[7,0,3,25],
 "sliced__ell__matrix_8hpp.html":[7,0,3,26],
 "sliced__ell__matrix_8hpp.html#a40fb810a020b6bd780ee1e12e6d02763":[7,0,3,26,1],
+"sliced__ell__matrix_8hpp.html#ab1bf9bf2d8e0714db63fc999000c1510":[7,0,3,26,2],
 "sliced__ell__matrix_8hpp_source.html":[7,0,3,26],
 "small__matrix_8hpp.html":[7,0,3,4,1,3,4],
 "small__matrix_8hpp.html#a75d03e25caf5c1957fab6334c0d91c31":[7,0,3,4,1,3,4,1],
@@ -237,8 +217,8 @@ var NAVTREEINDEX20 =
 "spai-static_8hpp.html#ae548ee7e9301caf3cc50ada65389bce0":[7,0,3,4,1,3,6,6],
 "spai-static_8hpp_source.html":[7,0,3,4,1,3,6],
 "spai_8cpp-example.html":[8,26],
-"spai_8cpp.html":[7,0,0,1,28],
-"spai_8cpp_source.html":[7,0,0,1,28],
+"spai_8cpp.html":[7,0,0,1,29],
+"spai_8cpp_source.html":[7,0,0,1,29],
 "spai_8hpp.html":[7,0,3,4,39],
 "spai_8hpp.html#a1938ef67659d8ba96e9b9517e680cccf":[7,0,3,4,39,5],
 "spai_8hpp.html#ab87a5b5e7c60eee5c2e45f9ab21c935c":[7,0,3,4,39,4],
@@ -249,5 +229,25 @@ var NAVTREEINDEX20 =
 "sparse__matrix__operations_8hpp.html":[7,0,3,4,40],
 "sparse__matrix__operations_8hpp.html#a02babae1af157516bd1e92d28c711957":[7,0,3,4,40,2],
 "sparse__matrix__operations_8hpp.html#a07ddf85f2f61d198160ffd13bf7aebac":[7,0,3,4,40,7],
-"sparse__matrix__operations_8hpp.html#a2cd904fcd01a99005ca9f83f3c696b41":[7,0,3,4,40,1]
+"sparse__matrix__operations_8hpp.html#a2cd904fcd01a99005ca9f83f3c696b41":[7,0,3,4,40,1],
+"sparse__matrix__operations_8hpp.html#a2ee5dd77d41040e0a937a60346475b84":[7,0,3,4,40,9],
+"sparse__matrix__operations_8hpp.html#a5309df539f189a889f45f5e25098930f":[7,0,3,4,40,4],
+"sparse__matrix__operations_8hpp.html#a5ef8943054b39077573f94234980bd0f":[7,0,3,4,40,8],
+"sparse__matrix__operations_8hpp.html#a926494a1bd9b3c66def0c860bf564b42":[7,0,3,4,40,0],
+"sparse__matrix__operations_8hpp.html#ab85e3912a40d5d479835e7608808f07e":[7,0,3,4,40,3],
+"sparse__matrix__operations_8hpp.html#ac6448c1d1c0cdb1010a146c0238c8d20":[7,0,3,4,40,6],
+"sparse__matrix__operations_8hpp.html#af0e2c481d5920946ce6fce0874cd8138":[7,0,3,4,40,5],
+"sparse__matrix__operations_8hpp_source.html":[7,0,3,4,40],
+"sparse__matrix__operations__solve_8hpp.html":[7,0,3,4,0,18],
+"sparse__matrix__operations__solve_8hpp.html#a0fdaf16a87e07c124373a52254c173ad":[7,0,3,4,0,18,4],
+"sparse__matrix__operations__solve_8hpp.html#a1c1b2731df8afb9c3f915b9d0d639753":[7,0,3,4,0,18,2],
+"sparse__matrix__operations__solve_8hpp.html#a233ac7fb62f71e33255e7c9cba345ed7":[7,0,3,4,0,18,9],
+"sparse__matrix__operations__solve_8hpp.html#a8000df1bca574a42318a5b7edbe6b97f":[7,0,3,4,0,18,0],
+"sparse__matrix__operations__solve_8hpp.html#a9abc8d66c512f9124bbb993eee4b5586":[7,0,3,4,0,18,1],
+"sparse__matrix__operations__solve_8hpp.html#aa12dd112fa13a12a456cf19945adc9c0":[7,0,3,4,0,18,5],
+"sparse__matrix__operations__solve_8hpp.html#aa52e774f145abd8da05d99dc722acc28":[7,0,3,4,0,18,3],
+"sparse__matrix__operations__solve_8hpp.html#acddaf2035898ce13496e3494dd22cd69":[7,0,3,4,0,18,6],
+"sparse__matrix__operations__solve_8hpp.html#adcf87e5dfd0c05d2d88c7be8bf81395a":[7,0,3,4,0,18,11],
+"sparse__matrix__operations__solve_8hpp.html#ae4caa7ec537c21ce87da42e70289633c":[7,0,3,4,0,18,8],
+"sparse__matrix__operations__solve_8hpp.html#af45d44700626214f9474848e09fb9126":[7,0,3,4,0,18,7]
 };
