@@ -1,35 +1,15 @@
 var NAVTREEINDEX21 =
 {
-"sparse__matrix__operations_8hpp.html#a2ee5dd77d41040e0a937a60346475b84":[7,0,3,4,40,9],
-"sparse__matrix__operations_8hpp.html#a5309df539f189a889f45f5e25098930f":[7,0,3,4,40,4],
-"sparse__matrix__operations_8hpp.html#a5ef8943054b39077573f94234980bd0f":[7,0,3,4,40,8],
-"sparse__matrix__operations_8hpp.html#a926494a1bd9b3c66def0c860bf564b42":[7,0,3,4,40,0],
-"sparse__matrix__operations_8hpp.html#ab85e3912a40d5d479835e7608808f07e":[7,0,3,4,40,3],
-"sparse__matrix__operations_8hpp.html#ac6448c1d1c0cdb1010a146c0238c8d20":[7,0,3,4,40,6],
-"sparse__matrix__operations_8hpp.html#af0e2c481d5920946ce6fce0874cd8138":[7,0,3,4,40,5],
-"sparse__matrix__operations_8hpp_source.html":[7,0,3,4,40],
-"sparse__matrix__operations__solve_8hpp.html":[7,0,3,4,0,18],
-"sparse__matrix__operations__solve_8hpp.html#a0fdaf16a87e07c124373a52254c173ad":[7,0,3,4,0,18,4],
-"sparse__matrix__operations__solve_8hpp.html#a1c1b2731df8afb9c3f915b9d0d639753":[7,0,3,4,0,18,2],
-"sparse__matrix__operations__solve_8hpp.html#a233ac7fb62f71e33255e7c9cba345ed7":[7,0,3,4,0,18,9],
-"sparse__matrix__operations__solve_8hpp.html#a8000df1bca574a42318a5b7edbe6b97f":[7,0,3,4,0,18,0],
-"sparse__matrix__operations__solve_8hpp.html#a9abc8d66c512f9124bbb993eee4b5586":[7,0,3,4,0,18,1],
-"sparse__matrix__operations__solve_8hpp.html#aa12dd112fa13a12a456cf19945adc9c0":[7,0,3,4,0,18,5],
-"sparse__matrix__operations__solve_8hpp.html#aa52e774f145abd8da05d99dc722acc28":[7,0,3,4,0,18,3],
-"sparse__matrix__operations__solve_8hpp.html#acddaf2035898ce13496e3494dd22cd69":[7,0,3,4,0,18,6],
-"sparse__matrix__operations__solve_8hpp.html#adcf87e5dfd0c05d2d88c7be8bf81395a":[7,0,3,4,0,18,11],
-"sparse__matrix__operations__solve_8hpp.html#ae4caa7ec537c21ce87da42e70289633c":[7,0,3,4,0,18,8],
-"sparse__matrix__operations__solve_8hpp.html#af45d44700626214f9474848e09fb9126":[7,0,3,4,0,18,7],
 "sparse__matrix__operations__solve_8hpp.html#afd116a080fa6ff167e6845f62c7d5229":[7,0,3,4,0,18,10],
 "sparse__matrix__operations__solve_8hpp_source.html":[7,0,3,4,0,18],
 "sparse__vector_8hpp.html":[7,0,3,4,1,3,9],
 "sparse__vector_8hpp_source.html":[7,0,3,4,1,3,9],
-"spmdm_8cpp.html":[7,0,2,0,39],
-"spmdm_8cpp.html#a69e6d2aea1a54a57c32143a1f1a67443":[7,0,2,0,39,3],
-"spmdm_8cpp.html#ad37b6388e659bcf40d9f782132321b4d":[7,0,2,0,39,1],
-"spmdm_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,39,2],
-"spmdm_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,39,0],
-"spmdm_8cpp_source.html":[7,0,2,0,39],
+"spmdm_8cpp.html":[7,0,2,0,37],
+"spmdm_8cpp.html#a69e6d2aea1a54a57c32143a1f1a67443":[7,0,2,0,37,3],
+"spmdm_8cpp.html#ad37b6388e659bcf40d9f782132321b4d":[7,0,2,0,37,1],
+"spmdm_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,37,2],
+"spmdm_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,37,0],
+"spmdm_8cpp_source.html":[7,0,2,0,37],
 "sse__blas_8hpp.html":[7,0,3,4,2,9],
 "sse__blas_8hpp.html#a6c8d9882f41360d19f6615d06b31d4d3":[7,0,3,4,2,9,5],
 "sse__blas_8hpp.html#a73ae3d8082d7379517630d6d64c1027c":[7,0,3,4,2,9,2],
@@ -63,45 +43,45 @@ var NAVTREEINDEX21 =
 "stride_8hpp.html#a53a39f11907d9098e6f144c87998fe5e":[7,0,3,10,7,1],
 "stride_8hpp.html#ace596004f16c075adbfcd329e6c60e91":[7,0,3,10,7,2],
 "stride_8hpp_source.html":[7,0,3,10,7],
-"struct_vienna_c_l_backend__impl.html":[6,0,9],
-"struct_vienna_c_l_backend__impl.html#a4ac0646f1f1f1cdc2dc7d3b0899fd5b0":[6,0,9,0],
-"struct_vienna_c_l_backend__impl.html#a4ba7ba11806c9207ea5bbd34bdca056b":[6,0,9,3],
-"struct_vienna_c_l_backend__impl.html#a644a5eaaed66eb35c69d5f094a117b87":[6,0,9,2],
-"struct_vienna_c_l_backend__impl.html#aa0382d3f1a5628c16c0fcb19faf6a7f6":[6,0,9,1],
-"struct_vienna_c_l_c_u_d_a_backend__impl.html":[6,0,10],
-"struct_vienna_c_l_host_backend__impl.html":[6,0,11],
-"struct_vienna_c_l_host_scalar__impl.html":[6,0,12],
-"struct_vienna_c_l_host_scalar__impl.html#a3a3cee55ea3498c0fd3ae6feef77bbdf":[6,0,12,1],
-"struct_vienna_c_l_host_scalar__impl.html#a5017f1f1f2d1e9054c4a1b8f5f724211":[6,0,12,0],
-"struct_vienna_c_l_host_scalar__impl.html#a7738a955cabcae09b84f455c1452b18f":[6,0,12,2],
-"struct_vienna_c_l_matrix__impl.html":[6,0,13],
-"struct_vienna_c_l_matrix__impl.html#a1a2591ff60fda8cb4e932ee8e4220e37":[6,0,13,10],
-"struct_vienna_c_l_matrix__impl.html#a1bb3e3df3fe8b7befe40d30780779cb3":[6,0,13,11],
-"struct_vienna_c_l_matrix__impl.html#a39776c9313e28c8c2ef265c3dfcded84":[6,0,13,0],
-"struct_vienna_c_l_matrix__impl.html#a4103855d69aecbe85314a65700a02de3":[6,0,13,2],
-"struct_vienna_c_l_matrix__impl.html#a56404bb5c6aaf0b64c53c89b2f6bc26a":[6,0,13,8],
-"struct_vienna_c_l_matrix__impl.html#a83761810e0c5f91ea10ef3a4167b78d7":[6,0,13,6],
-"struct_vienna_c_l_matrix__impl.html#a93e92d4c7b468cab69b0af60abe4bff0":[6,0,13,1],
-"struct_vienna_c_l_matrix__impl.html#aa4e2d47a634e56bfb4184520792c7f64":[6,0,13,3],
-"struct_vienna_c_l_matrix__impl.html#ab7815c208b9260ca0097909c1892fd0f":[6,0,13,9],
-"struct_vienna_c_l_matrix__impl.html#ac2184140bcb059f7521857a6a5ef4362":[6,0,13,7],
-"struct_vienna_c_l_matrix__impl.html#ad9b5572714d5760e0d6db0d5c4eacbc4":[6,0,13,5],
-"struct_vienna_c_l_matrix__impl.html#ada5cf997e93ae6184f6fd1fb897a7387":[6,0,13,4],
-"struct_vienna_c_l_matrix__impl.html#ae33a64dcfb8dfe7234dddc3270838bec":[6,0,13,12],
-"struct_vienna_c_l_open_c_l_backend__impl.html":[6,0,14],
-"struct_vienna_c_l_open_c_l_backend__impl.html#aa5f97c2ab6d7e2d75d0b378fb0014df7":[6,0,14,0],
-"struct_vienna_c_l_scalar__impl.html":[6,0,15],
-"struct_vienna_c_l_scalar__impl.html#a67d292f8863e566d0efb1f04708264d9":[6,0,15,0],
-"struct_vienna_c_l_scalar__impl.html#a723dd4b75586c0d500b122db2458eb86":[6,0,15,2],
-"struct_vienna_c_l_scalar__impl.html#a995d0345857ac7a6ad47e13021b9abb9":[6,0,15,1],
-"struct_vienna_c_l_scalar__impl.html#af8a28d7c016b5c0b811c46a4bcb4b7c2":[6,0,15,3],
-"struct_vienna_c_l_vector__impl.html":[6,0,16],
-"struct_vienna_c_l_vector__impl.html#a2102cfe143f959a93374f4c1632f3b15":[6,0,16,5],
-"struct_vienna_c_l_vector__impl.html#a277090fedfd0305e92a3f539a4f2d491":[6,0,16,2],
-"struct_vienna_c_l_vector__impl.html#a3cf30b82794eaa7c0dac9f24060b0575":[6,0,16,1],
-"struct_vienna_c_l_vector__impl.html#a843560fa56c6ad15a948b4253d9e0cb8":[6,0,16,3],
-"struct_vienna_c_l_vector__impl.html#a8d5df6fb95c537becef8fe3f574945f9":[6,0,16,4],
-"struct_vienna_c_l_vector__impl.html#ac9f74d13e9df7ce1332e99fca52bacc6":[6,0,16,0],
+"struct_vienna_c_l_backend__impl.html":[6,0,13],
+"struct_vienna_c_l_backend__impl.html#a4ac0646f1f1f1cdc2dc7d3b0899fd5b0":[6,0,13,0],
+"struct_vienna_c_l_backend__impl.html#a4ba7ba11806c9207ea5bbd34bdca056b":[6,0,13,3],
+"struct_vienna_c_l_backend__impl.html#a644a5eaaed66eb35c69d5f094a117b87":[6,0,13,2],
+"struct_vienna_c_l_backend__impl.html#aa0382d3f1a5628c16c0fcb19faf6a7f6":[6,0,13,1],
+"struct_vienna_c_l_c_u_d_a_backend__impl.html":[6,0,14],
+"struct_vienna_c_l_host_backend__impl.html":[6,0,15],
+"struct_vienna_c_l_host_scalar__impl.html":[6,0,16],
+"struct_vienna_c_l_host_scalar__impl.html#a3a3cee55ea3498c0fd3ae6feef77bbdf":[6,0,16,1],
+"struct_vienna_c_l_host_scalar__impl.html#a5017f1f1f2d1e9054c4a1b8f5f724211":[6,0,16,0],
+"struct_vienna_c_l_host_scalar__impl.html#a7738a955cabcae09b84f455c1452b18f":[6,0,16,2],
+"struct_vienna_c_l_matrix__impl.html":[6,0,17],
+"struct_vienna_c_l_matrix__impl.html#a1a2591ff60fda8cb4e932ee8e4220e37":[6,0,17,10],
+"struct_vienna_c_l_matrix__impl.html#a1bb3e3df3fe8b7befe40d30780779cb3":[6,0,17,11],
+"struct_vienna_c_l_matrix__impl.html#a39776c9313e28c8c2ef265c3dfcded84":[6,0,17,0],
+"struct_vienna_c_l_matrix__impl.html#a4103855d69aecbe85314a65700a02de3":[6,0,17,2],
+"struct_vienna_c_l_matrix__impl.html#a56404bb5c6aaf0b64c53c89b2f6bc26a":[6,0,17,8],
+"struct_vienna_c_l_matrix__impl.html#a83761810e0c5f91ea10ef3a4167b78d7":[6,0,17,6],
+"struct_vienna_c_l_matrix__impl.html#a93e92d4c7b468cab69b0af60abe4bff0":[6,0,17,1],
+"struct_vienna_c_l_matrix__impl.html#aa4e2d47a634e56bfb4184520792c7f64":[6,0,17,3],
+"struct_vienna_c_l_matrix__impl.html#ab7815c208b9260ca0097909c1892fd0f":[6,0,17,9],
+"struct_vienna_c_l_matrix__impl.html#ac2184140bcb059f7521857a6a5ef4362":[6,0,17,7],
+"struct_vienna_c_l_matrix__impl.html#ad9b5572714d5760e0d6db0d5c4eacbc4":[6,0,17,5],
+"struct_vienna_c_l_matrix__impl.html#ada5cf997e93ae6184f6fd1fb897a7387":[6,0,17,4],
+"struct_vienna_c_l_matrix__impl.html#ae33a64dcfb8dfe7234dddc3270838bec":[6,0,17,12],
+"struct_vienna_c_l_open_c_l_backend__impl.html":[6,0,18],
+"struct_vienna_c_l_open_c_l_backend__impl.html#aa5f97c2ab6d7e2d75d0b378fb0014df7":[6,0,18,0],
+"struct_vienna_c_l_scalar__impl.html":[6,0,19],
+"struct_vienna_c_l_scalar__impl.html#a67d292f8863e566d0efb1f04708264d9":[6,0,19,0],
+"struct_vienna_c_l_scalar__impl.html#a723dd4b75586c0d500b122db2458eb86":[6,0,19,2],
+"struct_vienna_c_l_scalar__impl.html#a995d0345857ac7a6ad47e13021b9abb9":[6,0,19,1],
+"struct_vienna_c_l_scalar__impl.html#af8a28d7c016b5c0b811c46a4bcb4b7c2":[6,0,19,3],
+"struct_vienna_c_l_vector__impl.html":[6,0,20],
+"struct_vienna_c_l_vector__impl.html#a2102cfe143f959a93374f4c1632f3b15":[6,0,20,5],
+"struct_vienna_c_l_vector__impl.html#a277090fedfd0305e92a3f539a4f2d491":[6,0,20,2],
+"struct_vienna_c_l_vector__impl.html#a3cf30b82794eaa7c0dac9f24060b0575":[6,0,20,1],
+"struct_vienna_c_l_vector__impl.html#a843560fa56c6ad15a948b4253d9e0cb8":[6,0,20,3],
+"struct_vienna_c_l_vector__impl.html#a8d5df6fb95c537becef8fe3f574945f9":[6,0,20,4],
+"struct_vienna_c_l_vector__impl.html#ac9f74d13e9df7ce1332e99fca52bacc6":[6,0,20,0],
 "structmatrix__maker.html":[6,0,2],
 "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html":[6,0,3],
 "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html#aeae2df6ae63978fa4d4e73c2097dfafc":[6,0,3,0],
@@ -111,15 +91,18 @@ var NAVTREEINDEX21 =
 "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html":[6,0,5],
 "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html#adb3efe7c7b6a198fa64e8bbe3829e981":[6,0,5,1],
 "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html#ae9721615acd711ed356c8eb64db6c651":[6,0,5,0],
+"structop__assign.html":[6,0,7],
+"structop__minus__assign.html":[6,0,8],
+"structop__plus__assign.html":[6,0,9],
 "structs_8hpp.html":[7,0,3,4,1,1,5],
 "structs_8hpp_source.html":[7,0,3,4,1,1,5],
-"structtest_data.html":[6,0,7],
-"structtest_data.html#a17b3748f5f39c787969812b2e8323d9c":[6,0,7,1],
-"structtest_data.html#a221ded1c886a86b39e9fef197af7c58b":[6,0,7,5],
-"structtest_data.html#a3c78d34e230ea1a828dceb27180ea700":[6,0,7,2],
-"structtest_data.html#a634014dc338b61c038693642efabff47":[6,0,7,4],
-"structtest_data.html#ad8e3394939d9f0e3e3f33abb01e28af4":[6,0,7,3],
-"structtest_data.html#afbeac1b8842462a94a3204945bc54535":[6,0,7,0],
+"structtest_data.html":[6,0,10],
+"structtest_data.html#a17b3748f5f39c787969812b2e8323d9c":[6,0,10,1],
+"structtest_data.html#a221ded1c886a86b39e9fef197af7c58b":[6,0,10,5],
+"structtest_data.html#a3c78d34e230ea1a828dceb27180ea700":[6,0,10,2],
+"structtest_data.html#a634014dc338b61c038693642efabff47":[6,0,10,4],
+"structtest_data.html#ad8e3394939d9f0e3e3f33abb01e28af4":[6,0,10,3],
+"structtest_data.html#afbeac1b8842462a94a3204945bc54535":[6,0,10,0],
 "structured-matrices_8cpp-example.html":[8,28],
 "structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html":[6,0,0,0,0,0,0],
 "structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html#abd0b5a4c3bfd43ef47b182fcc64b263b":[6,0,0,0,0,0,0,0],
@@ -249,5 +232,22 @@ var NAVTREEINDEX21 =
 "structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html":[6,0,0,2,2,25],
 "structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#a8859a3effbc408c887156a3270377362":[6,0,0,2,2,25,1],
 "structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#afa684b874dcbd93cecc20beaf5d5300b":[6,0,0,2,2,25,0],
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html":[6,0,0,2,2,26]
+"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html":[6,0,0,2,2,26],
+"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#ab9e9f54c99ee5c4fa7b03c86fb3c7bac":[6,0,0,2,2,26,0],
+"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#acd76d9e773edd4ce64ab535898b7ee2e":[6,0,0,2,2,26,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html":[6,0,0,2,2,27],
+"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a0be523ad58edf147b3cd3adfdd58f621":[6,0,0,2,2,27,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a7bf16956f06a6bbf04e1ed2f86e42f3f":[6,0,0,2,2,27,0],
+"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html":[6,0,0,2,2,28],
+"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#a19297e53a833c520335ecc5320807d2c":[6,0,0,2,2,28,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#ad81e702da882bd123ace4a495da13df5":[6,0,0,2,2,28,0],
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html":[6,0,0,2,2,29],
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30737a886c21ee6e8b31b47f812e2312":[6,0,0,2,2,29,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30b3642c00ccbf41e80ddbe1c8857112":[6,0,0,2,2,29,0],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html":[6,0,0,2,2,30],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html":[6,0,0,2,2,31],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html":[6,0,0,2,2,32],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html":[6,0,0,2,2,33],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html":[6,0,0,2,2,34],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html":[6,0,0,2,2,35]
 };
