@@ -1,22 +1,5 @@
 var NAVTREEINDEX22 =
 {
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#ab9e9f54c99ee5c4fa7b03c86fb3c7bac":[6,0,0,2,2,26,0],
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#acd76d9e773edd4ce64ab535898b7ee2e":[6,0,0,2,2,26,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html":[6,0,0,2,2,27],
-"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a0be523ad58edf147b3cd3adfdd58f621":[6,0,0,2,2,27,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a7bf16956f06a6bbf04e1ed2f86e42f3f":[6,0,0,2,2,27,0],
-"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html":[6,0,0,2,2,28],
-"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#a19297e53a833c520335ecc5320807d2c":[6,0,0,2,2,28,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#ad81e702da882bd123ace4a495da13df5":[6,0,0,2,2,28,0],
-"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html":[6,0,0,2,2,29],
-"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30737a886c21ee6e8b31b47f812e2312":[6,0,0,2,2,29,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30b3642c00ccbf41e80ddbe1c8857112":[6,0,0,2,2,29,0],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html":[6,0,0,2,2,30],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html":[6,0,0,2,2,31],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html":[6,0,0,2,2,32],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html":[6,0,0,2,2,33],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html":[6,0,0,2,2,34],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html":[6,0,0,2,2,35],
 "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html":[6,0,0,2,2,36],
 "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html":[6,0,0,2,2,37],
 "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html":[6,0,0,2,2,38],
@@ -249,5 +232,22 @@ var NAVTREEINDEX22 =
 "structviennacl_1_1row__major__tag.html":[6,0,0,133],
 "structviennacl_1_1scalar__vector.html":[6,0,0,144],
 "structviennacl_1_1scalar__vector.html#ab1110376608b81d0b1aa4c76a0a2ef46":[6,0,0,144,0],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html":[6,0,0,7,1]
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html":[6,0,0,7,1],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a004b1ebc6c30dd52c7864dac15ffdcf5":[6,0,0,7,1,5],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0137a9fb11a97dc62832a72edfc2a293":[6,0,0,7,1,67],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0a66d1b72140af28cf0ea82d506bcde5":[6,0,0,7,1,20],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0aa9cfe0e6438394453e18cb4b2d5f88":[6,0,0,7,1,31],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a141b47baf5ef9c2fc1e8e1775914911b":[6,0,0,7,1,13],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1518bbf03064436bbd8ebaeb27d02231":[6,0,0,7,1,37],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1714016d2100f1e6c1eb08112c5548de":[6,0,0,7,1,16],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1d729198a4b9c4ea8cf639984d332c68":[6,0,0,7,1,43],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1f921a78e2e942208e8bc1c7ecc52401":[6,0,0,7,1,6],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a23d2b2c40c404c9005452d9810967293":[6,0,0,7,1,40],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2634adf095e95920e6c8fa5b484cb833":[6,0,0,7,1,33],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2a0432d9e22968d482b8b66058a3fbe5":[6,0,0,7,1,70],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2fb5c22bfceabb819702ff1ea87f2eb0":[6,0,0,7,1,18],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a35fe2d6c0ef69f04ad2c94d7b10c7cdd":[6,0,0,7,1,52],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a3f7a03c29c0d4d79d20ef759f4fe88e2":[6,0,0,7,1,32],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a403714231bcd54f45438a296bfe7a631":[6,0,0,7,1,64],
+"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a44882e8993eb5d47c40152868cdf5556":[6,0,0,7,1,46]
 };
