@@ -1,19 +1,10 @@
 var NAVTREEINDEX25 =
 {
-"tql2_8cpp.html":[7,0,0,1,31],
-"tql2_8cpp_source.html":[7,0,0,1,31],
-"tql2_8hpp.html":[7,0,3,4,43],
-"tql2_8hpp.html#a3fe3eb20d4dcda794259fd6a6d30afb6":[7,0,3,4,43,0],
-"tql2_8hpp_source.html":[7,0,3,4,43],
-"tql_8cpp.html":[7,0,2,0,42],
-"tql_8cpp.html#a6ebf6899d6c1c8b7b9d09be872c05aae":[7,0,2,0,42,0],
-"tql_8cpp.html#a8204a5a8d4b9cbed559875cb65848656":[7,0,2,0,42,6],
-"tql_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,42,1],
-"tql_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,42,3],
-"tql_8cpp.html#addc3b5bf488c68ee7b156e7554638126":[7,0,2,0,42,5],
-"tql_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,42,4],
-"tql_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,42,2],
-"tql_8cpp_source.html":[7,0,2,0,42],
+"tql_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,40,3],
+"tql_8cpp.html#addc3b5bf488c68ee7b156e7554638126":[7,0,2,0,40,5],
+"tql_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,40,4],
+"tql_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,40,2],
+"tql_8cpp_source.html":[7,0,2,0,40],
 "traits_2context_8hpp.html":[7,0,3,10,1],
 "traits_2context_8hpp.html#a4a96792186391df8fe04d4ea2708b298":[7,0,3,10,1,1],
 "traits_2context_8hpp.html#a6707f5dab8f482170d2046a605f46ef8":[7,0,3,10,1,0],
@@ -53,15 +44,15 @@ var NAVTREEINDEX25 =
 "vandermonde__matrix__operations_8hpp.html":[7,0,3,4,45],
 "vandermonde__matrix__operations_8hpp.html#a64b4f1d927a4df6416192cc8e69ed8aa":[7,0,3,4,45,0],
 "vandermonde__matrix__operations_8hpp_source.html":[7,0,3,4,45],
-"vector-io_8hpp.html":[7,0,0,1,32],
-"vector-io_8hpp.html#a2153ea85c265deda214decb215af6553":[7,0,0,1,32,2],
-"vector-io_8hpp.html#a303954a45833b84192a6dcf3065f85e3":[7,0,0,1,32,3],
-"vector-io_8hpp.html#a55017a0da63da825e2f206bac4607a7a":[7,0,0,1,32,1],
-"vector-io_8hpp.html#aeb6c51d29fa8bd684fa1e649415ad9c3":[7,0,0,1,32,4],
-"vector-io_8hpp_source.html":[7,0,0,1,32],
+"vector-io_8hpp.html":[7,0,0,1,33],
+"vector-io_8hpp.html#a2153ea85c265deda214decb215af6553":[7,0,0,1,33,2],
+"vector-io_8hpp.html#a303954a45833b84192a6dcf3065f85e3":[7,0,0,1,33,3],
+"vector-io_8hpp.html#a55017a0da63da825e2f206bac4607a7a":[7,0,0,1,33,1],
+"vector-io_8hpp.html#aeb6c51d29fa8bd684fa1e649415ad9c3":[7,0,0,1,33,4],
+"vector-io_8hpp_source.html":[7,0,0,1,33],
 "vector-range_8cpp-example.html":[8,30],
-"vector-range_8cpp.html":[7,0,0,1,33],
-"vector-range_8cpp_source.html":[7,0,0,1,33],
+"vector-range_8cpp.html":[7,0,0,1,34],
+"vector-range_8cpp_source.html":[7,0,0,1,34],
 "vector_8hpp.html":[7,0,3,29],
 "vector_8hpp.html#a0250b6a52a40df48e3ee18f1db6e4747":[7,0,3,29,55],
 "vector_8hpp.html#a0a9b799cd9d2b4ae4376c5216d5ac93f":[7,0,3,29,40],
@@ -125,43 +116,43 @@ var NAVTREEINDEX25 =
 "vector__axpy__template_8hpp_source.html":[7,0,3,2,1,6],
 "vector__def_8hpp.html":[7,0,3,1,1],
 "vector__def_8hpp_source.html":[7,0,3,1,1],
-"vector__float__double_8cpp.html":[7,0,2,0,43],
-"vector__float__double_8cpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,43,1],
-"vector__float__double_8cpp.html#a244af8a9755388ff60c8f62905537ea4":[7,0,2,0,43,7],
-"vector__float__double_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,43,4],
-"vector__float__double_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3":[7,0,2,0,43,3],
-"vector__float__double_8cpp.html#a9f8ddcb40078b98954fd07f7745789ac":[7,0,2,0,43,9],
-"vector__float__double_8cpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,43,0],
-"vector__float__double_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,43,5],
-"vector__float__double_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,43,10],
-"vector__float__double_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,43,6],
-"vector__float__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,43,8],
-"vector__float__double_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,43,2],
-"vector__float__double_8cpp_source.html":[7,0,2,0,43],
-"vector__int_8cpp.html":[7,0,2,0,44],
-"vector__int_8cpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,44,0],
-"vector__int_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,44,3],
-"vector__int_8cpp.html#a3886c6e131e2471b850fd7a4c85b4441":[7,0,2,0,44,8],
-"vector__int_8cpp.html#a804cb698245c0bd3e4d40119b9f1dcde":[7,0,2,0,44,2],
-"vector__int_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,44,9],
-"vector__int_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,44,4],
-"vector__int_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,44,6],
-"vector__int_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,44,5],
-"vector__int_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,44,7],
-"vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,44,1],
-"vector__int_8cpp_source.html":[7,0,2,0,44],
-"vector__multi__inner__prod_8cpp.html":[7,0,2,0,45],
-"vector__multi__inner__prod_8cpp.html#a244af8a9755388ff60c8f62905537ea4":[7,0,2,0,45,5],
-"vector__multi__inner__prod_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,45,2],
-"vector__multi__inner__prod_8cpp.html#a3894ad8174371e2fdf40f647826a50e6":[7,0,2,0,45,6],
-"vector__multi__inner__prod_8cpp.html#a3b968d2d9c975862628248f76fbc56db":[7,0,2,0,45,8],
-"vector__multi__inner__prod_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3":[7,0,2,0,45,1],
-"vector__multi__inner__prod_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,45,3],
-"vector__multi__inner__prod_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,45,9],
-"vector__multi__inner__prod_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,45,4],
-"vector__multi__inner__prod_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,45,7],
-"vector__multi__inner__prod_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,45,0],
-"vector__multi__inner__prod_8cpp_source.html":[7,0,2,0,45],
+"vector__float__double_8cpp.html":[7,0,2,0,41],
+"vector__float__double_8cpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,41,1],
+"vector__float__double_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,41,3],
+"vector__float__double_8cpp.html#a372953495e22570af3e118e7535ca6ce":[7,0,2,0,41,10],
+"vector__float__double_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3":[7,0,2,0,41,2],
+"vector__float__double_8cpp.html#a772fd210577b8c77b874ab50fea12807":[7,0,2,0,41,9],
+"vector__float__double_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,41,4],
+"vector__float__double_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,41,11],
+"vector__float__double_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,41,5],
+"vector__float__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,41,7],
+"vector__float__double_8cpp.html#af21acead8d9fc830d018ebd10045d086":[7,0,2,0,41,6],
+"vector__float__double_8cpp.html#af58462ac765a0fb3b2f35f6245acd131":[7,0,2,0,41,8],
+"vector__float__double_8cpp_source.html":[7,0,2,0,41],
+"vector__int_8cpp.html":[7,0,2,0,42],
+"vector__int_8cpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,42,0],
+"vector__int_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,42,3],
+"vector__int_8cpp.html#a3886c6e131e2471b850fd7a4c85b4441":[7,0,2,0,42,8],
+"vector__int_8cpp.html#a804cb698245c0bd3e4d40119b9f1dcde":[7,0,2,0,42,2],
+"vector__int_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,42,9],
+"vector__int_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,42,4],
+"vector__int_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,42,6],
+"vector__int_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,42,5],
+"vector__int_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,42,7],
+"vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,42,1],
+"vector__int_8cpp_source.html":[7,0,2,0,42],
+"vector__multi__inner__prod_8cpp.html":[7,0,2,0,43],
+"vector__multi__inner__prod_8cpp.html#a244af8a9755388ff60c8f62905537ea4":[7,0,2,0,43,5],
+"vector__multi__inner__prod_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,43,2],
+"vector__multi__inner__prod_8cpp.html#a3894ad8174371e2fdf40f647826a50e6":[7,0,2,0,43,6],
+"vector__multi__inner__prod_8cpp.html#a3b968d2d9c975862628248f76fbc56db":[7,0,2,0,43,8],
+"vector__multi__inner__prod_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3":[7,0,2,0,43,1],
+"vector__multi__inner__prod_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,43,3],
+"vector__multi__inner__prod_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,43,9],
+"vector__multi__inner__prod_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,43,4],
+"vector__multi__inner__prod_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,43,7],
+"vector__multi__inner__prod_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,43,0],
+"vector__multi__inner__prod_8cpp_source.html":[7,0,2,0,43],
 "vector__operations_8hpp.html":[7,0,3,4,46],
 "vector__operations_8hpp.html#a029d42a0d83d6db9f4737ee3443cbeb0":[7,0,3,4,46,27],
 "vector__operations_8hpp.html#a0be57ce7d327b479a4e9dc8bf0cb43ac":[7,0,3,4,46,7],
@@ -218,25 +209,25 @@ var NAVTREEINDEX25 =
 "vector__proxy_8hpp.html#ae54949548426c32cb2b7f651e41497ef":[7,0,3,30,13],
 "vector__proxy_8hpp.html#aff87e6c12c0c4774fb92fa88e0c44806":[7,0,3,30,8],
 "vector__proxy_8hpp_source.html":[7,0,3,30],
-"vector__uint_8cpp.html":[7,0,2,0,46],
-"vector__uint_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,46,2],
-"vector__uint_8cpp.html#a3886c6e131e2471b850fd7a4c85b4441":[7,0,2,0,46,7],
-"vector__uint_8cpp.html#a804cb698245c0bd3e4d40119b9f1dcde":[7,0,2,0,46,1],
-"vector__uint_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,46,8],
-"vector__uint_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,46,3],
-"vector__uint_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,46,5],
-"vector__uint_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,46,4],
-"vector__uint_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,46,6],
-"vector__uint_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,46,0],
-"vector__uint_8cpp_source.html":[7,0,2,0,46],
+"vector__uint_8cpp.html":[7,0,2,0,44],
+"vector__uint_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,44,2],
+"vector__uint_8cpp.html#a3886c6e131e2471b850fd7a4c85b4441":[7,0,2,0,44,7],
+"vector__uint_8cpp.html#a804cb698245c0bd3e4d40119b9f1dcde":[7,0,2,0,44,1],
+"vector__uint_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,44,8],
+"vector__uint_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,44,3],
+"vector__uint_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,44,5],
+"vector__uint_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,44,4],
+"vector__uint_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,44,6],
+"vector__uint_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,44,0],
+"vector__uint_8cpp_source.html":[7,0,2,0,44],
 "version_8hpp.html":[7,0,3,31],
 "version_8hpp.html#a3d45b5315400d02d83c3c11f0ee6b494":[7,0,3,31,1],
 "version_8hpp.html#ac4f352886df7f3da2e958797a8629b87":[7,0,3,31,2],
 "version_8hpp.html#acd20c0ad13043a1bda59bd2332c6fb3e":[7,0,3,31,0],
 "version_8hpp_source.html":[7,0,3,31],
 "viennacl-info_8cpp-example.html":[8,31],
-"viennacl-info_8cpp.html":[7,0,0,1,34],
-"viennacl-info_8cpp_source.html":[7,0,0,1,34],
+"viennacl-info_8cpp.html":[7,0,0,1,35],
+"viennacl-info_8cpp_source.html":[7,0,0,1,35],
 "viennacl_8hpp.html":[7,0,1,0,0],
 "viennacl_8hpp.html#a0274c655632f37c36f006b68540abcea":[7,0,1,0,0,38],
 "viennacl_8hpp.html#a061757a06f70dc035a9aca46d2ccc66b":[7,0,1,0,0,29],
@@ -249,5 +240,14 @@ var NAVTREEINDEX25 =
 "viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519ab858179ff3fab038dbb2e5e5c460084d":[7,0,1,0,0,12,2],
 "viennacl_8hpp.html#a11d74dcf290a16551b33c97ef3838d99":[7,0,1,0,0,51],
 "viennacl_8hpp.html#a13a355b36c39dd0cb150164a92f46f0a":[7,0,1,0,0,19],
-"viennacl_8hpp.html#a174b55e484de020634bb234f383f6078":[7,0,1,0,0,27]
+"viennacl_8hpp.html#a174b55e484de020634bb234f383f6078":[7,0,1,0,0,27],
+"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015":[7,0,1,0,0,11],
+"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015a29e68210bd47ec635255b78ebd6ace0f":[7,0,1,0,0,11,1],
+"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015ad8df17d6ac56ff06dab0547d9af8fc30":[7,0,1,0,0,11,0],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87b":[7,0,1,0,0,10],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87ba9914ab727e34dc6fe58e77516df3713c":[7,0,1,0,0,10,2],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87bab82a7582744552581791992e118399f1":[7,0,1,0,0,10,0],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87bac579d3deafe1fce44c8ae9319ea3e13b":[7,0,1,0,0,10,1],
+"viennacl_8hpp.html#a23c8eb8eab78d14cc4ba56e14e1441cd":[7,0,1,0,0,66],
+"viennacl_8hpp.html#a24361d25205ad5256ee2c130712299a9":[7,0,1,0,0,67]
 };
