@@ -1,19 +1,25 @@
 var NAVTREEINDEX3 =
 {
-"classviennacl_1_1hyb__matrix.html#a83cb07a6aa15fcf960b40b4a82fdc574":[6,0,0,30,10],
-"classviennacl_1_1hyb__matrix.html#a85c8cfa2f303c11c2e8ebea46e4ea400":[6,0,0,30,11],
-"classviennacl_1_1hyb__matrix.html#a8e95fcc738d25bcbf274dbfd538f000f":[6,0,0,30,16],
-"classviennacl_1_1hyb__matrix.html#a98dfc47bcf5178ccd6c888f39b2ec0e4":[6,0,0,30,5],
-"classviennacl_1_1hyb__matrix.html#a9a02c98d000f3d316c297300a8117246":[6,0,0,30,0],
-"classviennacl_1_1hyb__matrix.html#ab5f077832dd0efade9f5037327a1786d":[6,0,0,30,17],
-"classviennacl_1_1hyb__matrix.html#ac80cf4d3ab3ab38f398405ecf88419cd":[6,0,0,30,14],
-"classviennacl_1_1hyb__matrix.html#ac93fc5b3db82256f22d780618ad362db":[6,0,0,30,7],
-"classviennacl_1_1hyb__matrix.html#acd8b0197ad9c5a92ed26cf6ec3ce6137":[6,0,0,30,12],
-"classviennacl_1_1hyb__matrix.html#ad283de5ab491d075b34788c3293890ce":[6,0,0,30,8],
+"classviennacl_1_1hyb__matrix.html#a2b1b27a7e14035e94742129e5b6c00b5":[6,0,0,30,12],
+"classviennacl_1_1hyb__matrix.html#a2f620a72f3f44c563dd9fdcd9c788324":[6,0,0,30,15],
+"classviennacl_1_1hyb__matrix.html#a3863e14e65c82bffbd5ac3f42ae72ffc":[6,0,0,30,7],
+"classviennacl_1_1hyb__matrix.html#a4a711db273189338d5c47793777f7a98":[6,0,0,30,18],
+"classviennacl_1_1hyb__matrix.html#a69cbf2163826b43e4cb6717199fd0474":[6,0,0,30,16],
+"classviennacl_1_1hyb__matrix.html#a6bb63193628710851ff6da33f70a1ce9":[6,0,0,30,6],
+"classviennacl_1_1hyb__matrix.html#a7ae9a356c47a3298619625df2392eb4e":[6,0,0,30,17],
+"classviennacl_1_1hyb__matrix.html#a829531b89c462d336136881073bb5fc4":[6,0,0,30,1],
+"classviennacl_1_1hyb__matrix.html#a933565e3dda939889ac55a64decbc96f":[6,0,0,30,13],
+"classviennacl_1_1hyb__matrix.html#a94d49d42b85e5424296c47823d036dfc":[6,0,0,30,9],
+"classviennacl_1_1hyb__matrix.html#a99f19b7f1f18c18ec9f86920548f72bb":[6,0,0,30,11],
+"classviennacl_1_1hyb__matrix.html#ab5017072236a32e18afbca82b02dec86":[6,0,0,30,0],
+"classviennacl_1_1hyb__matrix.html#ac062f8671868c51dd2b4eeab4cdb9168":[6,0,0,30,14],
+"classviennacl_1_1hyb__matrix.html#ac6d3dd46446e7aecfad31403e5a6857d":[6,0,0,30,8],
+"classviennacl_1_1hyb__matrix.html#ace03d552e9b1e5ae6de9484a8a1218ae":[6,0,0,30,5],
+"classviennacl_1_1hyb__matrix.html#ad6a8c43b8c110e6dc7377eecaf4fce7c":[6,0,0,30,2],
+"classviennacl_1_1hyb__matrix.html#ad937b9563e4c764fd4bd7858b3d95803":[6,0,0,30,3],
+"classviennacl_1_1hyb__matrix.html#adc4674678fa747c72ef2937fb7cef141":[6,0,0,30,4],
+"classviennacl_1_1hyb__matrix.html#ae35b2e77d7d4ecb2ea13770a5c3f4670":[6,0,0,30,10],
 "classviennacl_1_1hyb__matrix.html#aea26738cc380b7355a9ca42d0c47497d":[6,0,0,30,19],
-"classviennacl_1_1hyb__matrix.html#aed5ff60ddfef1cd59108064a5d4cdd7f":[6,0,0,30,13],
-"classviennacl_1_1hyb__matrix.html#af433c1695c1607b3b4f81a464bda22b6":[6,0,0,30,1],
-"classviennacl_1_1hyb__matrix.html#af90d7f7564c2e70301ea71f7a994f245":[6,0,0,30,6],
 "classviennacl_1_1identity__matrix.html":[6,0,0,31],
 "classviennacl_1_1identity__matrix.html#a08fccf1a11df6b16574d06c518748525":[6,0,0,31,0],
 "classviennacl_1_1identity__matrix.html#ae2a1c61b696a5f38b99d7acdc05068e7":[6,0,0,31,1],
@@ -243,11 +249,5 @@ var NAVTREEINDEX3 =
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ac2cabe20900909465d4f78368611e251":[6,0,0,4,1,0,5,4],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ac488087c92d47d8f400f524ba5857071":[6,0,0,4,1,0,5,11],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#adab776ab70ecca767a16044f462f35c5":[6,0,0,4,1,0,5,10],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ae1c58ea9ff93afc2992e3c24ba0a5a13":[6,0,0,4,1,0,5,19],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#aefe2e025be1e1caeea7ae2f238b8e492":[6,0,0,4,1,0,5,16],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html":[6,0,0,4,1,0,6],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a00756e2673490d7ff66157f81e934824":[6,0,0,4,1,0,6,0],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a48373cb1ea0622b2681f9e0a76c2e03e":[6,0,0,4,1,0,6,8],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a53d845014ef1c8d03ff6e40e5cae2f13":[6,0,0,4,1,0,6,7],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a664118ce72ee88a3bf52026a80c1efaf":[6,0,0,4,1,0,6,2]
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ae1c58ea9ff93afc2992e3c24ba0a5a13":[6,0,0,4,1,0,5,19]
 };
