@@ -1,5 +1,11 @@
 var NAVTREEINDEX4 =
 {
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#aefe2e025be1e1caeea7ae2f238b8e492":[6,0,0,4,1,0,5,16],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html":[6,0,0,4,1,0,6],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a00756e2673490d7ff66157f81e934824":[6,0,0,4,1,0,6,0],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a48373cb1ea0622b2681f9e0a76c2e03e":[6,0,0,4,1,0,6,8],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a53d845014ef1c8d03ff6e40e5cae2f13":[6,0,0,4,1,0,6,7],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a664118ce72ee88a3bf52026a80c1efaf":[6,0,0,4,1,0,6,2],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a6efe3ab857ef8a25a28990c3712a32c3":[6,0,0,4,1,0,6,3],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a93b7b5743ecab247b79efc4ac4e806f9":[6,0,0,4,1,0,6,10],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a995ee6d6be91346f2bf177661e31db15":[6,0,0,4,1,0,6,1],
@@ -224,18 +230,18 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#a964acb6fb9cda96c9ff15ad9e60dadb4":[6,0,0,4,35,0],
 "classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#aabfc6ef7298c66e9189107614fe1a297":[6,0,0,4,35,1],
 "classviennacl_1_1matrix.html":[6,0,0,62],
-"classviennacl_1_1matrix.html#a1de4d71a10ba9b60a01005bae51027b5":[6,0,0,62,0],
-"classviennacl_1_1matrix.html#a69431725e09b2b73606dee084c962d7f":[6,0,0,62,11],
-"classviennacl_1_1matrix.html#a8a5ce7e676c57d1f0acd746951d32fec":[6,0,0,62,9],
-"classviennacl_1_1matrix.html#aa1d160f8ee553be461e27550d33a774e":[6,0,0,62,1],
-"classviennacl_1_1matrix.html#ab3ef00115276f179a8cd2172f9738e33":[6,0,0,62,3],
-"classviennacl_1_1matrix.html#ab8eb950050017f961faf5ac0184e934c":[6,0,0,62,8],
-"classviennacl_1_1matrix.html#ac3cd72a83b58d55a61357669bee23b38":[6,0,0,62,2],
-"classviennacl_1_1matrix.html#ac8dad9e664244e4a6dd9f45e061a4adc":[6,0,0,62,7],
-"classviennacl_1_1matrix.html#ad5fde9fad4e61456dfd9a4818bf210d0":[6,0,0,62,10],
-"classviennacl_1_1matrix.html#adae9b1fad83885bd3162031e012ed3ea":[6,0,0,62,4],
-"classviennacl_1_1matrix.html#adde2f19fc84b9d96db059b9bb9af448d":[6,0,0,62,5],
-"classviennacl_1_1matrix.html#aedafac235f345bca2e555930a748415d":[6,0,0,62,6],
+"classviennacl_1_1matrix.html#a4ee409dd9bb90fb9324758e786a9220c":[6,0,0,62,7],
+"classviennacl_1_1matrix.html#a4f2838c746c5a8db1377898ee44489e0":[6,0,0,62,1],
+"classviennacl_1_1matrix.html#a52fe7272d3d01be023e7e80d2e31085c":[6,0,0,62,9],
+"classviennacl_1_1matrix.html#a677954883f3e9baac8fabfc61879a045":[6,0,0,62,4],
+"classviennacl_1_1matrix.html#a743efa0137f5f82478a8a1b615a738a4":[6,0,0,62,3],
+"classviennacl_1_1matrix.html#a79ae164ce8f984f303304d90f042bdcf":[6,0,0,62,8],
+"classviennacl_1_1matrix.html#a8467bf0d29df43906d388c961ad6a573":[6,0,0,62,0],
+"classviennacl_1_1matrix.html#a85f7c011fe21676c6a790d770e817787":[6,0,0,62,6],
+"classviennacl_1_1matrix.html#a9004170f7d1aca2ef3379927170f4564":[6,0,0,62,2],
+"classviennacl_1_1matrix.html#a912547a8b6b58c92375f84e27bb6d054":[6,0,0,62,11],
+"classviennacl_1_1matrix.html#aaaf86c2934b1e93a48c616d0c915f76c":[6,0,0,62,5],
+"classviennacl_1_1matrix.html#adf2592ae9254d226e24a26389a04721c":[6,0,0,62,10],
 "classviennacl_1_1matrix__base.html":[6,0,0,63],
 "classviennacl_1_1matrix__base.html#a00e30fdc61081a73995b54175a91d220":[6,0,0,63,19],
 "classviennacl_1_1matrix__base.html#a050371bcbfcc677b0514f1a00c9bdf67":[6,0,0,63,4],
@@ -243,11 +249,5 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1matrix__base.html#a0a523347f5392d5afd43c6b41cbbc6ce":[6,0,0,63,54],
 "classviennacl_1_1matrix__base.html#a15ec879f9e85a6fc209454b0bf137084":[6,0,0,63,50],
 "classviennacl_1_1matrix__base.html#a21c79063d8aa5108bdec78b7ee720da8":[6,0,0,63,24],
-"classviennacl_1_1matrix__base.html#a24e4f5fa27a1af5ad47e52a97c065d68":[6,0,0,63,52],
-"classviennacl_1_1matrix__base.html#a25b797fdf4d3c841cae4d047f9cfbaee":[6,0,0,63,36],
-"classviennacl_1_1matrix__base.html#a28087e6cd79a3eb13df18b40092966d3":[6,0,0,63,56],
-"classviennacl_1_1matrix__base.html#a2896fa7b137959c57bcb5966a2a37870":[6,0,0,63,25],
-"classviennacl_1_1matrix__base.html#a2a789435ff884ce9f1ff9d65025ba3e7":[6,0,0,63,3],
-"classviennacl_1_1matrix__base.html#a2b8c9fe73ee98c4a55ac0d116ee9df38":[6,0,0,63,5],
-"classviennacl_1_1matrix__base.html#a2cdca5a19d0e0d46a0ace69f1724b714":[6,0,0,63,28]
+"classviennacl_1_1matrix__base.html#a24e4f5fa27a1af5ad47e52a97c065d68":[6,0,0,63,52]
 };
