@@ -1,5 +1,11 @@
 var NAVTREEINDEX5 =
 {
+"classviennacl_1_1matrix__base.html#a25b797fdf4d3c841cae4d047f9cfbaee":[6,0,0,63,36],
+"classviennacl_1_1matrix__base.html#a28087e6cd79a3eb13df18b40092966d3":[6,0,0,63,56],
+"classviennacl_1_1matrix__base.html#a2896fa7b137959c57bcb5966a2a37870":[6,0,0,63,25],
+"classviennacl_1_1matrix__base.html#a2a789435ff884ce9f1ff9d65025ba3e7":[6,0,0,63,3],
+"classviennacl_1_1matrix__base.html#a2b8c9fe73ee98c4a55ac0d116ee9df38":[6,0,0,63,5],
+"classviennacl_1_1matrix__base.html#a2cdca5a19d0e0d46a0ace69f1724b714":[6,0,0,63,28],
 "classviennacl_1_1matrix__base.html#a33997bfe92e860894b22f5bb518a1290":[6,0,0,63,7],
 "classviennacl_1_1matrix__base.html#a38f0caaff139f738da4d629a19eb8133":[6,0,0,63,45],
 "classviennacl_1_1matrix__base.html#a4082cd3586bc99deb68733257b30c51f":[6,0,0,63,15],
@@ -54,16 +60,16 @@ var NAVTREEINDEX5 =
 "classviennacl_1_1matrix__expression.html#aa2c582e8d2c1cafbf2ffdf05c9fdfaca":[6,0,0,64,2],
 "classviennacl_1_1matrix__expression.html#ad8516f3a2ef4db4d5379fb64832fd39f":[6,0,0,64,5],
 "classviennacl_1_1matrix__iterator.html":[6,0,0,65],
-"classviennacl_1_1matrix__iterator.html#a121be30f9b9c7585e30d14dd0cdcc6a3":[6,0,0,65,0],
-"classviennacl_1_1matrix__iterator.html#a1d773c1b5ee19bc68b400442a9550e2e":[6,0,0,65,4],
-"classviennacl_1_1matrix__iterator.html#a2cab0902708eef3409d060525e7b1bd3":[6,0,0,65,7],
-"classviennacl_1_1matrix__iterator.html#a4801a7780c28b98488cfb2bf75c668c3":[6,0,0,65,6],
-"classviennacl_1_1matrix__iterator.html#a4ef6bffdf5f728b0bbba6ba175a0a4d9":[6,0,0,65,8],
-"classviennacl_1_1matrix__iterator.html#a6831a7e228fd80e84711d82e2362c6db":[6,0,0,65,5],
-"classviennacl_1_1matrix__iterator.html#a70cfd358baf22f4ee9570f1a6b7c1701":[6,0,0,65,2],
-"classviennacl_1_1matrix__iterator.html#a817d81d889d73ac2dc6e6177e062bd7a":[6,0,0,65,1],
-"classviennacl_1_1matrix__iterator.html#a895218ddd37e5f964c30bc89d0cd1781":[6,0,0,65,9],
-"classviennacl_1_1matrix__iterator.html#ac35c319df57718089c7f39d97733e1ba":[6,0,0,65,3],
+"classviennacl_1_1matrix__iterator.html#a15bda6557c012f86dc73d712bc71d7f3":[6,0,0,65,7],
+"classviennacl_1_1matrix__iterator.html#a1837364083cd08f862d3ea5608af5f82":[6,0,0,65,2],
+"classviennacl_1_1matrix__iterator.html#a3ff1ff49f79aea6ba824ecdb460ecc14":[6,0,0,65,1],
+"classviennacl_1_1matrix__iterator.html#a839f7b14cdb91361b88dd6b230d6b505":[6,0,0,65,8],
+"classviennacl_1_1matrix__iterator.html#a9b8eeaefaa8bf5276b8d63cf3a471ade":[6,0,0,65,4],
+"classviennacl_1_1matrix__iterator.html#ab0dc7706eacde70d1857372b602b6bad":[6,0,0,65,3],
+"classviennacl_1_1matrix__iterator.html#ab5b8c98222880e6ae5f92d54c7d06e14":[6,0,0,65,6],
+"classviennacl_1_1matrix__iterator.html#ae11cd06a58c70e8a4f90fd5e1946a9ee":[6,0,0,65,0],
+"classviennacl_1_1matrix__iterator.html#ae473cc7d80378c7384b365d4959457df":[6,0,0,65,5],
+"classviennacl_1_1matrix__iterator.html#af1aee4972f71999a4f46dac773543530":[6,0,0,65,9],
 "classviennacl_1_1matrix__range.html":[6,0,0,66],
 "classviennacl_1_1matrix__range.html#a100b1ddda26bfd792b34b666c0dc23e2":[6,0,0,66,8],
 "classviennacl_1_1matrix__range.html#a294649e885898124628094aa3acd5fa5":[6,0,0,66,4],
@@ -243,11 +249,5 @@ var NAVTREEINDEX5 =
 "classviennacl_1_1ocl_1_1handle.html#abd32b02babef2794751f39eb749a556a":[6,0,0,5,15,6],
 "classviennacl_1_1ocl_1_1handle.html#ae3177c23936042f8984cc6f09f9e83d6":[6,0,0,5,15,3],
 "classviennacl_1_1ocl_1_1handle.html#ae422ce46a3a48223c08b87cead97bf7e":[6,0,0,5,15,0],
-"classviennacl_1_1ocl_1_1handle.html#ae9699f5b1f8d8df4eba7bacf0a563f32":[6,0,0,5,15,8],
-"classviennacl_1_1ocl_1_1handle.html#aedfb2501c3d363bf46127d03cab9ad2f":[6,0,0,5,15,2],
-"classviennacl_1_1ocl_1_1handle__inc__dec__helper.html":[6,0,0,5,16],
-"classviennacl_1_1ocl_1_1image__format__mismatch.html":[6,0,0,5,17],
-"classviennacl_1_1ocl_1_1image__format__not__supported.html":[6,0,0,5,18],
-"classviennacl_1_1ocl_1_1invalid__arg__index.html":[6,0,0,5,19],
-"classviennacl_1_1ocl_1_1invalid__arg__size.html":[6,0,0,5,20]
+"classviennacl_1_1ocl_1_1handle.html#ae9699f5b1f8d8df4eba7bacf0a563f32":[6,0,0,5,15,8]
 };
