@@ -1,5 +1,11 @@
 var NAVTREEINDEX6 =
 {
+"classviennacl_1_1ocl_1_1handle.html#aedfb2501c3d363bf46127d03cab9ad2f":[6,0,0,5,15,2],
+"classviennacl_1_1ocl_1_1handle__inc__dec__helper.html":[6,0,0,5,16],
+"classviennacl_1_1ocl_1_1image__format__mismatch.html":[6,0,0,5,17],
+"classviennacl_1_1ocl_1_1image__format__not__supported.html":[6,0,0,5,18],
+"classviennacl_1_1ocl_1_1invalid__arg__index.html":[6,0,0,5,19],
+"classviennacl_1_1ocl_1_1invalid__arg__size.html":[6,0,0,5,20],
 "classviennacl_1_1ocl_1_1invalid__arg__value.html":[6,0,0,5,21],
 "classviennacl_1_1ocl_1_1invalid__binary.html":[6,0,0,5,22],
 "classviennacl_1_1ocl_1_1invalid__buffer__size.html":[6,0,0,5,23],
@@ -123,53 +129,53 @@ var NAVTREEINDEX6 =
 "classviennacl_1_1ocl_1_1program.html#acd547941bc65e0a26eb2d6a9c3e4c29f":[6,0,0,5,64,8],
 "classviennacl_1_1ocl_1_1unknown__error.html":[6,0,0,5,66],
 "classviennacl_1_1scalar.html":[6,0,0,134],
-"classviennacl_1_1scalar.html#a039864953bf3d52090a2745d2fe6fd7d":[6,0,0,134,36],
-"classviennacl_1_1scalar.html#a08003a51f240beb986e87e89c3e5aadb":[6,0,0,134,26],
-"classviennacl_1_1scalar.html#a0c8acf00720f9f1e6905afa49f161195":[6,0,0,134,42],
-"classviennacl_1_1scalar.html#a0e537abe4622c337c128fdeb69fa7bc3":[6,0,0,134,13],
-"classviennacl_1_1scalar.html#a0fb54e68e728d5498beccd8f576f2824":[6,0,0,134,4],
-"classviennacl_1_1scalar.html#a1348460f9568c82b03e702f0f462b103":[6,0,0,134,31],
-"classviennacl_1_1scalar.html#a13841f655ad0db828a051dc5c493f62e":[6,0,0,134,11],
-"classviennacl_1_1scalar.html#a20696140c3c8be4a8e57eac4c981e901":[6,0,0,134,16],
-"classviennacl_1_1scalar.html#a2848490d989bc3bbc43bce9c9e2e7e47":[6,0,0,134,46],
-"classviennacl_1_1scalar.html#a300abf63fd0a8c7d16a86b5c38fcba85":[6,0,0,134,19],
-"classviennacl_1_1scalar.html#a3a1c64828845f9cb3ff95c9b74d7d91e":[6,0,0,134,15],
-"classviennacl_1_1scalar.html#a40e8ee6244282b6fbf78721ad882d7f3":[6,0,0,134,43],
-"classviennacl_1_1scalar.html#a4796cc006370a23ad39c219345b8f9d1":[6,0,0,134,28],
-"classviennacl_1_1scalar.html#a4d3f381ef0e11f0982008478d6880260":[6,0,0,134,23],
-"classviennacl_1_1scalar.html#a4dd25a5b21b73666beb53be74c6600c0":[6,0,0,134,34],
-"classviennacl_1_1scalar.html#a5084e4fb32433ce7f89db0b360d02d6e":[6,0,0,134,12],
-"classviennacl_1_1scalar.html#a61edbb3444dc11d3f9a486471bb7c73f":[6,0,0,134,22],
-"classviennacl_1_1scalar.html#a61f087873af5cf044919a9d8cc65148b":[6,0,0,134,44],
-"classviennacl_1_1scalar.html#a62e91650a0e4c8bfea7295ec2ec135ae":[6,0,0,134,9],
-"classviennacl_1_1scalar.html#a69ce10d4e191713197693808422b44fa":[6,0,0,134,14],
-"classviennacl_1_1scalar.html#a6ade6278192bdccdea73d652572d0eff":[6,0,0,134,10],
-"classviennacl_1_1scalar.html#a6ae18afad2a90e658dad9f13590d6233":[6,0,0,134,24],
-"classviennacl_1_1scalar.html#a809eec0b71ad355e477d4373b752cdbc":[6,0,0,134,27],
-"classviennacl_1_1scalar.html#a86b08f019e042e64980409be388f964d":[6,0,0,134,17],
-"classviennacl_1_1scalar.html#a875ae8b5e6e94c647d7e936ceefcb6af":[6,0,0,134,1],
-"classviennacl_1_1scalar.html#a9a62e56c8941de87f86b6b7ccd4987e3":[6,0,0,134,7],
-"classviennacl_1_1scalar.html#a9aac3b41ba11b615ac4b7386760d8817":[6,0,0,134,37],
-"classviennacl_1_1scalar.html#aa6cfc729c8415bd77ead0279029ff10a":[6,0,0,134,0],
-"classviennacl_1_1scalar.html#aa99c65862c6bfdf615b500343a499a53":[6,0,0,134,45],
-"classviennacl_1_1scalar.html#aae8ff8c9d2f2c6a4f5dd949f357351fb":[6,0,0,134,38],
-"classviennacl_1_1scalar.html#ab3423f018ea6f514563afe6c9aa22b90":[6,0,0,134,5],
-"classviennacl_1_1scalar.html#ab66c8839c17398e14b580ce106a5065a":[6,0,0,134,18],
-"classviennacl_1_1scalar.html#abba3283c5cbc4b256b93d98cbeb7c547":[6,0,0,134,20],
-"classviennacl_1_1scalar.html#abca016cd21e4ad7b64613ce01f4b5d1b":[6,0,0,134,35],
-"classviennacl_1_1scalar.html#abe434dd18296ba57abd06953e18ff54d":[6,0,0,134,21],
-"classviennacl_1_1scalar.html#abf40c59a34e3ef69f94a6dce2864579a":[6,0,0,134,32],
-"classviennacl_1_1scalar.html#ac4a8f1294091d07ce08a843143447916":[6,0,0,134,39],
-"classviennacl_1_1scalar.html#ac9ae9cb3d8a2a4ac9b9f351b9c6728f0":[6,0,0,134,2],
-"classviennacl_1_1scalar.html#ad5a9f875223d34af2cf32c31fe38c7df":[6,0,0,134,29],
-"classviennacl_1_1scalar.html#ae52bd107e3502d5a3a617b5a2f5c2553":[6,0,0,134,8],
-"classviennacl_1_1scalar.html#ae930cde127fae5e9121b7fe1a70279d5":[6,0,0,134,41],
-"classviennacl_1_1scalar.html#af05f82cd1a2e83039743260ac20510d1":[6,0,0,134,25],
-"classviennacl_1_1scalar.html#af1efa3d0a079e942373354692ecd2645":[6,0,0,134,3],
-"classviennacl_1_1scalar.html#af534e2813fd3c2e452713b2744de19c8":[6,0,0,134,30],
-"classviennacl_1_1scalar.html#af82f32946ff33d23156c922a2be7c5c6":[6,0,0,134,40],
-"classviennacl_1_1scalar.html#afa017f43747cb3373bb3c7ef7b980c19":[6,0,0,134,33],
-"classviennacl_1_1scalar.html#afc9662763b781600f5daa2ae22961a29":[6,0,0,134,6],
+"classviennacl_1_1scalar.html#a08c2d9ff4896a158886dcd25e5adb8d3":[6,0,0,134,38],
+"classviennacl_1_1scalar.html#a0d3e0ad91f3fcd6b01421a8736a09f56":[6,0,0,134,2],
+"classviennacl_1_1scalar.html#a1158f00ae60e1814779bc280019b77fb":[6,0,0,134,13],
+"classviennacl_1_1scalar.html#a1edb6d67dceb3c1e0a35b296a25ff247":[6,0,0,134,17],
+"classviennacl_1_1scalar.html#a2402edbb5081a3129c3ed51cae1c821a":[6,0,0,134,18],
+"classviennacl_1_1scalar.html#a247ef5ba45ecfa89cf77f88f1ea944c0":[6,0,0,134,21],
+"classviennacl_1_1scalar.html#a2550463c69ac48380b81784c2d033835":[6,0,0,134,5],
+"classviennacl_1_1scalar.html#a29593690a9b384bbfd5f6ec8b83420e8":[6,0,0,134,15],
+"classviennacl_1_1scalar.html#a2baf935224e17d6ff9d3dbd9a9e200ea":[6,0,0,134,33],
+"classviennacl_1_1scalar.html#a336274152948771e58a151ced13ab590":[6,0,0,134,36],
+"classviennacl_1_1scalar.html#a397022764ab50cb43eb26323d6289649":[6,0,0,134,14],
+"classviennacl_1_1scalar.html#a59a856b45ab90c25c50a28a87a5e96a6":[6,0,0,134,45],
+"classviennacl_1_1scalar.html#a633f9442401801c504485d3bf40137ae":[6,0,0,134,25],
+"classviennacl_1_1scalar.html#a64235c3e5db6f4ae8481f73262158da9":[6,0,0,134,16],
+"classviennacl_1_1scalar.html#a6706e7de76559bbf0c59b080d8c23af8":[6,0,0,134,44],
+"classviennacl_1_1scalar.html#a677d9162e070ba140d32200dc8286d1c":[6,0,0,134,0],
+"classviennacl_1_1scalar.html#a67c0b9d5ee5e1525b17d51daa939ace2":[6,0,0,134,12],
+"classviennacl_1_1scalar.html#a6e015ff1e1e91d34b62cf84324aafed7":[6,0,0,134,27],
+"classviennacl_1_1scalar.html#a6f9bee9cfee9774b8152064f91db74a3":[6,0,0,134,22],
+"classviennacl_1_1scalar.html#a74523d98c54af86ddbfbd105b81b4cb4":[6,0,0,134,35],
+"classviennacl_1_1scalar.html#a74a7c48ebab16d449260ee545e8d4a16":[6,0,0,134,8],
+"classviennacl_1_1scalar.html#a77ed90aa6e021bb56a16036dff9bf840":[6,0,0,134,24],
+"classviennacl_1_1scalar.html#a7ce155edb3984c0d4ac55f176b2b98a8":[6,0,0,134,42],
+"classviennacl_1_1scalar.html#a8454ca86b8e813bbcc9dd8d2848ae661":[6,0,0,134,41],
+"classviennacl_1_1scalar.html#a86fc93687caec15554bf9899b8b4b5fe":[6,0,0,134,37],
+"classviennacl_1_1scalar.html#a886772924333d38c331ff6075f52aaee":[6,0,0,134,6],
+"classviennacl_1_1scalar.html#a8b1050438e0ac684bc427c28ca518c72":[6,0,0,134,43],
+"classviennacl_1_1scalar.html#a8b356ca09132e5f02b1ed3d98c3d56a6":[6,0,0,134,20],
+"classviennacl_1_1scalar.html#a8f1444dd3d6625ad55c9ee448a89bffc":[6,0,0,134,26],
+"classviennacl_1_1scalar.html#a8fdf64948b6d57df95d2eb948ec0d309":[6,0,0,134,19],
+"classviennacl_1_1scalar.html#a93ddffb91eb58839512f20e1f31e3eee":[6,0,0,134,3],
+"classviennacl_1_1scalar.html#a984dbf64266ea3c69a3881c3adc047c4":[6,0,0,134,11],
+"classviennacl_1_1scalar.html#a9e3fc554897e2d89583e44b23c5dbacb":[6,0,0,134,31],
+"classviennacl_1_1scalar.html#a9ed196c307e0d8651db96554f601ea0b":[6,0,0,134,28],
+"classviennacl_1_1scalar.html#aa21ce8cf63c4eb0ba5dc73cce6887edd":[6,0,0,134,34],
+"classviennacl_1_1scalar.html#aa7833efb94a6e4bef447de465ce792a3":[6,0,0,134,40],
+"classviennacl_1_1scalar.html#ab2648786b83a24feaeb3acee44d9d1f3":[6,0,0,134,29],
+"classviennacl_1_1scalar.html#abc196fa7a5c88c211509bc08b6b3cffb":[6,0,0,134,23],
+"classviennacl_1_1scalar.html#abe064f0f208940ca6cf641e9f6c10d2e":[6,0,0,134,9],
+"classviennacl_1_1scalar.html#ace0a5bc265d1adb46887d9357d1a9a48":[6,0,0,134,39],
+"classviennacl_1_1scalar.html#ad055379bae77025ac33511134cd4d235":[6,0,0,134,32],
+"classviennacl_1_1scalar.html#adc0be626c3180f31f27a17ccb1e6826d":[6,0,0,134,1],
+"classviennacl_1_1scalar.html#ae23752527f0a3839de0ad8f4e58086e8":[6,0,0,134,4],
+"classviennacl_1_1scalar.html#ae5e3379620c912103a6ebf441f62ff74":[6,0,0,134,10],
+"classviennacl_1_1scalar.html#ae879be2125165b53e30fdf6a614d9ed2":[6,0,0,134,7],
+"classviennacl_1_1scalar.html#ae91913100fba02dc781872c78afc2eb1":[6,0,0,134,30],
+"classviennacl_1_1scalar.html#afa2d31bbedb21aeefd47b305e4638866":[6,0,0,134,46],
 "classviennacl_1_1scalar__expression.html":[6,0,0,135],
 "classviennacl_1_1scalar__expression.html#a0193d061e7248e70783129db29a557d5":[6,0,0,135,3],
 "classviennacl_1_1scalar__expression.html#a53b924f0f346fb455ae3dc8a06f53c27":[6,0,0,135,1],
@@ -243,11 +249,5 @@ var NAVTREEINDEX6 =
 "classviennacl_1_1sliced__ell__matrix.html#a31d5fa9ec25dcfeb260f7e11c4db6571":[6,0,0,145,11],
 "classviennacl_1_1sliced__ell__matrix.html#a362dc0c5f0d644cbcf6514f3b3ee6529":[6,0,0,145,3],
 "classviennacl_1_1sliced__ell__matrix.html#a40c479e880ef7e7f50ed67cda91bb8e7":[6,0,0,145,20],
-"classviennacl_1_1sliced__ell__matrix.html#a45249ad5b44d0f506adc27e1e18aecdf":[6,0,0,145,12],
-"classviennacl_1_1sliced__ell__matrix.html#a727fd3a25232545c59204885ff3e32d4":[6,0,0,145,10],
-"classviennacl_1_1sliced__ell__matrix.html#a94043424c01974b2db8062f74f625825":[6,0,0,145,9],
-"classviennacl_1_1sliced__ell__matrix.html#aa59ae796d592a679a4c6036ba84f61b0":[6,0,0,145,13],
-"classviennacl_1_1sliced__ell__matrix.html#aa725bf2d5b213f119bd4b9fe9258c201":[6,0,0,145,5],
-"classviennacl_1_1sliced__ell__matrix.html#aa9a7f4003687cae9a2af97f9fa328db5":[6,0,0,145,17],
-"classviennacl_1_1sliced__ell__matrix.html#ab8a2233384ac8dcdb85b5385706548a1":[6,0,0,145,15]
+"classviennacl_1_1sliced__ell__matrix.html#a45249ad5b44d0f506adc27e1e18aecdf":[6,0,0,145,12]
 };
