@@ -1,13 +1,19 @@
 var NAVTREEINDEX8 =
 {
-"classviennacl_1_1vector__iterator.html#a3d6f0cdf4dc263a0158620734e1e5c0b":[6,0,0,158,0],
-"classviennacl_1_1vector__iterator.html#a569410cd7f08cff5c98dfccf36d8e4af":[6,0,0,158,2],
-"classviennacl_1_1vector__iterator.html#a5e0e454f6331493d811d0c01e5f62a7a":[6,0,0,158,9],
-"classviennacl_1_1vector__iterator.html#a65a068f2037b7ab51d1bb2c3b3ffaaad":[6,0,0,158,3],
-"classviennacl_1_1vector__iterator.html#a66cfad479c0e3fc45e0b01aed8cf44d7":[6,0,0,158,8],
-"classviennacl_1_1vector__iterator.html#a945eb5d3193eaad1c776c1b7666d0e98":[6,0,0,158,10],
-"classviennacl_1_1vector__iterator.html#aa7ffa22176b67ae742e7cdacc96cf739":[6,0,0,158,1],
-"classviennacl_1_1vector__iterator.html#adf08866ed77efe9aa69bfb9a678dd7ca":[6,0,0,158,7],
+"classviennacl_1_1vector__expression.html#af32367d489747d02c0e48e5fcca12469":[6,0,0,157,5],
+"classviennacl_1_1vector__expression.html#aff94c356857f48e8d676ec82c6f98c03":[6,0,0,157,2],
+"classviennacl_1_1vector__iterator.html":[6,0,0,158],
+"classviennacl_1_1vector__iterator.html#a070223d6eefc8da36c64a4c47618b154":[6,0,0,158,2],
+"classviennacl_1_1vector__iterator.html#a07383f1103e3fb45a61f55d5d39b9022":[6,0,0,158,8],
+"classviennacl_1_1vector__iterator.html#a16509d8f948514a2f81e0b83cf06396e":[6,0,0,158,10],
+"classviennacl_1_1vector__iterator.html#a4110a9e5c6b1c76fc16ee7afb3bee1f6":[6,0,0,158,6],
+"classviennacl_1_1vector__iterator.html#a54c60d200c37f74c74ae7f019533d8e4":[6,0,0,158,1],
+"classviennacl_1_1vector__iterator.html#a5514f0c1b4c70ee63b73a00f6fb91357":[6,0,0,158,4],
+"classviennacl_1_1vector__iterator.html#a5862045814c6cf2004f8208321c7d4cc":[6,0,0,158,3],
+"classviennacl_1_1vector__iterator.html#a70abd3b6fea5777f3af802e1fdd1134f":[6,0,0,158,7],
+"classviennacl_1_1vector__iterator.html#acc28ef3263b6eb16360b2e39ab1bcf9a":[6,0,0,158,0],
+"classviennacl_1_1vector__iterator.html#ade476415f537c00a88beb0b59c3d950e":[6,0,0,158,5],
+"classviennacl_1_1vector__iterator.html#afc719587759e23e8b0700622eeed6591":[6,0,0,158,9],
 "classviennacl_1_1vector__range.html":[6,0,0,159],
 "classviennacl_1_1vector__range.html#a0e8ff91829f522c94dac80759ff20afe":[6,0,0,159,9],
 "classviennacl_1_1vector__range.html#a200a915e7a287327517a5d003221d0dd":[6,0,0,159,11],
@@ -128,22 +134,22 @@ var NAVTREEINDEX8 =
 "cuda_2bisect__kernel__calls_8hpp_source.html":[7,0,3,4,0,0],
 "cuda_2direct__solve_8hpp.html":[7,0,3,4,0,7],
 "cuda_2direct__solve_8hpp.html#a061e47445ab2119df45a77a786d9b8bf":[7,0,3,4,0,7,2],
-"cuda_2direct__solve_8hpp.html#a098bcfa45d9c8d789991dc299870ca07":[7,0,3,4,0,7,4],
 "cuda_2direct__solve_8hpp.html#a4779cdb0e79ce4b9a30532f40c961018":[7,0,3,4,0,7,9],
 "cuda_2direct__solve_8hpp.html#a50854d28f6bd464ca4b805bfd66a4b9b":[7,0,3,4,0,7,16],
-"cuda_2direct__solve_8hpp.html#a5999a491e81dc145191bdef35dd844bd":[7,0,3,4,0,7,14],
 "cuda_2direct__solve_8hpp.html#a718784f1f7a78c70fb7ad64108a96fe8":[7,0,3,4,0,7,12],
 "cuda_2direct__solve_8hpp.html#a76a50acd52862ae7c5098d6118a3a40e":[7,0,3,4,0,7,13],
 "cuda_2direct__solve_8hpp.html#a77a3c252de6f55b557d62883d827d61f":[7,0,3,4,0,7,0],
 "cuda_2direct__solve_8hpp.html#a7a3f3d35a029c92cc6f37f4b8eda7407":[7,0,3,4,0,7,17],
-"cuda_2direct__solve_8hpp.html#a7e26784f234784f4f096e57a6cb5ebc8":[7,0,3,4,0,7,15],
 "cuda_2direct__solve_8hpp.html#a892996ac658d03ad1adaec5cda5c5482":[7,0,3,4,0,7,1],
-"cuda_2direct__solve_8hpp.html#aa2295ab8fa917ba72b6d3931076fe295":[7,0,3,4,0,7,5],
+"cuda_2direct__solve_8hpp.html#ab89c01aa6feda324fd81d4f50743cee5":[7,0,3,4,0,7,14],
+"cuda_2direct__solve_8hpp.html#abb2f5d395f245df3d05018965384434d":[7,0,3,4,0,7,5],
 "cuda_2direct__solve_8hpp.html#ac293095cb20f7d5b3738d5ef28a92784":[7,0,3,4,0,7,7],
 "cuda_2direct__solve_8hpp.html#ac6f9bc7461fa1c13342aca0a248271f6":[7,0,3,4,0,7,3],
+"cuda_2direct__solve_8hpp.html#acb0b34e3ac22c72081eceaabeab80f22":[7,0,3,4,0,7,4],
 "cuda_2direct__solve_8hpp.html#adb4bb3e10b636b052d515e603ce7a032":[7,0,3,4,0,7,10],
-"cuda_2direct__solve_8hpp.html#ae07c24137a3bc67e6e67906fa939ab98":[7,0,3,4,0,7,6],
+"cuda_2direct__solve_8hpp.html#ae1945d12693c4e77ad857853e4312249":[7,0,3,4,0,7,6],
 "cuda_2direct__solve_8hpp.html#af481ca18e99cf50dd520d9e7eb720262":[7,0,3,4,0,7,11],
+"cuda_2direct__solve_8hpp.html#afb2fa1855c70722f6f33f1f1007bc9a9":[7,0,3,4,0,7,15],
 "cuda_2direct__solve_8hpp.html#afecd9de1634f971cfd4dce2d5ad0b3e5":[7,0,3,4,0,7,8],
 "cuda_2direct__solve_8hpp_source.html":[7,0,3,4,0,7],
 "cuda_2fft__operations_8hpp.html":[7,0,3,4,0,8],
@@ -191,6 +197,7 @@ var NAVTREEINDEX8 =
 "cuda_2iterative__operations_8hpp.html#a0025f3051fda53e94137ffcd7dffff0e":[7,0,3,4,0,9,36],
 "cuda_2iterative__operations_8hpp.html#a085a61ef1f2fceeb591d6d7edd0bcb4e":[7,0,3,4,0,9,20],
 "cuda_2iterative__operations_8hpp.html#a1295be3c0567f5ee1675315d939d2961":[7,0,3,4,0,9,5],
+"cuda_2iterative__operations_8hpp.html#a15bebdac73a80ac68a4f71f2e468ff03":[7,0,3,4,0,9,1],
 "cuda_2iterative__operations_8hpp.html#a1e20ba11b18ef4d72f83d8e607f87b31":[7,0,3,4,0,9,12],
 "cuda_2iterative__operations_8hpp.html#a2210bf2052e1542a16afd8e7bb36c8aa":[7,0,3,4,0,9,30],
 "cuda_2iterative__operations_8hpp.html#a2e9e7aa9bcc654c9d8ed46fe9866fa59":[7,0,3,4,0,9,35],
@@ -205,6 +212,7 @@ var NAVTREEINDEX8 =
 "cuda_2iterative__operations_8hpp.html#a6c9f7768d5c2e10330ab997498f41453":[7,0,3,4,0,9,3],
 "cuda_2iterative__operations_8hpp.html#a6ca0c953be9082c14a9276435897d2e3":[7,0,3,4,0,9,38],
 "cuda_2iterative__operations_8hpp.html#a704ee2a70cf3563e3928fec38ac16bc0":[7,0,3,4,0,9,16],
+"cuda_2iterative__operations_8hpp.html#a75736f7687babaabe269f432b681503c":[7,0,3,4,0,9,15],
 "cuda_2iterative__operations_8hpp.html#a7f57426fbc4a00904dc1719dc0ce2951":[7,0,3,4,0,9,32],
 "cuda_2iterative__operations_8hpp.html#a7f982f594432ad424f4cb6e774b8fa19":[7,0,3,4,0,9,8],
 "cuda_2iterative__operations_8hpp.html#a86390fe48798192c7390e39d92f97520":[7,0,3,4,0,9,0],
@@ -214,7 +222,6 @@ var NAVTREEINDEX8 =
 "cuda_2iterative__operations_8hpp.html#aa83c7101b05e9185f660f930ca9efb2c":[7,0,3,4,0,9,22],
 "cuda_2iterative__operations_8hpp.html#ab06346505de4a3b8bf2a1ff523622903":[7,0,3,4,0,9,13],
 "cuda_2iterative__operations_8hpp.html#ab458dfdb7b06602a42f588468fe8db75":[7,0,3,4,0,9,27],
-"cuda_2iterative__operations_8hpp.html#ab69dde2aac4eacd92a126e22e089d578":[7,0,3,4,0,9,15],
 "cuda_2iterative__operations_8hpp.html#acaaa759ba8f6ed9ce08b8e2d7eb17eac":[7,0,3,4,0,9,29],
 "cuda_2iterative__operations_8hpp.html#ad40f19322bc978ffba33972c6f63ff48":[7,0,3,4,0,9,28],
 "cuda_2iterative__operations_8hpp.html#ad6e3793be60ca5210a56f8d2c8fccd7f":[7,0,3,4,0,9,17],
@@ -225,7 +232,6 @@ var NAVTREEINDEX8 =
 "cuda_2iterative__operations_8hpp.html#aef20cd32ec9f7c6299573e19318f976a":[7,0,3,4,0,9,24],
 "cuda_2iterative__operations_8hpp.html#af050e6eba3a68ce30af78180bf8fda4a":[7,0,3,4,0,9,11],
 "cuda_2iterative__operations_8hpp.html#af13d83b719540f28d9ec7a3c1feece02":[7,0,3,4,0,9,14],
-"cuda_2iterative__operations_8hpp.html#af50f0e1c8dd5fc58ac6b9c3856358763":[7,0,3,4,0,9,1],
 "cuda_2iterative__operations_8hpp.html#af8a1bdfc669f947e93987f66d3090172":[7,0,3,4,0,9,26],
 "cuda_2iterative__operations_8hpp_source.html":[7,0,3,4,0,9],
 "cuda_2matrix__operations_8hpp.html":[7,0,3,4,0,10],
@@ -243,11 +249,5 @@ var NAVTREEINDEX8 =
 "cuda_2matrix__operations_8hpp.html#a2f2692acec11817fd1ef26c63d052245":[7,0,3,4,0,10,41],
 "cuda_2matrix__operations_8hpp.html#a35b884c529815e76862fd445d3232a8b":[7,0,3,4,0,10,15],
 "cuda_2matrix__operations_8hpp.html#a3b7535979abdede56147bc5ff52314fd":[7,0,3,4,0,10,1],
-"cuda_2matrix__operations_8hpp.html#a42be7c8aa70b6d1d33b41b19dae6ffd4":[7,0,3,4,0,10,25],
-"cuda_2matrix__operations_8hpp.html#a4c4e9facf296d533b6b9f0b0c23a88c7":[7,0,3,4,0,10,22],
-"cuda_2matrix__operations_8hpp.html#a4ef8acb7819438761f82f3284d7acd5e":[7,0,3,4,0,10,3],
-"cuda_2matrix__operations_8hpp.html#a5561702a83a13b07b7101754c93158c2":[7,0,3,4,0,10,33],
-"cuda_2matrix__operations_8hpp.html#a596b46152810f915c06bd322a4aed316":[7,0,3,4,0,10,38],
-"cuda_2matrix__operations_8hpp.html#a5a0dcc19dab2b7813538d308393c3224":[7,0,3,4,0,10,36],
-"cuda_2matrix__operations_8hpp.html#a6d9facffc2ee10180885ed71950f4aea":[7,0,3,4,0,10,24]
+"cuda_2matrix__operations_8hpp.html#a42be7c8aa70b6d1d33b41b19dae6ffd4":[7,0,3,4,0,10,25]
 };
