@@ -1,5 +1,11 @@
 var NAVTREEINDEX9 =
 {
+"cuda_2matrix__operations_8hpp.html#a4c4e9facf296d533b6b9f0b0c23a88c7":[7,0,3,4,0,10,22],
+"cuda_2matrix__operations_8hpp.html#a4ef8acb7819438761f82f3284d7acd5e":[7,0,3,4,0,10,3],
+"cuda_2matrix__operations_8hpp.html#a5561702a83a13b07b7101754c93158c2":[7,0,3,4,0,10,33],
+"cuda_2matrix__operations_8hpp.html#a596b46152810f915c06bd322a4aed316":[7,0,3,4,0,10,38],
+"cuda_2matrix__operations_8hpp.html#a5a0dcc19dab2b7813538d308393c3224":[7,0,3,4,0,10,36],
+"cuda_2matrix__operations_8hpp.html#a6d9facffc2ee10180885ed71950f4aea":[7,0,3,4,0,10,24],
 "cuda_2matrix__operations_8hpp.html#a70728abd4e950c940cb4ab08ea643347":[7,0,3,4,0,10,4],
 "cuda_2matrix__operations_8hpp.html#a71614a410d5ebdd500b3c8ed52a4bd1a":[7,0,3,4,0,10,29],
 "cuda_2matrix__operations_8hpp.html#a896e84eed510eabefb25c2dc08bffef4":[7,0,3,4,0,10,0],
@@ -52,48 +58,49 @@ var NAVTREEINDEX9 =
 "cuda_2scalar__operations_8hpp_source.html":[7,0,3,4,0,16],
 "cuda_2sparse__matrix__operations_8hpp.html":[7,0,3,4,0,17],
 "cuda_2sparse__matrix__operations_8hpp.html#a024534399717753627909b438923214a":[7,0,3,4,0,17,5],
-"cuda_2sparse__matrix__operations_8hpp.html#a0c365dcc8bb5fcc34ff63d4d59b7a1fa":[7,0,3,4,0,17,31],
-"cuda_2sparse__matrix__operations_8hpp.html#a0d90ae5104947ac08924577953bef578":[7,0,3,4,0,17,36],
-"cuda_2sparse__matrix__operations_8hpp.html#a0ef28a94368c9b52dc01d02303c012c1":[7,0,3,4,0,17,12],
-"cuda_2sparse__matrix__operations_8hpp.html#a162b793a59cb8435e2c8021baba67063":[7,0,3,4,0,17,25],
-"cuda_2sparse__matrix__operations_8hpp.html#a2274b07759c6f58ef22fc899f2e71df0":[7,0,3,4,0,17,39],
-"cuda_2sparse__matrix__operations_8hpp.html#a24059796bd4e6fc06e81b0dcb3c2634a":[7,0,3,4,0,17,37],
-"cuda_2sparse__matrix__operations_8hpp.html#a304bf29f521944c0727c4ddccfe871a5":[7,0,3,4,0,17,7],
-"cuda_2sparse__matrix__operations_8hpp.html#a3a7b9b0998cc5a4c69049be2e0d70008":[7,0,3,4,0,17,23],
-"cuda_2sparse__matrix__operations_8hpp.html#a4138788ef0f9453e5cec339748b684f7":[7,0,3,4,0,17,24],
+"cuda_2sparse__matrix__operations_8hpp.html#a0c2c303c629870e3f32dc08c2cf22a64":[7,0,3,4,0,17,7],
+"cuda_2sparse__matrix__operations_8hpp.html#a0c365dcc8bb5fcc34ff63d4d59b7a1fa":[7,0,3,4,0,17,32],
+"cuda_2sparse__matrix__operations_8hpp.html#a0d90ae5104947ac08924577953bef578":[7,0,3,4,0,17,37],
+"cuda_2sparse__matrix__operations_8hpp.html#a0ef28a94368c9b52dc01d02303c012c1":[7,0,3,4,0,17,13],
+"cuda_2sparse__matrix__operations_8hpp.html#a162b793a59cb8435e2c8021baba67063":[7,0,3,4,0,17,26],
+"cuda_2sparse__matrix__operations_8hpp.html#a2274b07759c6f58ef22fc899f2e71df0":[7,0,3,4,0,17,40],
+"cuda_2sparse__matrix__operations_8hpp.html#a24059796bd4e6fc06e81b0dcb3c2634a":[7,0,3,4,0,17,38],
+"cuda_2sparse__matrix__operations_8hpp.html#a304bf29f521944c0727c4ddccfe871a5":[7,0,3,4,0,17,8],
+"cuda_2sparse__matrix__operations_8hpp.html#a3a7b9b0998cc5a4c69049be2e0d70008":[7,0,3,4,0,17,24],
+"cuda_2sparse__matrix__operations_8hpp.html#a4138788ef0f9453e5cec339748b684f7":[7,0,3,4,0,17,25],
 "cuda_2sparse__matrix__operations_8hpp.html#a43b31c772693ff5486a7d6b97984f11d":[7,0,3,4,0,17,6],
-"cuda_2sparse__matrix__operations_8hpp.html#a45615bf3f3314b66269070ae06bc3386":[7,0,3,4,0,17,41],
-"cuda_2sparse__matrix__operations_8hpp.html#a4a8d6aa23566b195f88cd484f5847ab2":[7,0,3,4,0,17,40],
-"cuda_2sparse__matrix__operations_8hpp.html#a5084d3e574223cc8c80d82a5c0df44f3":[7,0,3,4,0,17,18],
-"cuda_2sparse__matrix__operations_8hpp.html#a55ee720fa910a193f763e5e0339b1d8f":[7,0,3,4,0,17,15],
+"cuda_2sparse__matrix__operations_8hpp.html#a45615bf3f3314b66269070ae06bc3386":[7,0,3,4,0,17,42],
+"cuda_2sparse__matrix__operations_8hpp.html#a4a8d6aa23566b195f88cd484f5847ab2":[7,0,3,4,0,17,41],
+"cuda_2sparse__matrix__operations_8hpp.html#a5084d3e574223cc8c80d82a5c0df44f3":[7,0,3,4,0,17,19],
+"cuda_2sparse__matrix__operations_8hpp.html#a55ee720fa910a193f763e5e0339b1d8f":[7,0,3,4,0,17,16],
 "cuda_2sparse__matrix__operations_8hpp.html#a56b30f30bab469b7ee9efa74a0479b0a":[7,0,3,4,0,17,4],
-"cuda_2sparse__matrix__operations_8hpp.html#a58667ad168f3038faf582fd9b7bcfe63":[7,0,3,4,0,17,14],
-"cuda_2sparse__matrix__operations_8hpp.html#a58f92a1210124363530b848ddbb2608e":[7,0,3,4,0,17,29],
-"cuda_2sparse__matrix__operations_8hpp.html#a5df5057dcbcb5b9aaecdd1044fc91471":[7,0,3,4,0,17,42],
-"cuda_2sparse__matrix__operations_8hpp.html#a627be04a12785d50ede1becfea01a8e8":[7,0,3,4,0,17,34],
-"cuda_2sparse__matrix__operations_8hpp.html#a62fe3f2822e97ce4a612c08271bff4ab":[7,0,3,4,0,17,17],
-"cuda_2sparse__matrix__operations_8hpp.html#a7fc317edefd9bb239a9d1d591bc6aaac":[7,0,3,4,0,17,16],
-"cuda_2sparse__matrix__operations_8hpp.html#a886565441cda563116228f1a984a9077":[7,0,3,4,0,17,30],
-"cuda_2sparse__matrix__operations_8hpp.html#a8d72d223a94a2e7d72599b197495ce28":[7,0,3,4,0,17,38],
+"cuda_2sparse__matrix__operations_8hpp.html#a58667ad168f3038faf582fd9b7bcfe63":[7,0,3,4,0,17,15],
+"cuda_2sparse__matrix__operations_8hpp.html#a58f92a1210124363530b848ddbb2608e":[7,0,3,4,0,17,30],
+"cuda_2sparse__matrix__operations_8hpp.html#a5df5057dcbcb5b9aaecdd1044fc91471":[7,0,3,4,0,17,43],
+"cuda_2sparse__matrix__operations_8hpp.html#a627be04a12785d50ede1becfea01a8e8":[7,0,3,4,0,17,35],
+"cuda_2sparse__matrix__operations_8hpp.html#a62fe3f2822e97ce4a612c08271bff4ab":[7,0,3,4,0,17,18],
+"cuda_2sparse__matrix__operations_8hpp.html#a7fc317edefd9bb239a9d1d591bc6aaac":[7,0,3,4,0,17,17],
+"cuda_2sparse__matrix__operations_8hpp.html#a886565441cda563116228f1a984a9077":[7,0,3,4,0,17,31],
+"cuda_2sparse__matrix__operations_8hpp.html#a8d72d223a94a2e7d72599b197495ce28":[7,0,3,4,0,17,39],
 "cuda_2sparse__matrix__operations_8hpp.html#a8dc1bcfa3513087ec991e515d77cebeb":[7,0,3,4,0,17,3],
-"cuda_2sparse__matrix__operations_8hpp.html#a9b88a5d172082773693e6b71aae2c879":[7,0,3,4,0,17,28],
-"cuda_2sparse__matrix__operations_8hpp.html#aa81864a154a9aa526e297c37c9eee511":[7,0,3,4,0,17,9],
-"cuda_2sparse__matrix__operations_8hpp.html#aa8b34f9803d351cc9a89a603ed922fdd":[7,0,3,4,0,17,43],
-"cuda_2sparse__matrix__operations_8hpp.html#aabe94b15790c0d5ce1491105b4fa67a1":[7,0,3,4,0,17,32],
-"cuda_2sparse__matrix__operations_8hpp.html#ab3881905db81575de93b0fd9ae174b9b":[7,0,3,4,0,17,26],
-"cuda_2sparse__matrix__operations_8hpp.html#ab495253e3bb653e523c2e628efdd0d58":[7,0,3,4,0,17,20],
-"cuda_2sparse__matrix__operations_8hpp.html#ab6b75eafc5e309d770a760f3dad516f8":[7,0,3,4,0,17,8],
+"cuda_2sparse__matrix__operations_8hpp.html#a9b88a5d172082773693e6b71aae2c879":[7,0,3,4,0,17,29],
+"cuda_2sparse__matrix__operations_8hpp.html#aa81864a154a9aa526e297c37c9eee511":[7,0,3,4,0,17,10],
+"cuda_2sparse__matrix__operations_8hpp.html#aa8b34f9803d351cc9a89a603ed922fdd":[7,0,3,4,0,17,44],
+"cuda_2sparse__matrix__operations_8hpp.html#aabe94b15790c0d5ce1491105b4fa67a1":[7,0,3,4,0,17,33],
+"cuda_2sparse__matrix__operations_8hpp.html#ab3881905db81575de93b0fd9ae174b9b":[7,0,3,4,0,17,27],
+"cuda_2sparse__matrix__operations_8hpp.html#ab495253e3bb653e523c2e628efdd0d58":[7,0,3,4,0,17,21],
+"cuda_2sparse__matrix__operations_8hpp.html#ab6b75eafc5e309d770a760f3dad516f8":[7,0,3,4,0,17,9],
 "cuda_2sparse__matrix__operations_8hpp.html#ac588666828831dc470e4ed55da6d9a10":[7,0,3,4,0,17,1],
-"cuda_2sparse__matrix__operations_8hpp.html#ac9cc3af3ddf62ac5a8d17deb100cd829":[7,0,3,4,0,17,19],
-"cuda_2sparse__matrix__operations_8hpp.html#ad31cda4aebc7b1b2455cb64510355ac1":[7,0,3,4,0,17,22],
-"cuda_2sparse__matrix__operations_8hpp.html#ad40efac67a29cbc3482aa6da0a6a7a02":[7,0,3,4,0,17,27],
-"cuda_2sparse__matrix__operations_8hpp.html#adc106f90ea24d3bd6691f0db4fd56d9c":[7,0,3,4,0,17,35],
+"cuda_2sparse__matrix__operations_8hpp.html#ac9cc3af3ddf62ac5a8d17deb100cd829":[7,0,3,4,0,17,20],
+"cuda_2sparse__matrix__operations_8hpp.html#ad31cda4aebc7b1b2455cb64510355ac1":[7,0,3,4,0,17,23],
+"cuda_2sparse__matrix__operations_8hpp.html#ad40efac67a29cbc3482aa6da0a6a7a02":[7,0,3,4,0,17,28],
+"cuda_2sparse__matrix__operations_8hpp.html#adc106f90ea24d3bd6691f0db4fd56d9c":[7,0,3,4,0,17,36],
 "cuda_2sparse__matrix__operations_8hpp.html#adef638b203497a37625dc0f3ef8a81e2":[7,0,3,4,0,17,2],
-"cuda_2sparse__matrix__operations_8hpp.html#adf0603d39ba4e5c25a45348fddede2be":[7,0,3,4,0,17,10],
-"cuda_2sparse__matrix__operations_8hpp.html#aecebe8fe96a843f68fadeefa6aa6c900":[7,0,3,4,0,17,13],
-"cuda_2sparse__matrix__operations_8hpp.html#aed1f23243a32f7b4fe627ca7c42346e4":[7,0,3,4,0,17,21],
-"cuda_2sparse__matrix__operations_8hpp.html#af538b6efd58d3b9a72d19d8e60aeab08":[7,0,3,4,0,17,11],
-"cuda_2sparse__matrix__operations_8hpp.html#afedae669b4c5992f25d43e89f67729d6":[7,0,3,4,0,17,33],
+"cuda_2sparse__matrix__operations_8hpp.html#adf0603d39ba4e5c25a45348fddede2be":[7,0,3,4,0,17,11],
+"cuda_2sparse__matrix__operations_8hpp.html#aecebe8fe96a843f68fadeefa6aa6c900":[7,0,3,4,0,17,14],
+"cuda_2sparse__matrix__operations_8hpp.html#aed1f23243a32f7b4fe627ca7c42346e4":[7,0,3,4,0,17,22],
+"cuda_2sparse__matrix__operations_8hpp.html#af538b6efd58d3b9a72d19d8e60aeab08":[7,0,3,4,0,17,12],
+"cuda_2sparse__matrix__operations_8hpp.html#afedae669b4c5992f25d43e89f67729d6":[7,0,3,4,0,17,34],
 "cuda_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,0,17],
 "cuda_2vector__operations_8hpp.html":[7,0,3,4,0,19],
 "cuda_2vector__operations_8hpp.html#a0084570f864bca09fd50bf70bc7151ba":[7,0,3,4,0,19,2],
@@ -242,12 +249,5 @@ var NAVTREEINDEX9 =
 "dense__blas_8cpp_source.html":[7,0,0,0,1],
 "detail_2bisect_2bisect__kernel__calls_8hpp.html":[7,0,3,4,1,1,0],
 "detail_2bisect_2bisect__kernel__calls_8hpp.html#a049a115f9821da18cc960a5170bd2692":[7,0,3,4,1,1,0,3],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a4b0688e2a510e3fdc62fab34aedce77b":[7,0,3,4,1,1,0,1],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a82198b841ca247fd74b6a8b39242d708":[7,0,3,4,1,1,0,2],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#ada59d9072c648b1dde7f09c15d6b20de":[7,0,3,4,1,1,0,0],
-"detail_2bisect_2bisect__kernel__calls_8hpp_source.html":[7,0,3,4,1,1,0],
-"detail_2spai_2qr_8hpp.html":[7,0,3,4,1,3,3],
-"detail_2spai_2qr_8hpp.html#a08cfda20cf63c245a5c22034875743da":[7,0,3,4,1,3,3,0],
-"detail_2spai_2qr_8hpp.html#a0f734abea08b6732fb5a6d3d50f36319":[7,0,3,4,1,3,3,6],
-"detail_2spai_2qr_8hpp.html#a1bcb9bff13f114739f5f7d70d5b38223":[7,0,3,4,1,3,3,1]
+"detail_2bisect_2bisect__kernel__calls_8hpp.html#a4b0688e2a510e3fdc62fab34aedce77b":[7,0,3,4,1,1,0,1]
 };
