@@ -34,7 +34,7 @@
 template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, ScalarType const & s2)
 {
-   if (std::fabs(s1 - s2) > 0)
+   if (s1 > s2 || s1 < s2)
       return (s1 - s2) / std::max(static_cast<ScalarType>(std::fabs(static_cast<double>(s1))),
                                   static_cast<ScalarType>(std::fabs(static_cast<double>(s2))));
    return ScalarType(0);
@@ -65,7 +65,7 @@ ScalarType diff(std::vector<ScalarType> const & v1, ViennaCLVectorType const & v
 template<typename T, typename U, typename EpsilonT>
 void check(T const & t, U const & u, EpsilonT eps)
 {
-  EpsilonT rel_error = static_cast<EpsilonT>(diff(t,u));
+  EpsilonT rel_error = std::fabs(static_cast<EpsilonT>(diff(t,u)));
   if (rel_error > eps)
   {
     std::cerr << "Relative error: " << rel_error << std::endl;
@@ -323,8 +323,8 @@ int main()
   ref_double_alpha = 0;
   for (std::size_t i=0; i<size/2; ++i)
   {
-    ref_float_alpha  += ref_float_y[3 + 2*i]  * ref_float_x[2 + 2*i];
-    ref_double_alpha += ref_double_y[3 + 2*i] * ref_double_x[2 + 2*i];
+    ref_float_alpha  += ref_float_y[3 + i]  * ref_float_x[2 + i];
+    ref_double_alpha += ref_double_y[3 + i] * ref_double_x[2 + i];
   }
 
   std::cout << std::endl << "Host: ";
