@@ -50,9 +50,7 @@
 #include "boost/numeric/ublas/vector_proxy.hpp"
 #include "boost/numeric/ublas/io.hpp"
 
-using namespace boost::numeric;
-
-template <typename MatrixType, typename VCLMatrixType>
+template<typename MatrixType, typename VCLMatrixType>
 bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A, double epsilon)
 {
   typedef typename MatrixType::value_type   value_type;
@@ -65,9 +63,9 @@ bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A,
   {
     for (std::size_t j=0; j<ublas_A.size2(); ++j)
     {
-      if (ublas_A(i,j) != vcl_A_cpu(i,j))
+      if (std::fabs(ublas_A(i,j) - vcl_A_cpu(i,j)) > 0)
       {
-        if ( (std::abs(ublas_A(i,j) - vcl_A_cpu(i,j)) / std::max(std::fabs(ublas_A(i,j)), std::fabs(vcl_A_cpu(i,j))) > epsilon) || (vcl_A_cpu(i,j) != vcl_A_cpu(i,j)) )
+        if ( (std::abs(ublas_A(i,j) - vcl_A_cpu(i,j)) / std::max(std::fabs(ublas_A(i,j)), std::fabs(vcl_A_cpu(i,j))) > epsilon) || std::fabs(vcl_A_cpu(i,j) - vcl_A_cpu(i,j)) > 0 )
         {
           std::cout << "Error at index (" << i << ", " << j << "): " << ublas_A(i,j) << " vs " << vcl_A_cpu(i,j) << std::endl;
           std::cout << std::endl << "TEST failed!" << std::endl;
@@ -84,7 +82,7 @@ bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A,
 
 
 
-template <typename UBLASMatrixType,
+template<typename UBLASMatrixType,
           typename ViennaCLMatrixType1, typename ViennaCLMatrixType2, typename ViennaCLMatrixType3>
 int run_test(double epsilon,
              UBLASMatrixType & ublas_A, UBLASMatrixType & ublas_B, UBLASMatrixType & ublas_C,
@@ -104,24 +102,24 @@ int run_test(double epsilon,
   // Initializer:
   //
   std::cout << "Checking for zero_matrix initializer..." << std::endl;
-  ublas_A = ublas::zero_matrix<cpu_value_type>(ublas_A.size1(), ublas_A.size2());
+  ublas_A = boost::numeric::ublas::zero_matrix<cpu_value_type>(ublas_A.size1(), ublas_A.size2());
   vcl_A = viennacl::zero_matrix<cpu_value_type>(vcl_A.size1(), vcl_A.size2());
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   std::cout << "Checking for scalar_matrix initializer..." << std::endl;
-  ublas_A = ublas::scalar_matrix<cpu_value_type>(ublas_A.size1(), ublas_A.size2(), alpha);
+  ublas_A = boost::numeric::ublas::scalar_matrix<cpu_value_type>(ublas_A.size1(), ublas_A.size2(), alpha);
   vcl_A = viennacl::scalar_matrix<cpu_value_type>(vcl_A.size1(), vcl_A.size2(), alpha);
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A =    ublas::scalar_matrix<cpu_value_type>(ublas_A.size1(), ublas_A.size2(), gpu_beta);
+  ublas_A =    boost::numeric::ublas::scalar_matrix<cpu_value_type>(ublas_A.size1(), ublas_A.size2(), gpu_beta);
   vcl_A   = viennacl::scalar_matrix<cpu_value_type>(  vcl_A.size1(),   vcl_A.size2(), gpu_beta);
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   /*std::cout << "Checking for identity initializer..." << std::endl;
-  ublas_A = ublas::identity_matrix<cpu_value_type>(ublas_A.size1());
+  ublas_A = boost::numeric::ublas::identity_matrix<cpu_value_type>(ublas_A.size1());
   vcl_A = viennacl::identity_matrix<cpu_value_type>(vcl_A.size1());
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;*/
@@ -142,6 +140,16 @@ int run_test(double epsilon,
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
+  if (ublas_A.size1() == ublas_A.size2())
+  {
+    std::cout << "Testing matrix assignment (transposed)... ";
+    ublas_A = trans(ublas_B);
+    vcl_A   = viennacl::trans(vcl_B);
+
+    if (!check_for_equality(ublas_A, vcl_A, epsilon))
+      return EXIT_FAILURE;
+  }
+
 
 
   //std::cout << std::endl;
@@ -190,6 +198,16 @@ int run_test(double epsilon,
   if (!check_for_equality(ublas_C, vcl_C, epsilon))
     return EXIT_FAILURE;
 
+  if (ublas_C.size1() == ublas_C.size2())
+  {
+    std::cout << "Inplace add (transposed): ";
+    ublas_C += trans(ublas_C);
+    vcl_C   += viennacl::trans(vcl_C);
+
+    if (!check_for_equality(ublas_C, vcl_C, epsilon))
+      return EXIT_FAILURE;
+  }
+
   std::cout << "Scaled inplace add: ";
   ublas_C += beta * ublas_A;
   vcl_C   += gpu_beta * vcl_A;
@@ -213,8 +231,20 @@ int run_test(double epsilon,
 
 
   std::cout << "Scaled add (left): ";
-  ublas_C = alpha * ublas_A + ublas_B;
-  vcl_C   = alpha *   vcl_A +   vcl_B;
+  ublas_C = long(alpha) * ublas_A + ublas_B;
+  vcl_C   = long(alpha) *   vcl_A +   vcl_B;
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_C = float(alpha) * ublas_A + ublas_B;
+  vcl_C   = float(alpha) *   vcl_A +   vcl_B;
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_C = double(alpha) * ublas_A + ublas_B;
+  vcl_C   = double(alpha) *   vcl_A +   vcl_B;
 
   if (!check_for_equality(ublas_C, vcl_C, epsilon))
     return EXIT_FAILURE;
@@ -226,8 +256,20 @@ int run_test(double epsilon,
 
 
   std::cout << "Scaled add (right): ";
-  ublas_C = ublas_A + beta * ublas_B;
-  vcl_C   =   vcl_A + beta *   vcl_B;
+  ublas_C = ublas_A + ublas_B * long(beta);
+  vcl_C   =   vcl_A + vcl_B   * long(beta);
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_C = ublas_A + ublas_B * float(beta);
+  vcl_C   =   vcl_A + vcl_B   * float(beta);
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_C = ublas_A + ublas_B * double(beta);
+  vcl_C   =   vcl_A + vcl_B   * double(beta);
 
   if (!check_for_equality(ublas_C, vcl_C, epsilon))
     return EXIT_FAILURE;
@@ -237,6 +279,24 @@ int run_test(double epsilon,
   if (!check_for_equality(ublas_C, vcl_C, epsilon))
     return EXIT_FAILURE;
 
+  std::cout << "Scaled add (right, with division): ";
+  ublas_C = ublas_A + ublas_B / long(beta);
+  vcl_C   =   vcl_A + vcl_B   / long(beta);
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_C = ublas_A + ublas_B / float(beta);
+  vcl_C   =   vcl_A + vcl_B   / float(beta);
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_C = ublas_A + ublas_B / double(beta);
+  vcl_C   =   vcl_A + vcl_B   / double(beta);
+
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
 
 
   std::cout << "Scaled add (both): ";
@@ -260,6 +320,16 @@ int run_test(double epsilon,
   ublas_C -= ublas_B;
   vcl_C -= vcl_B;
 
+  if (!check_for_equality(ublas_C, vcl_C, epsilon))
+    return EXIT_FAILURE;
+
+  if (ublas_C.size1() == ublas_C.size2())
+  {
+    std::cout << "Inplace add (transposed): ";
+    ublas_C -= trans(ublas_C);
+    vcl_C   -= viennacl::trans(vcl_C);
+  }
+
   if (!check_for_equality(ublas_C, vcl_C, epsilon))
     return EXIT_FAILURE;
 
@@ -334,8 +404,20 @@ int run_test(double epsilon,
   viennacl::copy(ublas_A, vcl_A);
 
   std::cout << "Multiplication with CPU scalar: ";
-  ublas_A *= alpha;
-  vcl_A   *= alpha;
+  ublas_A *= long(alpha);
+  vcl_A   *= long(alpha);
+
+  if (!check_for_equality(ublas_A, vcl_A, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_A *= float(alpha);
+  vcl_A   *= float(alpha);
+
+  if (!check_for_equality(ublas_A, vcl_A, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_A *= double(alpha);
+  vcl_A   *= double(alpha);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
@@ -349,8 +431,20 @@ int run_test(double epsilon,
 
 
   std::cout << "Division with CPU scalar: ";
-  ublas_A /= alpha;
-  vcl_A /= alpha;
+  ublas_A /= long(alpha);
+  vcl_A   /= long(alpha);
+
+  if (!check_for_equality(ublas_A, vcl_A, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_A /= float(alpha);
+  vcl_A   /= float(alpha);
+
+  if (!check_for_equality(ublas_A, vcl_A, epsilon))
+    return EXIT_FAILURE;
+
+  ublas_A /= double(alpha);
+  vcl_A   /= double(alpha);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
@@ -365,162 +459,162 @@ int run_test(double epsilon,
 
 
   std::cout << "Testing elementwise multiplication..." << std::endl;
-  ublas_B = ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142));
+  ublas_B = boost::numeric::ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142));
   ublas_A = cpu_value_type(3.1415) * ublas_B;
   viennacl::copy(ublas_A, vcl_A);
   viennacl::copy(ublas_B, vcl_B);
   viennacl::copy(ublas_B, vcl_B);
-  ublas_A = ublas::element_prod(ublas_A, ublas_B);
+  ublas_A = boost::numeric::ublas::element_prod(ublas_A, ublas_B);
   vcl_A = viennacl::linalg::element_prod(vcl_A, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_prod(ublas_A, ublas_B);
+  ublas_A += boost::numeric::ublas::element_prod(ublas_A, ublas_B);
   vcl_A += viennacl::linalg::element_prod(vcl_A, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_prod(ublas_A, ublas_B);
+  ublas_A -= boost::numeric::ublas::element_prod(ublas_A, ublas_B);
   vcl_A -= viennacl::linalg::element_prod(vcl_A, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   ///////
-  ublas_A = ublas::element_prod(ublas_A + ublas_B, ublas_B);
+  ublas_A = boost::numeric::ublas::element_prod(ublas_A + ublas_B, ublas_B);
   vcl_A = viennacl::linalg::element_prod(vcl_A + vcl_B, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_prod(ublas_A + ublas_B, ublas_B);
+  ublas_A += boost::numeric::ublas::element_prod(ublas_A + ublas_B, ublas_B);
   vcl_A += viennacl::linalg::element_prod(vcl_A + vcl_B, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_prod(ublas_A + ublas_B, ublas_B);
+  ublas_A -= boost::numeric::ublas::element_prod(ublas_A + ublas_B, ublas_B);
   vcl_A -= viennacl::linalg::element_prod(vcl_A + vcl_B, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   ///////
-  ublas_A = ublas::element_prod(ublas_A, ublas_B + ublas_A);
+  ublas_A = boost::numeric::ublas::element_prod(ublas_A, ublas_B + ublas_A);
   vcl_A = viennacl::linalg::element_prod(vcl_A, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_prod(ublas_A, ublas_B + ublas_A);
+  ublas_A += boost::numeric::ublas::element_prod(ublas_A, ublas_B + ublas_A);
   vcl_A += viennacl::linalg::element_prod(vcl_A, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_prod(ublas_A, ublas_B + ublas_A);
+  ublas_A -= boost::numeric::ublas::element_prod(ublas_A, ublas_B + ublas_A);
   vcl_A -= viennacl::linalg::element_prod(vcl_A, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   ///////
-  ublas_A = ublas::element_prod(ublas_A + ublas_B, ublas_B + ublas_A);
+  ublas_A = boost::numeric::ublas::element_prod(ublas_A + ublas_B, ublas_B + ublas_A);
   vcl_A = viennacl::linalg::element_prod(vcl_A + vcl_B, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_prod(ublas_A + ublas_B, ublas_B + ublas_A);
+  ublas_A += boost::numeric::ublas::element_prod(ublas_A + ublas_B, ublas_B + ublas_A);
   vcl_A += viennacl::linalg::element_prod(vcl_A + vcl_B, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_prod(ublas_A + ublas_B, ublas_B + ublas_A);
+  ublas_A -= boost::numeric::ublas::element_prod(ublas_A + ublas_B, ublas_B + ublas_A);
   vcl_A -= viennacl::linalg::element_prod(vcl_A + vcl_B, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
 
-  ublas_B = ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142));
+  ublas_B = boost::numeric::ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142));
   ublas_A = cpu_value_type(3.1415) * ublas_B;
   viennacl::copy(ublas_A, vcl_A);
   viennacl::copy(ublas_B, vcl_B);
 
-  ublas_A = ublas::element_div(ublas_A, ublas_B);
+  ublas_A = boost::numeric::ublas::element_div(ublas_A, ublas_B);
   vcl_A = viennacl::linalg::element_div(vcl_A, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_div(ublas_A, ublas_B);
+  ublas_A += boost::numeric::ublas::element_div(ublas_A, ublas_B);
   vcl_A += viennacl::linalg::element_div(vcl_A, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_div(ublas_A, ublas_B);
+  ublas_A -= boost::numeric::ublas::element_div(ublas_A, ublas_B);
   vcl_A -= viennacl::linalg::element_div(vcl_A, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   ///////
-  ublas_A = ublas::element_div(ublas_A + ublas_B, ublas_B);
+  ublas_A = boost::numeric::ublas::element_div(ublas_A + ublas_B, ublas_B);
   vcl_A = viennacl::linalg::element_div(vcl_A + vcl_B, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_div(ublas_A + ublas_B, ublas_B);
+  ublas_A += boost::numeric::ublas::element_div(ublas_A + ublas_B, ublas_B);
   vcl_A += viennacl::linalg::element_div(vcl_A + vcl_B, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_div(ublas_A + ublas_B, ublas_B);
+  ublas_A -= boost::numeric::ublas::element_div(ublas_A + ublas_B, ublas_B);
   vcl_A -= viennacl::linalg::element_div(vcl_A + vcl_B, vcl_B);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   ///////
-  ublas_A = ublas::element_div(ublas_A, ublas_B + ublas_A);
+  ublas_A = boost::numeric::ublas::element_div(ublas_A, ublas_B + ublas_A);
   vcl_A = viennacl::linalg::element_div(vcl_A, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_div(ublas_A, ublas_B + ublas_A);
+  ublas_A += boost::numeric::ublas::element_div(ublas_A, ublas_B + ublas_A);
   vcl_A += viennacl::linalg::element_div(vcl_A, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_div(ublas_A, ublas_B + ublas_A);
+  ublas_A -= boost::numeric::ublas::element_div(ublas_A, ublas_B + ublas_A);
   vcl_A -= viennacl::linalg::element_div(vcl_A, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
   ///////
-  ublas_A = ublas::element_div(ublas_A + ublas_B, ublas_B + ublas_A);
+  ublas_A = boost::numeric::ublas::element_div(ublas_A + ublas_B, ublas_B + ublas_A);
   vcl_A = viennacl::linalg::element_div(vcl_A + vcl_B, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A += ublas::element_div(ublas_A + ublas_B, ublas_B + ublas_A);
+  ublas_A += boost::numeric::ublas::element_div(ublas_A + ublas_B, ublas_B + ublas_A);
   vcl_A += viennacl::linalg::element_div(vcl_A + vcl_B, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
     return EXIT_FAILURE;
 
-  ublas_A -= ublas::element_div(ublas_A + ublas_B, ublas_B + ublas_A);
+  ublas_A -= boost::numeric::ublas::element_div(ublas_A + ublas_B, ublas_B + ublas_A);
   vcl_A -= viennacl::linalg::element_div(vcl_A + vcl_B, vcl_B + vcl_A);
 
   if (!check_for_equality(ublas_A, vcl_A, epsilon))
@@ -529,7 +623,7 @@ int run_test(double epsilon,
   // element_pow
   std::cout << "Testing unary element_pow()..." << std::endl;
 
-  ublas_B = ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142));
+  ublas_B = boost::numeric::ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142));
   ublas_A = cpu_value_type(3.1415) * ublas_B;
   viennacl::copy(ublas_A, vcl_A);
   viennacl::copy(ublas_B, vcl_B);
@@ -637,7 +731,7 @@ int run_test(double epsilon,
   std::cout << "Testing unary elementwise operations..." << std::endl;
 
 #define GENERATE_UNARY_OP_TEST(FUNCNAME) \
-  ublas_B = ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142)); \
+  ublas_B = boost::numeric::ublas::scalar_matrix<cpu_value_type>(ublas_B.size1(), ublas_B.size2(), cpu_value_type(1.4142)); \
   ublas_A = cpu_value_type(3.1415) * ublas_B; \
   ublas_C = cpu_value_type(2.7172) * ublas_A; \
   viennacl::copy(ublas_A, vcl_A); \
@@ -766,7 +860,7 @@ int run_test(double epsilon,
 
 
 
-template <typename T, typename ScalarType>
+template<typename T, typename ScalarType>
 int run_test(double epsilon)
 {
     //typedef float               ScalarType;
@@ -896,9 +990,9 @@ int run_test(double epsilon)
     std::cout << "//" << std::endl;
 
     {
-      ublas::matrix<ScalarType> ublas_dummy1 = ublas::identity_matrix<ScalarType>(ublas_A.size1());
-      ublas::matrix<ScalarType> ublas_dummy2 = ublas::scalar_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1(), 3.0);
-      ublas::matrix<ScalarType> ublas_dummy3 = ublas::zero_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1());
+      boost::numeric::ublas::matrix<ScalarType> ublas_dummy1 = boost::numeric::ublas::identity_matrix<ScalarType>(ublas_A.size1());
+      boost::numeric::ublas::matrix<ScalarType> ublas_dummy2 = boost::numeric::ublas::scalar_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1(), 3.0);
+      boost::numeric::ublas::matrix<ScalarType> ublas_dummy3 = boost::numeric::ublas::zero_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1());
 
       viennacl::matrix<ScalarType> vcl_dummy1 = viennacl::identity_matrix<ScalarType>(ublas_A.size1());
       viennacl::matrix<ScalarType> vcl_dummy2 = viennacl::scalar_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1(), 3.0);
@@ -916,9 +1010,9 @@ int run_test(double epsilon)
         return EXIT_FAILURE;
       }
 
-      ublas_dummy1 = ublas::zero_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1());
-      ublas_dummy2 = ublas::identity_matrix<ScalarType>(ublas_A.size1());
-      ublas_dummy3 = ublas::scalar_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1(), 3.0);
+      ublas_dummy1 = boost::numeric::ublas::zero_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1());
+      ublas_dummy2 = boost::numeric::ublas::identity_matrix<ScalarType>(ublas_A.size1());
+      ublas_dummy3 = boost::numeric::ublas::scalar_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1(), 3.0);
 
       vcl_dummy1 = viennacl::zero_matrix<ScalarType>(ublas_A.size1(), ublas_A.size1());
       vcl_dummy2 = viennacl::identity_matrix<ScalarType>(ublas_A.size1());
@@ -949,7 +1043,7 @@ int run_test(double epsilon)
       return EXIT_FAILURE;
     }
 
-    ScalarType ublas_norm_inf = ublas::norm_inf(ublas_C);
+    ScalarType ublas_norm_inf = boost::numeric::ublas::norm_inf(ublas_C);
     ScalarType   vcl_norm_inf = viennacl::linalg::norm_inf(vcl_C);
     if ( std::fabs(ublas_norm_inf - vcl_norm_inf) / ublas_norm_inf > epsilon)
     {
@@ -973,6 +1067,34 @@ int run_test(double epsilon)
       return EXIT_FAILURE;
     }
 
+    vcl_norm_frobenius = viennacl::linalg::norm_frobenius(vcl_range_C);
+    if ( std::fabs(ublas_norm_frobenius - vcl_norm_frobenius) / ublas_norm_frobenius > epsilon)
+    {
+      std::cerr << "Failure at norm_frobenius() with range" << std::endl;
+      return EXIT_FAILURE;
+    }
+
+    device_vcl_norm_frobenius = viennacl::linalg::norm_frobenius(vcl_range_C);
+    if ( std::fabs(device_ublas_norm_frobenius - device_vcl_norm_frobenius) / device_ublas_norm_frobenius > epsilon)
+    {
+      std::cerr << "Failure at norm_frobenius() with range" << std::endl;
+      return EXIT_FAILURE;
+    }
+
+    vcl_norm_frobenius = viennacl::linalg::norm_frobenius(vcl_slice_C);
+    if ( std::fabs(ublas_norm_frobenius - vcl_norm_frobenius) / ublas_norm_frobenius > epsilon)
+    {
+      std::cerr << "Failure at norm_frobenius() with slice" << std::endl;
+      return EXIT_FAILURE;
+    }
+
+    device_vcl_norm_frobenius = viennacl::linalg::norm_frobenius(vcl_slice_C);
+    if ( std::fabs(device_ublas_norm_frobenius - device_vcl_norm_frobenius) / device_ublas_norm_frobenius > epsilon)
+    {
+      std::cerr << "Failure at norm_frobenius() with slice" << std::endl;
+      return EXIT_FAILURE;
+    }
+
     std::cout << "PASSED!" << std::endl;
 
 
