@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2014, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -15,6 +15,11 @@
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
 
+
+/** \file tests/src/vector_int.cpp  Tests vector operations (BLAS level 1) for signed integer arithmetic.
+*   \test  Tests vector operations (BLAS level 1) for signed integer arithmetic.
+**/
+
 //
 // *** System
 //
@@ -39,6 +44,7 @@
 #include "viennacl/linalg/norm_1.hpp"
 #include "viennacl/linalg/norm_2.hpp"
 #include "viennacl/linalg/norm_inf.hpp"
+#include "viennacl/linalg/maxmin.hpp"
 
 #include "Random.hpp"
 
@@ -48,7 +54,7 @@ using namespace boost::numeric;
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, ScalarType const & s2)
 {
   viennacl::backend::finish();
@@ -57,7 +63,7 @@ ScalarType diff(ScalarType const & s1, ScalarType const & s2)
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, viennacl::scalar<ScalarType> const & s2)
 {
   viennacl::backend::finish();
@@ -66,7 +72,7 @@ ScalarType diff(ScalarType const & s1, viennacl::scalar<ScalarType> const & s2)
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, viennacl::entry_proxy<ScalarType> const & s2)
 {
   viennacl::backend::finish();
@@ -75,7 +81,7 @@ ScalarType diff(ScalarType const & s1, viennacl::entry_proxy<ScalarType> const &
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType, typename VCLVectorType>
+template<typename ScalarType, typename VCLVectorType>
 ScalarType diff(ublas::vector<ScalarType> const & v1, VCLVectorType const & v2)
 {
    ublas::vector<ScalarType> v2_cpu(v2.size());
@@ -91,7 +97,7 @@ ScalarType diff(ublas::vector<ScalarType> const & v1, VCLVectorType const & v2)
    return 0;
 }
 
-template <typename T1, typename T2>
+template<typename T1, typename T2>
 int check(T1 const & t1, T2 const & t2)
 {
   int retval = EXIT_SUCCESS;
@@ -252,6 +258,68 @@ int test(UblasVectorType     & ublas_v1, UblasVectorType     & ublas_v2,
   if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
+  // --------------------------------------------------------------------------
+  std::cout << "Testing max..." << std::endl;
+  cpu_result = ublas_v1[0];
+  for (std::size_t i=0; i<ublas_v1.size(); ++i)
+    cpu_result = std::max<NumericT>(cpu_result, ublas_v1[i]);
+  gpu_result = viennacl::linalg::max(vcl_v1);
+
+  if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+  cpu_result = ublas_v1[0];
+  for (std::size_t i=0; i<ublas_v1.size(); ++i)
+    cpu_result = std::max<NumericT>(cpu_result, ublas_v1[i]);
+  gpu_result = cpu_result;
+  cpu_result *= 2; //reset
+  cpu_result = viennacl::linalg::max(vcl_v1);
+
+  if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+  cpu_result = ublas_v1[0] + ublas_v2[0];
+  for (std::size_t i=0; i<ublas_v1.size(); ++i)
+    cpu_result = std::max<NumericT>(cpu_result, ublas_v1[i] + ublas_v2[i]);
+  gpu_result = cpu_result;
+  cpu_result *= 2; //reset
+  cpu_result = viennacl::linalg::max(vcl_v1 + vcl_v2);
+
+  if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+
+  // --------------------------------------------------------------------------
+  std::cout << "Testing min..." << std::endl;
+  cpu_result = ublas_v1[0];
+  for (std::size_t i=0; i<ublas_v1.size(); ++i)
+    cpu_result = std::min<NumericT>(cpu_result, ublas_v1[i]);
+  gpu_result = viennacl::linalg::min(vcl_v1);
+
+  if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+  cpu_result = ublas_v1[0];
+  for (std::size_t i=0; i<ublas_v1.size(); ++i)
+    cpu_result = std::min<NumericT>(cpu_result, ublas_v1[i]);
+  gpu_result = cpu_result;
+  cpu_result *= 2; //reset
+  cpu_result = viennacl::linalg::min(vcl_v1);
+
+  if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+  cpu_result = ublas_v1[0] + ublas_v2[0];
+  for (std::size_t i=0; i<ublas_v1.size(); ++i)
+    cpu_result = std::min<NumericT>(cpu_result, ublas_v1[i] + ublas_v2[i]);
+  gpu_result = cpu_result;
+  cpu_result *= 2; //reset
+  cpu_result = viennacl::linalg::min(vcl_v1 + vcl_v2);
+
+  if (check(cpu_result, gpu_result) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+
 
   //
   // Plane rotation and assignments
@@ -1345,8 +1413,8 @@ int test()
 
   for (std::size_t i=0; i<ublas_full_vec.size(); ++i)
   {
-    ublas_full_vec[i]  = NumericT(1.0 + i);
-    ublas_full_vec2[i] = NumericT(2.0 + i / 2);
+    ublas_full_vec[i]  = NumericT(1.0) + NumericT(i);
+    ublas_full_vec2[i] = NumericT(2.0) + NumericT(i) / NumericT(2);
   }
 
   ublas::range r1(    ublas_full_vec.size() / 4, 2 * ublas_full_vec.size() / 4);
@@ -1494,7 +1562,7 @@ int main()
     std::cout << "# Testing setup:" << std::endl;
     std::cout << "  numeric: int" << std::endl;
     retval = test<int>();
-    if( retval == EXIT_SUCCESS )
+    if ( retval == EXIT_SUCCESS )
       std::cout << "# Test passed" << std::endl;
     else
       return retval;
@@ -1506,7 +1574,7 @@ int main()
     std::cout << "# Testing setup:" << std::endl;
     std::cout << "  numeric: long" << std::endl;
     retval = test<long>();
-    if( retval == EXIT_SUCCESS )
+    if ( retval == EXIT_SUCCESS )
       std::cout << "# Test passed" << std::endl;
     else
       return retval;
