@@ -42,6 +42,10 @@ namespace viennacl
 namespace detail
 {
 
+  /** @brief Implementation of the copy of a host-based sparse matrix to the device.
+    *
+    * See convenience copy() routines for type requirements of CPUMatrixT
+    */
   template<typename CPUMatrixT, typename NumericT, unsigned int AlignmentV>
   void copy_impl(const CPUMatrixT & cpu_matrix,
                  compressed_matrix<NumericT, AlignmentV> & gpu_matrix,
@@ -85,6 +89,10 @@ namespace detail
   }
 }
 
+//
+// host to device:
+//
+
 //provide copy-operation:
 /** @brief Copies a sparse matrix from the host to the OpenCL device (either GPU or multi-core CPU)
   *
@@ -157,6 +165,10 @@ void copy(const std::vector< std::map<SizeT, NumericT> > & cpu_matrix,
 }
 
 #ifdef VIENNACL_WITH_UBLAS
+/** @brief Convenience routine for copying a sparse uBLAS matrix to a ViennaCL matrix.
+  *
+  * Optimization which copies the data directly from the internal uBLAS buffers.
+  */
 template<typename ScalarType, typename F, vcl_size_t IB, typename IA, typename TA>
 void copy(const boost::numeric::ublas::compressed_matrix<ScalarType, F, IB, IA, TA> & ublas_matrix,
           viennacl::compressed_matrix<ScalarType, 1> & gpu_matrix)
@@ -184,6 +196,10 @@ void copy(const boost::numeric::ublas::compressed_matrix<ScalarType, F, IB, IA,
 #endif
 
 #ifdef VIENNACL_WITH_EIGEN
+/** @brief Convenience routine for copying a sparse Eigen matrix to a ViennaCL matrix.
+  *
+  * Builds a temporary STL matrix. Patches for avoiding the temporary matrix welcome.
+  */
 template<typename NumericT, int flags, unsigned int AlignmentV>
 void copy(const Eigen::SparseMatrix<NumericT, flags> & eigen_matrix,
           compressed_matrix<NumericT, AlignmentV> & gpu_matrix)
@@ -203,6 +219,10 @@ void copy(const Eigen::SparseMatrix<NumericT, flags> & eigen_matrix,
 
 
 #ifdef VIENNACL_WITH_MTL4
+/** @brief Convenience routine for copying a sparse MTL4 matrix to a ViennaCL matrix.
+  *
+  * Builds a temporary STL matrix for the copy. Patches for avoiding the temporary matrix welcome.
+  */
 template<typename NumericT, unsigned int AlignmentV>
 void copy(const mtl::compressed2D<NumericT> & cpu_matrix,
           compressed_matrix<NumericT, AlignmentV> & gpu_matrix)
@@ -248,7 +268,7 @@ void copy(const mtl::compressed2D<NumericT> & cpu_matrix,
 
 
 //
-// gpu to cpu:
+// device to host:
 //
 /** @brief Copies a sparse matrix from the OpenCL device (either GPU or multi-core CPU) to the host.
   *
@@ -314,6 +334,10 @@ void copy(const compressed_matrix<NumericT, AlignmentV> & gpu_matrix,
 }
 
 #ifdef VIENNACL_WITH_UBLAS
+/** @brief Convenience routine for copying a ViennaCL sparse matrix back to a sparse uBLAS matrix
+  *
+  * Directly populates the internal buffer of the uBLAS matrix, thus avoiding a temporary STL matrix.
+  */
 template<typename ScalarType, unsigned int AlignmentV, typename F, vcl_size_t IB, typename IA, typename TA>
 void copy(viennacl::compressed_matrix<ScalarType, AlignmentV> const & gpu_matrix,
           boost::numeric::ublas::compressed_matrix<ScalarType> & ublas_matrix)
@@ -344,6 +368,7 @@ void copy(viennacl::compressed_matrix<ScalarType, AlignmentV> const & gpu_matrix
 #endif
 
 #ifdef VIENNACL_WITH_EIGEN
+/** @brief Convenience routine for copying a ViennaCL sparse matrix back to a sparse Eigen matrix */
 template<typename NumericT, int flags, unsigned int AlignmentV>
 void copy(compressed_matrix<NumericT, AlignmentV> & gpu_matrix,
           Eigen::SparseMatrix<NumericT, flags> & eigen_matrix)
@@ -381,6 +406,7 @@ void copy(compressed_matrix<NumericT, AlignmentV> & gpu_matrix,
 
 
 #ifdef VIENNACL_WITH_MTL4
+/** @brief Convenience routine for copying a ViennaCL sparse matrix back to a sparse MTL4 matrix */
 template<typename NumericT, unsigned int AlignmentV>
 void copy(compressed_matrix<NumericT, AlignmentV> & gpu_matrix,
           mtl::compressed2D<NumericT> & mtl4_matrix)
@@ -438,7 +464,7 @@ public:
   typedef vcl_size_t                                                                                 size_type;
 
   /** @brief Default construction of a compressed matrix. No memory is allocated */
-  compressed_matrix() : rows_(0), cols_(0), nonzeros_(0) {}
+  compressed_matrix() : rows_(0), cols_(0), nonzeros_(0), row_block_num_(0) {}
 
   /** @brief Construction of a compressed matrix with the supplied number of rows and columns. If the number of nonzeros is positive, memory is allocated
       *
@@ -448,11 +474,12 @@ public:
       * @param ctx      Optional context in which the matrix is created (one out of multiple OpenCL contexts, CUDA, host)
       */
   explicit compressed_matrix(vcl_size_t rows, vcl_size_t cols, vcl_size_t nonzeros = 0, viennacl::context ctx = viennacl::context())
-    : rows_(rows), cols_(cols), nonzeros_(nonzeros)
+    : rows_(rows), cols_(cols), nonzeros_(nonzeros), row_block_num_(0)
   {
     row_buffer_.switch_active_handle_id(ctx.memory_type());
     col_buffer_.switch_active_handle_id(ctx.memory_type());
     elements_.switch_active_handle_id(ctx.memory_type());
+    row_blocks_.switch_active_handle_id(ctx.memory_type());
 
 #ifdef VIENNACL_WITH_OPENCL
     if (ctx.memory_type() == OPENCL_MEMORY)
@@ -460,6 +487,7 @@ public:
       row_buffer_.opencl_handle().context(ctx.opencl_context());
       col_buffer_.opencl_handle().context(ctx.opencl_context());
       elements_.opencl_handle().context(ctx.opencl_context());
+      row_blocks_.opencl_handle().context(ctx.opencl_context());
     }
 #endif
     if (rows > 0)
@@ -480,11 +508,12 @@ public:
       * @param ctx      Context in which to create the matrix
       */
   explicit compressed_matrix(vcl_size_t rows, vcl_size_t cols, viennacl::context ctx)
-    : rows_(rows), cols_(cols), nonzeros_(0)
+    : rows_(rows), cols_(cols), nonzeros_(0), row_block_num_(0)
   {
     row_buffer_.switch_active_handle_id(ctx.memory_type());
     col_buffer_.switch_active_handle_id(ctx.memory_type());
     elements_.switch_active_handle_id(ctx.memory_type());
+    row_blocks_.switch_active_handle_id(ctx.memory_type());
 
 #ifdef VIENNACL_WITH_OPENCL
     if (ctx.memory_type() == OPENCL_MEMORY)
@@ -492,6 +521,7 @@ public:
       row_buffer_.opencl_handle().context(ctx.opencl_context());
       col_buffer_.opencl_handle().context(ctx.opencl_context());
       elements_.opencl_handle().context(ctx.opencl_context());
+      row_blocks_.opencl_handle().context(ctx.opencl_context());
     }
 #endif
     if (rows > 0)
@@ -500,11 +530,16 @@ public:
     }
   }
 
-  explicit compressed_matrix(viennacl::context ctx) : rows_(0), cols_(0), nonzeros_(0)
+  /** @brief Creates an empty compressed_matrix, but sets the respective context information.
+    *
+    * This is useful if you want to want to populate e.g. a viennacl::compressed_matrix<> on the host with copy(), but the default backend is OpenCL.
+    */
+  explicit compressed_matrix(viennacl::context ctx) : rows_(0), cols_(0), nonzeros_(0), row_block_num_(0)
   {
     row_buffer_.switch_active_handle_id(ctx.memory_type());
     col_buffer_.switch_active_handle_id(ctx.memory_type());
     elements_.switch_active_handle_id(ctx.memory_type());
+    row_blocks_.switch_active_handle_id(ctx.memory_type());
 
 #ifdef VIENNACL_WITH_OPENCL
     if (ctx.memory_type() == OPENCL_MEMORY)
@@ -512,15 +547,25 @@ public:
       row_buffer_.opencl_handle().context(ctx.opencl_context());
       col_buffer_.opencl_handle().context(ctx.opencl_context());
       elements_.opencl_handle().context(ctx.opencl_context());
+      row_blocks_.opencl_handle().context(ctx.opencl_context());
     }
 #endif
   }
 
 
 #ifdef VIENNACL_WITH_OPENCL
+  /** @brief Wraps existing OpenCL buffers holding the compressed sparse row information.
+    *
+    * @param mem_row_buffer   A buffer consisting of unsigned integers (cl_uint) holding the entry points for each row (0-based indexing). (rows+1) elements, the last element being 'nonzeros'.
+    * @param mem_col_buffer   A buffer consisting of unsigned integers (cl_uint) holding the column index for each nonzero entry as stored in 'mem_elements'.
+    * @param mem_elements     A buffer holding the floating point numbers for nonzeros. OpenCL type of elements must match the template 'NumericT'.
+    * @param rows             Number of rows in the matrix to be wrapped.
+    * @param cols             Number of columns to be wrapped.
+    * @param nonzeros         Number of nonzero entries in the matrix.
+    */
   explicit compressed_matrix(cl_mem mem_row_buffer, cl_mem mem_col_buffer, cl_mem mem_elements,
                              vcl_size_t rows, vcl_size_t cols, vcl_size_t nonzeros) :
-    rows_(rows), cols_(cols), nonzeros_(nonzeros)
+    rows_(rows), cols_(cols), nonzeros_(nonzeros), row_block_num_(0)
   {
     row_buffer_.switch_active_handle_id(viennacl::OPENCL_MEMORY);
     row_buffer_.opencl_handle() = mem_row_buffer;
@@ -536,6 +581,9 @@ public:
     elements_.opencl_handle() = mem_elements;
     elements_.opencl_handle().inc();               //prevents that the user-provided memory is deleted once the matrix object is destroyed.
     elements_.raw_size(sizeof(NumericT) * nonzeros);
+
+    //generate block information for CSR-adaptive:
+    generate_row_block_information();
   }
 #endif
 
@@ -549,9 +597,11 @@ public:
     rows_ = other.size1();
     cols_ = other.size2();
     nonzeros_ = other.nnz();
+    row_block_num_ = other.row_block_num_;
 
     viennacl::backend::typesafe_memory_copy<unsigned int>(other.row_buffer_, row_buffer_);
     viennacl::backend::typesafe_memory_copy<unsigned int>(other.col_buffer_, col_buffer_);
+    viennacl::backend::typesafe_memory_copy<unsigned int>(other.row_blocks_, row_blocks_);
     viennacl::backend::typesafe_memory_copy<NumericT>(other.elements_, elements_);
 
     return *this;
@@ -559,14 +609,18 @@ public:
 
 
   /** @brief Sets the row, column and value arrays of the compressed matrix
-      *
-      * @param row_jumper     Pointer to an array holding the indices of the first element of each row (starting with zero). E.g. row_jumper[10] returns the index of the first entry of the 11th row. The array length is 'cols + 1'
-      * @param col_buffer     Pointer to an array holding the column index of each entry. The array length is 'nonzeros'
-      * @param elements       Pointer to an array holding the entries of the sparse matrix. The array length is 'elements'
-      * @param rows           Number of rows of the sparse matrix
-      * @param cols           Number of columns of the sparse matrix
-      * @param nonzeros       Number of nonzeros
-      */
+    *
+    * Type of row_jumper and col_buffer is 'unsigned int' for CUDA and OpenMP (host) backend, but *must* be cl_uint for OpenCL.
+    * The reason is that 'unsigned int' might have a different bit representation on the host than 'unsigned int' on the OpenCL device.
+    * cl_uint is guaranteed to have the correct bit representation for OpenCL devices.
+    *
+    * @param row_jumper     Pointer to an array holding the indices of the first element of each row (starting with zero). E.g. row_jumper[10] returns the index of the first entry of the 11th row. The array length is 'cols + 1'
+    * @param col_buffer     Pointer to an array holding the column index of each entry. The array length is 'nonzeros'
+    * @param elements       Pointer to an array holding the entries of the sparse matrix. The array length is 'elements'
+    * @param rows           Number of rows of the sparse matrix
+    * @param cols           Number of columns of the sparse matrix
+    * @param nonzeros       Number of nonzeros
+    */
   void set(const void * row_jumper,
            const void * col_buffer,
            const NumericT * elements,
@@ -591,6 +645,9 @@ public:
     nonzeros_ = nonzeros;
     rows_ = rows;
     cols_ = cols;
+
+    //generate block information for CSR-adaptive:
+    generate_row_block_information();
   }
 
   /** @brief Allocate memory for the supplied number of nonzeros in the matrix. Old values are preserved. */
@@ -713,11 +770,15 @@ public:
   const vcl_size_t & size2() const { return cols_; }
   /** @brief  Returns the number of nonzero entries */
   const vcl_size_t & nnz() const { return nonzeros_; }
+  /** @brief  Returns the internal number of row blocks for an adaptive SpMV */
+  const vcl_size_t & blocks1() const { return row_block_num_; }
 
   /** @brief  Returns the OpenCL handle to the row index array */
   const handle_type & handle1() const { return row_buffer_; }
   /** @brief  Returns the OpenCL handle to the column index array */
   const handle_type & handle2() const { return col_buffer_; }
+  /** @brief  Returns the OpenCL handle to the row block array */
+  const handle_type & handle3() const { return row_blocks_; }
   /** @brief  Returns the OpenCL handle to the matrix entry array */
   const handle_type & handle() const { return elements_; }
 
@@ -725,9 +786,15 @@ public:
   handle_type & handle1() { return row_buffer_; }
   /** @brief  Returns the OpenCL handle to the column index array */
   handle_type & handle2() { return col_buffer_; }
+  /** @brief  Returns the OpenCL handle to the row block array */
+  handle_type & handle3() { return row_blocks_; }
   /** @brief  Returns the OpenCL handle to the matrix entry array */
   handle_type & handle() { return elements_; }
 
+  /** @brief Switches the memory context of the matrix.
+    *
+    * Allows for e.g. an migration of the full matrix from OpenCL memory to host memory for e.g. computing a preconditioner.
+    */
   void switch_memory_context(viennacl::context new_ctx)
   {
     viennacl::backend::switch_memory_context<unsigned int>(row_buffer_, new_ctx);
@@ -735,6 +802,7 @@ public:
     viennacl::backend::switch_memory_context<NumericT>(elements_, new_ctx);
   }
 
+  /** @brief Returns the current memory context to determine whether the matrix is set up for OpenMP, OpenCL, or CUDA. */
   viennacl::memory_types memory_context() const
   {
     return row_buffer_.get_active_handle_id();
@@ -742,6 +810,7 @@ public:
 
 private:
 
+  /** @brief Helper function for accessing the element (i,j) of the matrix. */
   vcl_size_t element_index(vcl_size_t i, vcl_size_t j)
   {
     //read row indices
@@ -762,6 +831,44 @@ private:
     return nonzeros_;
   }
 
+  void generate_row_block_information()
+  {
+    viennacl::backend::typesafe_host_array<unsigned int> row_buffer(row_buffer_, rows_ + 1);
+    viennacl::backend::memory_read(row_buffer_, 0, row_buffer.raw_size(), row_buffer.get());
+
+    viennacl::backend::typesafe_host_array<unsigned int> row_blocks(row_buffer_, rows_ + 1);
+
+    vcl_size_t num_entries_in_current_batch = 0;
+
+    const vcl_size_t shared_mem_size = 1024; // number of column indices loaded to shared memory, number of floating point values loaded to shared memory
+
+    row_block_num_ = 0;
+    row_blocks.set(0, 0);
+    for (vcl_size_t i=0; i<rows_; ++i)
+    {
+      vcl_size_t entries_in_row = vcl_size_t(row_buffer[i+1]) - vcl_size_t(row_buffer[i]);
+      num_entries_in_current_batch += entries_in_row;
+
+      if (num_entries_in_current_batch > shared_mem_size)
+      {
+        vcl_size_t rows_in_batch = i - row_blocks[row_block_num_];
+        if (rows_in_batch > 0) // at least one full row is in the batch. Use current row in next batch.
+          row_blocks.set(++row_block_num_, i--);
+        else // row is larger than buffer in shared memory
+          row_blocks.set(++row_block_num_, i+1);
+        num_entries_in_current_batch = 0;
+      }
+    }
+    if (num_entries_in_current_batch > 0)
+      row_blocks.set(++row_block_num_, rows_);
+
+    if (row_block_num_ > 0) //matrix might be empty...
+      viennacl::backend::memory_create(row_blocks_,
+                                       row_blocks.element_size() * (row_block_num_ + 1),
+                                       viennacl::traits::context(row_buffer_), row_blocks.get());
+
+  }
+
   // /** @brief Copy constructor is by now not available. */
   //compressed_matrix(compressed_matrix const &);
 
@@ -769,7 +876,9 @@ private:
   vcl_size_t rows_;
   vcl_size_t cols_;
   vcl_size_t nonzeros_;
+  vcl_size_t row_block_num_;
   handle_type row_buffer_;
+  handle_type row_blocks_;
   handle_type col_buffer_;
   handle_type elements_;
 };
