@@ -401,9 +401,9 @@ void generate_triangular_substitute_inplace(StringT & source, std::string const
   source.append("  for (unsigned int rows_processed = 0; rows_processed < A_size1; ++rows_processed)  \n");   //Note: A required to be square
   source.append("  { \n");
   source.append("    row = is_lower_solve ? rows_processed : ((A_size1 - rows_processed) - 1); \n");
+  source.append("    barrier(CLK_GLOBAL_MEM_FENCE); \n");
   source.append("    if (!unit_diagonal_flag) \n");
   source.append("    { \n");
-  source.append("      barrier(CLK_GLOBAL_MEM_FENCE); \n");
   source.append("      if (get_global_id(0) == 0) \n");
   if (is_row_major)
     source.append("        v[row * v_inc + v_start] /= A[(row * A_inc1 + A_start1) * A_internal_size2 + (row * A_inc2 + A_start2)]; \n");
@@ -446,29 +446,16 @@ void generate_trans_kernel(StringT & source, std::string const & numeric_string,
   source.append("           unsigned int B_internal_size1,  unsigned int B_internal_size2, \n");
   source.append("           unsigned int B_stride1,         unsigned int B_stride2) \n");
   source.append("{ \n");
-  source.append("  unsigned int size = A_internal_size2*A_internal_size1; \n");
-  source.append("  for(unsigned int i = get_group_id(0); i < size/get_num_groups(0); i += get_num_groups(0))\n");
+  source.append("  for(unsigned int row = get_group_id(0); row < A_size1; row += get_num_groups(0))\n");
   source.append("  {  \n");
-  source.append("    unsigned int matrix_index = i*get_local_size(0)+get_local_id(0);  \n");
-  source.append("    unsigned int row = matrix_index / A_internal_size2;  \n");
-  source.append("    unsigned int col = matrix_index % A_internal_size2;  \n");
-  source.append("    if (row < A_size1 && col < A_size2)  \n");
-  source.append("      {  \n");
-
+  source.append("    for(unsigned int col = get_local_id(0); col < A_size2; col += get_local_size(0))\n");
+  source.append("    {  \n");
   if(is_row_major)
-  {
-    source.append("      unsigned int pos = (A_start1 + A_stride1 * row) * A_internal_size2 + (A_start2 + A_stride2 * col);  \n");
-    source.append("      unsigned int new_pos = (B_start2 + B_stride2 * col) * B_internal_size2 + (B_start1 + B_stride1 * row);  \n");
-    source.append("      B[new_pos] = A[pos];  \n");
-  }
+    source.append("      B[(B_start1 + B_stride1 * col) * B_internal_size2 + (B_start2 + B_stride2 * row)] = A[(A_start1 + A_stride1 * row) * A_internal_size2 + (A_start2 + A_stride2 * col)];  \n");
   else
-  {
-    source.append("      unsigned int pos = (A_start1 + A_stride1 * row) + A_internal_size1 * (A_start2 + A_stride2 * col);  \n");
-    source.append("      unsigned int new_pos = (B_start2 + B_stride2 * col) + B_internal_size1 * (B_start1 + B_stride1 * row);  \n");
-    source.append("      B[new_pos] = A[pos];  \n");
-  }
-  source.append("     } \n");
-  source.append("   } \n");
+    source.append("      B[(B_start1 + B_stride1 * col) + (B_start2 + B_stride2 * row) * B_internal_size1] = A[(A_start1 + A_stride1 * row) + (A_start2 + A_stride2 * col) * A_internal_size1];  \n");
+  source.append("    } \n");
+  source.append("  } \n");
   source.append("}  \n");
 }
 
