@@ -403,7 +403,7 @@ public:
       for(std::vector< viennacl::ocl::device >::const_iterator it = devices_.begin(); it != devices_.end(); ++it)
         prefix += it->name() + it->vendor() + it->driver_version();
       std::string sha1 = tools::sha1(prefix + source);
-      
+
       std::ifstream cached((cache_path_+sha1).c_str(),std::ios::binary);
       if (cached)
       {
@@ -812,7 +812,7 @@ inline void viennacl::ocl::kernel::set_work_size_defaults()
     while (s < units) // find next power of 2. Important to make reductions work on e.g. six-core CPUs.
       s *= 2;
 
-    global_work_size_[0] = s; global_work_size_[1] = 0; global_work_size_[2] = 0;
+    global_work_size_[0] = s * local_work_size_[0]; global_work_size_[1] = 0; global_work_size_[2] = 0;
   }
 }
 
